@@ -66,6 +66,12 @@ namespace lsp
 
         status_t AudioStream::open(const char *id)
         {
+            if (id == NULL)
+                return STATUS_BAD_ARGUMENTS;
+
+            if (strlen(id) <= 0)
+                return STATUS_INVALID_VALUE;
+
             if (pHeader != NULL)
                 return STATUS_OPENED;
 
@@ -81,6 +87,12 @@ namespace lsp
 
         status_t AudioStream::open(const LSPString *id)
         {
+            if (id == NULL)
+                return STATUS_BAD_ARGUMENTS;
+
+            if (id->is_empty())
+                return STATUS_INVALID_VALUE;
+
             if (pHeader != NULL)
                 return STATUS_OPENED;
 
@@ -111,6 +123,11 @@ namespace lsp
 
         status_t AudioStream::create(const char *id, size_t channels, size_t length)
         {
+            if (id == NULL)
+                return STATUS_BAD_ARGUMENTS;
+            if (strlen(id) <= 0)
+                return STATUS_INVALID_VALUE;
+
             if (pHeader != NULL)
                 return STATUS_OPENED;
 
@@ -130,6 +147,11 @@ namespace lsp
 
         status_t AudioStream::create(const LSPString *id, size_t channels, size_t length)
         {
+            if (id == NULL)
+                return STATUS_BAD_ARGUMENTS;
+            if (id->is_empty())
+                return STATUS_INVALID_VALUE;
+
             if (pHeader != NULL)
                 return STATUS_OPENED;
 
@@ -149,6 +171,9 @@ namespace lsp
 
         status_t AudioStream::allocate(LSPString *name, const char *postfix, size_t channels, size_t length)
         {
+            if (name == NULL)
+                return STATUS_BAD_ARGUMENTS;
+
             if (pHeader != NULL)
                 return STATUS_OPENED;
 
@@ -171,6 +196,9 @@ namespace lsp
 
         status_t AudioStream::allocate(LSPString *name, const LSPString *postfix, size_t channels, size_t length)
         {
+            if (name == NULL)
+                return STATUS_BAD_ARGUMENTS;
+
             if (pHeader != NULL)
                 return STATUS_OPENED;
 
@@ -353,6 +381,11 @@ namespace lsp
             return (pHeader != NULL) ? pHeader->nLength : 0;
         }
 
+        uint32_t AudioStream::counter() const
+        {
+            return (pHeader != NULL) ? pHeader->nCounter : 0;
+        }
+
         status_t AudioStream::begin(ssize_t block_size)
         {
             if (pHeader == NULL)
@@ -417,7 +450,7 @@ namespace lsp
             return STATUS_OK;
         }
 
-        status_t AudioStream::read(size_t channel, float *dst, size_t samples)
+        status_t AudioStream::read_internal(size_t channel, float *dst, size_t samples, copy_function_t copy_func)
         {
             if (pHeader == NULL)
                 return STATUS_CLOSED;
@@ -449,7 +482,7 @@ namespace lsp
             while ((samples > 0) && (c->nCount < nAvail))
             {
                 size_t to_read  = lsp_min(samples, nAvail - c->nCount, length - c->nPosition);
-                dsp::copy(dst, &c->pData[c->nPosition], to_read);
+                copy_func(dst, &c->pData[c->nPosition], to_read);
 
                 samples        -= to_read;
                 dst            += to_read;
@@ -467,7 +500,17 @@ namespace lsp
             return STATUS_OK;
         }
 
-        status_t AudioStream::write(size_t channel, const float *src, size_t samples)
+        status_t AudioStream::read(size_t channel, float *dst, size_t samples)
+        {
+            return read_internal(channel, dst, samples, dsp::copy);
+        }
+
+        status_t AudioStream::read_sanitized(size_t channel, float *dst, size_t samples)
+        {
+            return read_internal(channel, dst, samples, dsp::sanitize2);
+        }
+
+        status_t AudioStream::write_internal(size_t channel, const float *src, size_t samples, copy_function_t copy_func)
         {
             if (pHeader == NULL)
                 return STATUS_CLOSED;
@@ -487,7 +530,7 @@ namespace lsp
             while (samples > 0)
             {
                 size_t to_write = lsp_min(samples, length - c->nPosition);
-                dsp::copy(&c->pData[c->nPosition], src, to_write);
+                copy_func(&c->pData[c->nPosition], src, to_write);
 
                 samples        -= to_write;
                 src            += to_write;
@@ -498,6 +541,16 @@ namespace lsp
             return STATUS_OK;
         }
 
+        status_t AudioStream::write(size_t channel, const float *src, size_t samples)
+        {
+            return write_internal(channel, src, samples, dsp::copy);
+        }
+
+        status_t AudioStream::write_sanitized(size_t channel, const float *src, size_t samples)
+        {
+            return write_internal(channel, src, samples, dsp::sanitize2);
+        }
+
         bool AudioStream::check_channels_synchronized()
         {
             for (size_t i=1; i<nChannels; ++i)
