@@ -289,7 +289,7 @@ namespace lsp
                 windows::window(vWindow, fft_size, windows::window_t(nWindow));
             // Update reactivity
             if (nReconfigure & R_TAU)
-                fTau    = 1.0f - expf(logf(1.0f - M_SQRT1_2) / seconds_to_samples(float(nSampleRate) / float(nPeriod), fReactivity));
+                fTau    = 1.0f - expf(logf(1.0f - M_SQRT1_2) / seconds_to_samples(fRate, fReactivity));
             // Update counters
             if (nReconfigure & R_COUNTERS)
             {
