@@ -137,6 +137,7 @@ namespace lsp
                 tk::MenuItem               *wInvertVScroll;             // Global inversion of mouse vertical scroll
                 tk::MenuItem               *wInvertGraphDotVScroll;     // Invert mouse vertical scroll for GraphDot widgets
                 tk::MenuItem               *wZoomableSpectrum;          // Automatic scaling mode of the frequency graph
+                tk::MenuItem               *wFilelistAutoload;          // Automatically load files on navigating list
                 tk::Menu                   *wFilterPointThickness;      // Filter point thickness submenu
                 tk::Timer                   wGreetingTimer;             // Greeting window timer
 
@@ -156,6 +157,7 @@ namespace lsp
                 ui::IPort                  *pInvertVScroll;
                 ui::IPort                  *pInvertGraphDotVScroll;
                 ui::IPort                  *pZoomableSpectrum;
+                ui::IPort                  *pFilelistAutoload;
 
                 ConfigSink                 *pConfigSink;    // Configuration sink
 
@@ -231,6 +233,7 @@ namespace lsp
                 static status_t slot_invert_vscroll_changed(tk::Widget *sender, void *ptr, void *data);
                 static status_t slot_invert_graph_dot_vscroll_changed(tk::Widget *sender, void *ptr, void *data);
                 static status_t slot_zoomable_spectrum_changed(tk::Widget *sender, void *ptr, void *data);
+                static status_t slot_filelist_autoload_changed(tk::Widget *sender, void *ptr, void *data);
 
                 static status_t slot_submit_enum_menu_item(tk::Widget *sender, void *ptr, void *data);
 
@@ -277,14 +280,17 @@ namespace lsp
                 void                sync_override_hydrogen();
                 void                sync_invert_vscroll(ui::IPort *port);
                 void                sync_zoomable_spectrum();
+                void                sync_filelist_autoload();
                 void                sync_filter_point_thickness();
                 void                sync_enum_menu(enum_menu_t *menu, ui::IPort *port);
                 void                apply_user_paths_settings();
+                void                read_path_param(LSPString *value, const char *port_id);
                 void                read_path_param(tk::String *value, const char *port_id);
                 void                read_bool_param(tk::Boolean *value, const char *port_id);
                 void                commit_path_param(tk::String *value, const char *port_id);
                 void                commit_bool_param(tk::Boolean *value, const char *port_id);
                 void                bind_trigger(const char *uid, tk::slot_t ev, tk::event_handler_t handler);
+                bool                open_manual_file(const char *fmt...);
 
                 status_t            init_context(ui::UIContext *ctx);
 
@@ -310,6 +316,7 @@ namespace lsp
             public:
                 status_t            show_about_window();
                 status_t            show_plugin_manual();
+                status_t            show_ui_manual();
                 void                host_scaling_changed();
 
             public:
