@@ -26,7 +26,9 @@
 #include <lsp-plug.in/plug-fw/core/osc_buffer.h>
 #include <lsp-plug.in/plug-fw/wrap/lv2/wrapper.h>
 #include <lsp-plug.in/plug-fw/meta/manifest.h>
+#include <lsp-plug.in/plug-fw/meta/func.h>
 #include <lsp-plug.in/plug-fw/wrap/lv2/types.h>
+#include <lsp-plug.in/plug-fw/wrap/lv2/factory.h>
 
 #define LSP_LEGACY_KVT_URI          LSP_LV2_BASE_URI "ui/lv2"
 
@@ -56,11 +58,12 @@ namespace lsp
             return ssize_t(a->get_urid()) - ssize_t(b->get_urid());
         }
 
-        Wrapper::Wrapper(plug::Module *plugin, resource::ILoader *loader, lv2::Extensions *ext):
-            plug::IWrapper(plugin, loader),
+        Wrapper::Wrapper(plug::Module *plugin, lv2::Factory *factory, lv2::Extensions *ext):
+            plug::IWrapper(plugin, factory->resources()),
             sKVTListener(this)
         {
             pPlugin         = plugin;
+            pFactory        = factory;
             pExt            = ext;
             pExecutor       = NULL;
             pAtomIn         = NULL;
@@ -82,15 +85,19 @@ namespace lsp
             bStateManage    = false;
             fSampleRate     = DEFAULT_SAMPLE_RATE;
             pOscPacket      = reinterpret_cast<uint8_t *>(::malloc(OSC_PACKET_MAX));
-            nStateMode      = SM_LOADING;
-            nDumpReq        = 0;
+            atomic_store(&nStateMode, SM_LOADING);
+            atomic_store(&nDumpReq, 0);
             nDumpResp       = 0;
-            pPackage        = NULL;
+            atomic_store(&nShmReqs, 0);
             pKVTDispatcher  = NULL;
 
             pSamplePlayer   = NULL;
             nPlayPosition   = 0;
             nPlayLength     = 0;
+
+            pShmClient      = NULL;
+
+            pFactory->acquire();
         }
 
         Wrapper::~Wrapper()
@@ -113,10 +120,15 @@ namespace lsp
             sSurface.width  = 0;
             sSurface.height = 0;
             sSurface.stride = 0;
-            pPackage        = NULL;
 
             pKVTDispatcher  = NULL;
             pSamplePlayer   = NULL;
+
+            if (pFactory != NULL)
+            {
+                pFactory->release();
+                pFactory        = NULL;
+            }
         }
 
         lv2::Port *Wrapper::port_by_urid(LV2_URID urid)
@@ -160,25 +172,6 @@ namespace lsp
 
             // Get plugin metadata
             const meta::plugin_t *m  = pPlugin->metadata();
-            status_t res;
-
-            // Load package information
-            io::IInStream *is = resources()->read_stream(LSP_BUILTIN_PREFIX "manifest.json");
-            if (is == NULL)
-            {
-                lsp_error("No manifest.json found in resources");
-                return STATUS_BAD_STATE;
-            }
-
-            res = meta::load_manifest(&pPackage, is);
-            is->close();
-            delete is;
-
-            if (res != STATUS_OK)
-            {
-                lsp_error("Error while reading manifest file");
-                return res;
-            }
 
             // Create ports
             lsp_trace("Creaing ports");
@@ -220,6 +213,18 @@ namespace lsp
                 pSamplePlayer->set_sample_rate(srate);
             }
 
+            // Create shared memory sends
+            if ((vAudioBuffers.size() > 0) || (m->extensions & meta::E_SHM_TRACKING))
+            {
+                lsp_trace("Creating shared memory client");
+                pShmClient          = new core::ShmClient();
+                if (pShmClient == NULL)
+                    return STATUS_NO_MEM;
+                pShmClient->init(this, pFactory, plugin_ports.array(), plugin_ports.size());
+                pShmClient->set_sample_rate(fSampleRate);
+                pShmClient->set_buffer_size(pExt->nMaxBlockLength);
+            }
+
             // Update refresh rate
             nSyncSamples        = srate / pExt->ui_refresh_rate();
             nClients            = 0;
@@ -242,6 +247,14 @@ namespace lsp
                 pSamplePlayer = NULL;
             }
 
+            // Destroy shared memory client
+            if (pShmClient != NULL)
+            {
+                pShmClient->destroy();
+                delete pShmClient;
+                pShmClient = NULL;
+            }
+
             // Stop KVT dispatcher
             if (pKVTDispatcher != NULL)
             {
@@ -291,13 +304,6 @@ namespace lsp
                 drop_port_metadata(vGenMetadata[i]);
             }
 
-            // Destroy manifest
-            if (pPackage != NULL)
-            {
-                meta::free_manifest(pPackage);
-                pPackage        = NULL;
-            }
-
             vAllPorts.flush();
             vExtPorts.flush();
             vMeshPorts.flush();
@@ -321,13 +327,6 @@ namespace lsp
                 delete pExt;
                 pExt        = NULL;
             }
-
-            // Drop loader
-            if (pLoader != NULL)
-            {
-                delete pLoader;
-                pLoader     = NULL;
-            }
         }
 
         lv2::Port *Wrapper::create_port(lltl::parray<plug::IPort> *plugin_ports, const meta::port_t *p, const char *postfix, bool virt)
@@ -347,7 +346,9 @@ namespace lsp
 
                     vPluginPorts.add(result);
                     plugin_ports->add(result);
+                    lsp_trace("Added mesh port id=%s", result->metadata()->id);
                     break;
+
                 case meta::R_STREAM:
                     if (pExt->atom_supported())
                     {
@@ -358,7 +359,9 @@ namespace lsp
                         result = new lv2::Port(p, pExt, false);
                     vPluginPorts.add(result);
                     plugin_ports->add(result);
+                    lsp_trace("Added stream port id=%s", result->metadata()->id);
                     break;
+
                 case meta::R_FBUFFER:
                     if (pExt->atom_supported())
                     {
@@ -369,7 +372,9 @@ namespace lsp
                         result = new lv2::Port(p, pExt, false);
                     vPluginPorts.add(result);
                     plugin_ports->add(result);
+                    lsp_trace("Added framebuffer port id=%s", result->metadata()->id);
                     break;
+
                 case meta::R_PATH:
                     if (pExt->atom_supported())
                         result      = new lv2::PathPort(p, pExt);
@@ -377,6 +382,30 @@ namespace lsp
                         result      = new lv2::Port(p, pExt, false);
                     vPluginPorts.add(result);
                     plugin_ports->add(result);
+                    lsp_trace("Added path port id=%s", result->metadata()->id);
+                    break;
+
+                case meta::R_STRING:
+                case meta::R_SEND_NAME:
+                case meta::R_RETURN_NAME:
+                    if (pExt->atom_supported())
+                    {
+                        lv2::StringPort *sp     = new lv2::StringPort(p, pExt);
+                        vStringPorts.add(sp);
+                        result      = sp;
+                    }
+                    else
+                        result      = new lv2::Port(p, pExt, false);
+                    vPluginPorts.add(result);
+                    plugin_ports->add(result);
+                #ifdef LSP_TRACE
+                    if (meta::is_send_name(p))
+                        lsp_trace("Added send name port id=%s", result->metadata()->id);
+                    else if (meta::is_return_name(p))
+                        lsp_trace("Added return name port id=%s", result->metadata()->id);
+                    else
+                        lsp_trace("Added string port id=%s", result->metadata()->id);
+                #endif /* LSP_TRACE */
                     break;
 
                 case meta::R_MIDI_IN:
@@ -389,7 +418,10 @@ namespace lsp
                     else
                         result = new lv2::Port(p, pExt, false);
                     plugin_ports->add(result);
+
+                    lsp_trace("Added midi port id=%s", result->metadata()->id);
                     break;
+
                 case meta::R_OSC_IN:
                 case meta::R_OSC_OUT:
                     if (pExt->atom_supported())
@@ -400,6 +432,8 @@ namespace lsp
                     else
                         result = new lv2::Port(p, pExt, false);
                     plugin_ports->add(result);
+
+                    lsp_trace("Added osc port id=%s", result->metadata()->id);
                     break;
 
 
@@ -415,9 +449,36 @@ namespace lsp
                     {
                         result->set_id(vExtPorts.size());
                         vExtPorts.add(result);
-                        lsp_trace("Added external port id=%s, external_id=%d", result->metadata()->id, int(vExtPorts.size() - 1));
+                        lsp_trace("Added external audio port id=%s, external_id=%d", result->metadata()->id, int(vExtPorts.size() - 1));
                     }
+                    else
+                        lsp_trace("Added audio port id=%s", result->metadata()->id);
                     break;
+
+                case meta::R_AUDIO_SEND:
+                {
+                    lv2::AudioBufferPort *ap = new lv2::AudioBufferPort(p, pExt);
+                    vPluginPorts.add(ap);
+                    vAudioBuffers.add(ap);
+                    plugin_ports->add(ap);
+                    result = ap;
+
+                    lsp_trace("Added audio send port id=%s", result->metadata()->id);
+                    break;
+                }
+
+                case meta::R_AUDIO_RETURN:
+                {
+                    lv2::AudioBufferPort *ap = new lv2::AudioBufferPort(p, pExt);
+                    vPluginPorts.add(ap);
+                    vAudioBuffers.add(ap);
+                    plugin_ports->add(ap);
+                    result = ap;
+
+                    lsp_trace("Added audio return port id=%s", result->metadata()->id);
+                    break;
+                }
+
                 case meta::R_CONTROL:
                 case meta::R_METER:
                     if (meta::is_out_port(p))
@@ -432,8 +493,10 @@ namespace lsp
                     {
                         result->set_id(vExtPorts.size());
                         vExtPorts.add(result);
-                        lsp_trace("Added external port id=%s, external_id=%d", result->metadata()->id, int(vExtPorts.size() - 1));
+                        lsp_trace("Added external control port id=%s, external_id=%d", result->metadata()->id, int(vExtPorts.size() - 1));
                     }
+                    else
+                        lsp_trace("Added control port id=%s", result->metadata()->id);
                     break;
 
                 case meta::R_BYPASS:
@@ -451,6 +514,8 @@ namespace lsp
                         vExtPorts.add(result);
                         lsp_trace("Added bypass port id=%s, external_id=%d", result->metadata()->id, int(vExtPorts.size() - 1));
                     }
+                    else
+                        lsp_trace("Added bypass port id=%s", result->metadata()->id);
                     break;
 
                 case meta::R_PORT_SET:
@@ -462,6 +527,7 @@ namespace lsp
                     vPluginPorts.add(pg);
                     vAllPorts.add(pg);
                     plugin_ports->add(pg);
+                    lsp_trace("Added port_set port id=%s", pg->metadata()->id);
 
                     // Generate nested ports
                     for (size_t row=0; row<pg->rows(); ++row)
@@ -543,7 +609,7 @@ namespace lsp
             receive_atoms(samples);
 
             // Pre-rocess regular ports
-            size_t smode            = nStateMode;
+            size_t smode            = atomic_load(&nStateMode);
             for (size_t i=0, n=vAllPorts.size(); i<n; ++i)
             {
                 // Get port
@@ -552,7 +618,7 @@ namespace lsp
                     continue;
 
                 // Pre-process data in port
-                if (port->pre_process(samples))
+                if (port->pre_process())
                 {
                     lsp_trace("port changed: %s, value=%f", port->metadata()->id, port->value());
                     bUpdateSettings = true;
@@ -569,11 +635,13 @@ namespace lsp
             if (bUpdateSettings)
             {
                 pPlugin->update_settings();
+                if (pShmClient != NULL)
+                    pShmClient->update_settings();
                 bUpdateSettings     = false;
             }
 
             // Need to dump state?
-            uatomic_t dump_req  = nDumpReq;
+            uatomic_t dump_req  = atomic_load(&nDumpReq);
             if (dump_req != nDumpResp)
             {
                 dump_plugin_state();
@@ -586,6 +654,12 @@ namespace lsp
             {
                 size_t to_process = lsp_min(samples - off, pExt->nMaxBlockLength);
 
+                if (pShmClient != NULL)
+                {
+                    pShmClient->begin(to_process);
+                    pShmClient->pre_process(to_process);
+                }
+
                 // Sanitize input data
                 for (size_t i=0; i<n_audio_ports; ++i)
                 {
@@ -605,9 +679,19 @@ namespace lsp
                         port->sanitize_after(off, to_process);
                 }
 
+                if (pShmClient != NULL)
+                {
+                    pShmClient->post_process(to_process);
+                    pShmClient->end();
+                }
+
                 off += to_process;
             }
 
+            // Increment number of state requests
+            if ((pShmClient != NULL) && (pShmClient->state_updated()))
+                atomic_add(&nShmReqs, 1);
+
             // Transmit atoms (if possible)
             transmit_atoms(samples);
             clear_midi_ports();
@@ -618,12 +702,22 @@ namespace lsp
                 // Get port
                 lv2::Port *port = vAllPorts.uget(i);
                 if (port != NULL)
-                    port->post_process(samples);
+                    port->post_process();
             }
 
             // Transmit latency (if possible)
             if (pLatency != NULL)
-                *pLatency   = pPlugin->latency();
+            {
+                const size_t latency = pPlugin->latency();
+
+            #ifdef LSP_TRACE
+                const size_t host_latency = *pLatency;
+                if (host_latency != latency)
+                    lsp_trace("Plugin latency changed from %d to %d", int(host_latency), int(latency));
+            #endif /* LSP_TRACE */
+
+                *pLatency   = latency;
+            }
         }
 
         void Wrapper::clear_midi_ports()
@@ -816,7 +910,6 @@ namespace lsp
                         lv2::Port *p    = port_by_urid(key->body);
                         if ((p != NULL) && (p->get_type_urid() == value->type))
                         {
-                            lsp_trace("forwarding patch message to port %s", p->metadata()->id);
                             if (p->deserialize(value, 0)) // No flags for simple PATCH message
                             {
                                 // Change state if it is a virtual port
@@ -883,8 +976,9 @@ namespace lsp
             {
                 if (obj->body.id == pExt->uridConnectUI)
                 {
-                    nClients    ++;
-                    nStateReqs  ++;
+                    ++nClients;
+                    ++nStateReqs;
+                    atomic_add(&nShmReqs, 1);
                     lsp_trace("UI has connected, current number of clients=%d", int(nClients));
                     if (pKVTDispatcher != NULL)
                         pKVTDispatcher->connect_client();
@@ -1072,6 +1166,60 @@ namespace lsp
             nPlayLength         = length;
         }
 
+        void Wrapper::transmit_shm_state_to_clients()
+        {
+            if ((pShmClient == NULL) || ((nClients + nDirectClients) <= 0))
+                return;
+
+            ssize_t count = atomic_load(&nShmReqs);
+            if (count <= 0)
+                return;
+
+            const core::ShmState *state   = pShmClient->state();
+            if (state == NULL)
+                return;
+
+            lsp_trace("Transmitting shared memory state...");
+
+            atomic_add(&nShmReqs, -count);
+
+            LV2_Atom_Forge_Frame    frame, tuple, obj;
+
+            pExt->forge_frame_time(0); // Event header
+            pExt->forge_object(&frame, pExt->uridShmState, pExt->uridShmStateType);
+
+            pExt->forge_key(pExt->uridShmStateItems);
+            pExt->forge_tuple(&tuple);
+
+            for (size_t i=0, n=state->size(); i<n; ++i)
+            {
+                const core::ShmRecord *item = state->get(i);
+                if (item == NULL)
+                    continue;
+
+                pExt->forge_object(&obj, pExt->uridBlank, pExt->uridShmRecordType);
+
+                pExt->forge_key(pExt->uridShmRecordName);
+                pExt->forge_string(item->name);
+
+                pExt->forge_key(pExt->uridShmRecordId);
+                pExt->forge_string(item->id);
+
+                pExt->forge_key(pExt->uridShmRecordIndex);
+                pExt->forge_int(item->index);
+
+                pExt->forge_key(pExt->uridShmRecordMagic);
+                pExt->forge_int(item->magic);
+
+                pExt->forge_pop(&obj);
+            }
+
+            pExt->forge_pop(&tuple);
+            pExt->forge_pop(&frame);
+
+            lsp_trace("Transmitted shared memory state of %d records", int(state->size()));
+        }
+
         void Wrapper::transmit_port_data_to_clients(bool sync_req, bool patch_req, bool state_req)
         {
             // Serialize time/position of plugin
@@ -1098,6 +1246,9 @@ namespace lsp
                     case meta::R_STREAM:
                     case meta::R_FBUFFER:
                         continue;
+                    case meta::R_STRING:
+                    case meta::R_SEND_NAME:
+                    case meta::R_RETURN_NAME:
                     case meta::R_PATH:
                         if (p->tx_pending()) // Tranmission request pending?
                             break;
@@ -1128,6 +1279,9 @@ namespace lsp
                 pExt->forge_key(pExt->uridPatchValue);
                 p->serialize();
                 pExt->forge_pop(&frame);
+
+                // Reset pending transfer flag
+                p->reset_tx_pending();
             }
 
             // Serialize meshes (it's own primitive MESH)
@@ -1337,6 +1491,7 @@ namespace lsp
             // Forge sequence header
             LV2_Atom_Forge_Frame    seq;
             pExt->forge_sequence_head(&seq, 0);
+            lsp_finally { pExt->forge_pop(&seq); };
 
             // Transmit state change atom if state has been changed
             if (change_state_atomic(SM_CHANGED, SM_REPORTED))
@@ -1345,7 +1500,7 @@ namespace lsp
                 pExt->forge_frame_time(0); // Event header
                 pExt->forge_object(&frame, pExt->uridBlank, pExt->uridStateChanged);
                 pExt->forge_pop(&frame);
-                lsp_trace("#STATE MODE = %d", nStateMode);
+                lsp_trace("#STATE MODE = %d", atomic_load(&nStateMode));
             }
 
             // For each MIDI port, serialize it's data
@@ -1377,9 +1532,7 @@ namespace lsp
             }
 
             transmit_play_position_to_clients();
-
-            // Complete sequence
-            pExt->forge_pop(&seq);
+            transmit_shm_state_to_clients();
         }
 
         void Wrapper::transmit_osc_events(lv2::Port *p)
@@ -1636,8 +1789,8 @@ namespace lsp
             pPlugin->before_state_save();
 
             // Mark state as synchronized
-            nStateMode      = SM_SYNC;
-            lsp_trace("#STATE MODE = %d", nStateMode);
+            atomic_store(&nStateMode, SM_SYNC);
+            lsp_trace("#STATE MODE = %d", atomic_load(&nStateMode));
 
             // Init context
             pExt->init_state_context(store, NULL, handle, flags, features);
@@ -2025,8 +2178,8 @@ namespace lsp
 
             // Update the state
             pExt->reset_state_context();
-            nStateMode = SM_LOADING;
-            lsp_trace("#STATE MODE = %d", nStateMode);
+            atomic_store(&nStateMode, SM_LOADING);
+            lsp_trace("#STATE MODE = %d", atomic_load(&nStateMode));
 
             // Notify that plugin state has been loaded
             pPlugin->state_loaded();
@@ -2037,7 +2190,7 @@ namespace lsp
             // Perform atomic state change
             while (true)
             {
-                if (nStateMode != from)
+                if (atomic_load(&nStateMode) != from)
                     return false;
                 if (atomic_cas(&nStateMode, from, to))
                 {
@@ -2050,7 +2203,8 @@ namespace lsp
         void Wrapper::connect_direct_ui()
         {
             // Increment number of clients
-            nDirectClients++;
+            ++nDirectClients;
+            atomic_add(&nShmReqs, 1);
             if (pKVTDispatcher != NULL)
                 pKVTDispatcher->connect_client();
         }
@@ -2146,7 +2300,7 @@ namespace lsp
 
         const meta::package_t *Wrapper::package() const
         {
-            return pPackage;
+            return pFactory->manifest();
         }
 
         meta::plugin_format_t Wrapper::plugin_format() const
@@ -2172,6 +2326,11 @@ namespace lsp
             bUpdateSettings     = true;
         }
 
+        const core::ShmState *Wrapper::shm_state()
+        {
+            return (pShmClient != NULL) ? pShmClient->state() : NULL;
+        }
+
     } /* namespace lv2 */
 } /* namespace lsp */
 
