@@ -33,36 +33,43 @@
 #include <lsp-plug.in/common/endian.h>
 #include <lsp-plug.in/ipc/NativeExecutor.h>
 
+#ifdef WITH_UI_FEATURE
+    #include <lsp-plug.in/plug-fw/wrap/vst2/ui_wrapper.h>
+#endif /* WITH_UI_FEATURE */
+
 namespace lsp
 {
     namespace vst2
     {
         Wrapper::Wrapper(
             plug::Module *plugin,
-            resource::ILoader *loader,
+            vst2::Factory *factory,
             AEffect *effect,
             audioMasterCallback callback)
-            : plug::IWrapper(plugin, loader)
+            : plug::IWrapper(plugin, factory->resources())
         {
-            pPlugin         = plugin;
             pEffect         = effect;
-
+            pFactory        = factory;
             pMaster         = callback;
             pExecutor       = NULL;
-
-            fLatency        = 0.0f;
-            nDumpReq        = 0;
-            nDumpResp       = 0;
-
-            pSamplePlayer   = NULL;
-
-            pBypass         = NULL;
             bUpdateSettings = true;
             bStateManage    = false;
+
+        #ifdef WITH_UI_FEATURE
             pUIWrapper      = NULL;
             nUIReq          = 0;
             nUIResp         = 0;
-            pPackage        = NULL;
+        #endif /* WITH_UI_FEATURE */
+
+            nLatency        = 0;
+            nDumpReq        = 0;
+            nDumpResp       = 0;
+
+            pBypass         = NULL;
+            pSamplePlayer   = NULL;
+            pShmClient      = NULL;
+
+            pFactory->acquire();
         }
 
         Wrapper::~Wrapper()
@@ -70,7 +77,12 @@ namespace lsp
             pPlugin         = NULL;
             pEffect         = NULL;
             pMaster         = NULL;
-            pPackage        = NULL;
+
+            if (pFactory != NULL)
+            {
+                pFactory->release();
+                pFactory        = NULL;
+            }
         }
 
         static ssize_t cmp_port_identifiers(const vst2::Port *pa, const vst2::Port *pb)
@@ -85,26 +97,6 @@ namespace lsp
             AEffect *e                      = pEffect;
             const meta::plugin_t *m         = pPlugin->metadata();
 
-            status_t res;
-
-            // Load package information
-            io::IInStream *is = resources()->read_stream(LSP_BUILTIN_PREFIX "manifest.json");
-            if (is == NULL)
-            {
-                lsp_error("No manifest.json found in resources");
-                return STATUS_BAD_STATE;
-            }
-
-            res = meta::load_manifest(&pPackage, is);
-            is->close();
-            delete is;
-
-            if (res != STATUS_OK)
-            {
-                lsp_error("Error while reading manifest file");
-                return res;
-            }
-
             // Create ports
             lsp_trace("Creating ports for %s - %s", m->name, m->description);
             lltl::parray<plug::IPort> plugin_ports;
@@ -123,7 +115,7 @@ namespace lsp
             // Update instance parameters
             e->numInputs                    = 0;
             e->numOutputs                   = 0;
-            e->numParams                    = vParams.size();
+            e->numParams                    = vExtParams.size();
 
             for (size_t i=0, n=vAudioPorts.size(); i<n; ++i)
             {
@@ -137,7 +129,7 @@ namespace lsp
 
             // Generate IDs for parameter ports
             for (ssize_t id=0; id < e->numParams; ++id)
-                vParams[id]->set_id(id);
+                vExtParams[id]->set_id(id);
 
             // Initialize state chunk
             pEffect->flags                 |= effFlagsProgramChunks;
@@ -154,11 +146,31 @@ namespace lsp
                 pSamplePlayer->init(this, plugin_ports.array(), plugin_ports.size());
             }
 
+            // Create shared memory sends and returns
+            if ((vAudioBuffers.size() > 0) || (m->extensions & meta::E_SHM_TRACKING))
+            {
+                lsp_trace("Creating shared memory client");
+                pShmClient          = new core::ShmClient();
+                if (pShmClient == NULL)
+                    return STATUS_NO_MEM;
+                pShmClient->init(this, pFactory, plugin_ports.array(), plugin_ports.size());
+            }
+
             return STATUS_OK;
         }
 
         void Wrapper::destroy()
         {
+        #ifdef WITH_UI_FEATURE
+            // Destroy UI wrapper
+            if (pUIWrapper != NULL)
+            {
+                lsp_trace("Destroy UI wrapper ui=%p", pUIWrapper);
+                pUIWrapper->destroy();
+                delete pUIWrapper;
+            }
+        #endif /* WITH_UI_FEATURE */
+
             // Destroy sample player
             if (pSamplePlayer != NULL)
             {
@@ -167,6 +179,14 @@ namespace lsp
                 pSamplePlayer = NULL;
             }
 
+            // Destroy shared memory client
+            if (pShmClient != NULL)
+            {
+                pShmClient->destroy();
+                delete pShmClient;
+                pShmClient = NULL;
+            }
+
             // Shutdown and delete executor if exists
             if (pExecutor != NULL)
             {
@@ -202,23 +222,11 @@ namespace lsp
             }
             vGenMetadata.flush();
 
-            // Destroy manifest
-            if (pPackage != NULL)
-            {
-                meta::free_manifest(pPackage);
-                pPackage        = NULL;
-            }
-
-            // Delete the loader
-            if (pLoader != NULL)
-            {
-                delete pLoader;
-                pLoader = NULL;
-            }
-
             // Clear all port lists
-            vAudioPorts.clear();
-            vParams.clear();
+            vAudioPorts.flush();
+            vAudioBuffers.flush();
+            vExtParams.flush();
+            vParams.flush();
 
             pMaster     = NULL;
             pEffect     = NULL;
@@ -254,12 +262,14 @@ namespace lsp
                     lsp_trace("creating midi output port %s", port->id);
                     vp = new vst2::MidiOutputPort(port, pEffect, pMaster);
                     plugin_ports->add(vp);
+                    vMidiOut.add(static_cast<vst2::MidiOutputPort *>(vp));
                     break;
 
                 case meta::R_MIDI_IN:
                     pEffect->flags         |= effFlagsIsSynth;
                     vp = new vst2::MidiInputPort(port, pEffect, pMaster);
                     plugin_ports->add(vp);
+                    vMidiIn.add(static_cast<vst2::MidiInputPort *>(vp));
                     break;
 
                 case meta::R_OSC_IN:
@@ -272,6 +282,28 @@ namespace lsp
                     lsp_trace("creating path port %s", port->id);
                     vp  = new vst2::PathPort(port, pEffect, pMaster);
                     plugin_ports->add(vp);
+                    vParams.add(static_cast<vst2::PathPort *>(vp));
+                    break;
+
+                case meta::R_STRING:
+                    lsp_trace("creating string port %s", port->id);
+                    vp  = new vst2::StringPort(port, pEffect, pMaster);
+                    plugin_ports->add(vp);
+                    vParams.add(static_cast<vst2::StringPort *>(vp));
+                    break;
+
+                case meta::R_SEND_NAME:
+                    lsp_trace("creating send name port %s", port->id);
+                    vp  = new vst2::StringPort(port, pEffect, pMaster);
+                    plugin_ports->add(vp);
+                    vParams.add(static_cast<vst2::StringPort *>(vp));
+                    break;
+
+                case meta::R_RETURN_NAME:
+                    lsp_trace("creating return name port %s", port->id);
+                    vp  = new vst2::StringPort(port, pEffect, pMaster);
+                    plugin_ports->add(vp);
+                    vParams.add(static_cast<vst2::StringPort *>(vp));
                     break;
 
                 case meta::R_AUDIO_IN:
@@ -282,19 +314,29 @@ namespace lsp
                     vAudioPorts.add(static_cast<vst2::AudioPort *>(vp));
                     break;
 
+                case meta::R_AUDIO_SEND:
+                case meta::R_AUDIO_RETURN:
+                    lsp_trace("creating audio buffer port %s", port->id);
+                    vp = new vst2::AudioBufferPort(port, pEffect, pMaster);
+                    plugin_ports->add(vp);
+                    vAudioBuffers.add(static_cast<vst2::AudioBufferPort *>(vp));
+                    break;
+
                 case meta::R_CONTROL:
                     lsp_trace("creating control port %s", port->id);
                     vp      = new vst2::ParameterPort(port, pEffect, pMaster);
+                    vParams.add(static_cast<vst2::ParameterPort *>(vp));
                     if (postfix == NULL)
-                        vParams.add(static_cast<vst2::ParameterPort *>(vp));
+                        vExtParams.add(static_cast<vst2::ParameterPort *>(vp));
                     plugin_ports->add(vp);
                     break;
 
                 case meta::R_BYPASS:
                     lsp_trace("creating bypass port %s", port->id);
                     vp      = new vst2::ParameterPort(port, pEffect, pMaster);
+                    vParams.add(static_cast<vst2::ParameterPort *>(vp));
                     if (postfix == NULL)
-                        vParams.add(static_cast<vst2::ParameterPort *>(vp));
+                        vExtParams.add(static_cast<vst2::ParameterPort *>(vp));
                     pBypass     = vp;
                     plugin_ports->add(vp);
                     break;
@@ -314,6 +356,7 @@ namespace lsp
                     lsp_trace("creating port_set port %s", port->id);
                     plugin_ports->add(pg);
                     vPorts.add(pg);
+                    vParams.add(pg);
 
                     // Add nested ports
                     for (size_t row=0; row<pg->rows(); ++row)
@@ -363,6 +406,8 @@ namespace lsp
             pPlugin->set_sample_rate(sr);
             if (pSamplePlayer != NULL)
                 pSamplePlayer->set_sample_rate(sr);
+            if (pShmClient != NULL)
+                pShmClient->set_sample_rate(sr);
             bUpdateSettings = true;
         }
 
@@ -370,13 +415,24 @@ namespace lsp
         {
             lsp_trace("Block size for audio processing: %d", int(size));
 
-            // Sync buffer size to all input ports
+            // Sync buffer size to all audio ports
             for (size_t i=0, n=vAudioPorts.size(); i<n; ++i)
             {
                 vst2::AudioPort *p = vAudioPorts.uget(i);
                 if (p != NULL)
                     p->set_block_size(size);
             }
+
+            // Sync buffer size to all send/return ports
+            for (size_t i=0, n=vAudioBuffers.size(); i<n; ++i)
+            {
+                vst2::AudioBufferPort *p = vAudioBuffers.uget(i);
+                if (p != NULL)
+                    p->set_block_size(size);
+            }
+
+            if (pShmClient != NULL)
+                pShmClient->set_buffer_size(size);
         }
 
         void Wrapper::mains_changed(VstIntPtr value)
@@ -417,26 +473,29 @@ namespace lsp
 
         vst2::ParameterPort *Wrapper::parameter_port(size_t index)
         {
-            return vParams[index];
+            return vExtParams[index];
         }
 
         void Wrapper::open()
         {
         }
 
+    #ifdef WITH_UI_FEATURE
         void Wrapper::set_ui_wrapper(UIWrapper *ui)
         {
             if (pUIWrapper == ui)
                 return;
 
             pUIWrapper  = ui;
-            atomic_add(&nUIReq, 1);
+            if (ui != NULL)
+                atomic_add(&nUIReq, 1);
         }
 
         UIWrapper *Wrapper::ui_wrapper()
         {
             return pUIWrapper;
         }
+    #endif /* WITH_UI_FEATURE */
 
         void Wrapper::sync_position()
         {
@@ -501,6 +560,7 @@ namespace lsp
                 return;
             }
 
+        #ifdef WITH_UI_FEATURE
             // Sync UI state
             const uatomic_t ui_req = nUIReq;
             if (ui_req != nUIResp)
@@ -511,6 +571,7 @@ namespace lsp
                     pPlugin->activate_ui();
                 nUIResp     = ui_req;
             }
+        #endif /* WITH_UI_FEATURE */
 
             // Synchronize position
             sync_position();
@@ -527,19 +588,12 @@ namespace lsp
                 port->sanitize_before(samples);
             }
 
-            // Process ALL ports for changes
-            size_t n_ports      = vPorts.size();
-            vst2::Port **v_ports= vPorts.array();
-
-            for (size_t i=0; i<n_ports; ++i)
+            // Process ALL parameter ports for changes
+            for (size_t i=0, n=vParams.size(); i<n; ++i)
             {
-                // Get port
-                vst2::Port *port = v_ports[i];
-                if (port == NULL)
-                    continue;
-
                 // Pre-process data in port
-                if (port->pre_process(samples))
+                vst2::Port *port = vParams.uget(i);
+                if ((port != NULL) && (port->changed()))
                 {
                     lsp_trace("port changed: %s", port->metadata()->id);
                     bUpdateSettings = true;
@@ -551,6 +605,8 @@ namespace lsp
             {
                 lsp_trace("updating settings");
                 pPlugin->update_settings();
+                if (pShmClient != NULL)
+                    pShmClient->update_settings();
                 bUpdateSettings     = false;
             }
 
@@ -562,6 +618,12 @@ namespace lsp
                 nDumpResp           = dump_req;
             }
 
+            if (pShmClient != NULL)
+            {
+                pShmClient->begin(samples);
+                pShmClient->pre_process(samples);
+            }
+
             // Process samples
             pPlugin->process(samples);
 
@@ -569,6 +631,12 @@ namespace lsp
             if (pSamplePlayer != NULL)
                 pSamplePlayer->process(samples);
 
+            if (pShmClient != NULL)
+            {
+                pShmClient->post_process(samples);
+                pShmClient->end();
+            }
+
             // Sanitize output audio data
             for (size_t i=0, n=vAudioPorts.size(); i<n; ++i)
             {
@@ -577,42 +645,38 @@ namespace lsp
                     port->sanitize_after(samples);
             }
 
-            // Report latency
-            float latency           = pPlugin->latency();
-            if (fLatency != latency)
+            // Emit MIDI events if they are present
+            for (size_t i=0, n=vMidiOut.size(); i < n; ++i)
             {
+                vst2::MidiOutputPort *port = vMidiOut.uget(i);
+                if (port != NULL)
+                    port->flush();
+            }
+
+            // Report latency
+            size_t latency      = pPlugin->latency();
+            if (nLatency != latency)
+            {
+                lsp_trace("Plugin latency changed from %d to %d", int(nLatency), int(latency));
+
                 pEffect->initialDelay   = latency;
-                fLatency                = latency;
+                nLatency                = latency;
                 if (pMaster)
                 {
                     lsp_trace("Reporting latency = %d samples to the host", int(latency));
                     pMaster(pEffect, audioMasterIOChanged, 0, 0, 0, 0);
                 }
             }
-
-            // Post-process ALL ports
-            for (size_t i=0; i<n_ports; ++i)
-            {
-                vst2::Port *port = v_ports[i];
-                if (port != NULL)
-                    port->post_process(samples);
-            }
         }
 
         void Wrapper::process_events(const VstEvents *e)
         {
             // We need to deliver MIDI events to MIDI ports
-            for (size_t i=0; i<vPorts.size(); ++i)
+            for (size_t i=0; i<vMidiIn.size(); ++i)
             {
-                vst2::Port *p               = vPorts[i];
-
-                // Find MIDI port(s)
-                if (!meta::is_midi_in_port(p->metadata()))
-                    continue;
-
-                // Call for event processing
-                vst2::MidiInputPort *mp     = static_cast<vst2::MidiInputPort *>(p);
-                mp->deserialize(e);
+                vst2::MidiInputPort *p = vMidiIn.uget(i);
+                if (p != NULL)
+                    p->deserialize(e);
             }
         }
 
@@ -1358,7 +1422,7 @@ namespace lsp
 
         const meta::package_t *Wrapper::package() const
         {
-            return pPackage;
+            return pFactory->manifest();
         }
 
         meta::plugin_format_t Wrapper::plugin_format() const
@@ -1371,6 +1435,11 @@ namespace lsp
             return pSamplePlayer;
         }
 
+        const core::ShmState *Wrapper::shm_state()
+        {
+            return (pShmClient != NULL) ? pShmClient->state() : NULL;
+        }
+
         void Wrapper::request_settings_update()
         {
             bUpdateSettings     = true;
