@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugin-fw
  * Created on: 5 июл. 2021 г.
@@ -62,8 +62,6 @@ namespace lsp
             pPort           = NULL;
 
             nFlags          = 0;
-            fMin            = 0.0f;
-            fMax            = 1.0f;
             fDefault        = 0.0f;
             fStep           = 1.0f;
             fAStep          = 10.0f;
@@ -91,6 +89,9 @@ namespace lsp
                 sScaleBorderColor.init(pWrapper, fdr->scale_border_color());
                 sBalanceColor.init(pWrapper, fdr->balance_color());
 
+                sMin.init(pWrapper, this);
+                sMax.init(pWrapper, this);
+
                 // Bind slots
                 fdr->slots()->bind(tk::SLOT_CHANGE, slot_change, this);
                 fdr->slots()->bind(tk::SLOT_MOUSE_DBL_CLICK, slot_dbl_click, this);
@@ -120,10 +121,16 @@ namespace lsp
                 sBalanceColor.set("balance.color", name, value);
                 sBalanceColor.set("bcolor", name, value);
 
-                if (set_value(&fMin, "min", name, value))
+                if (!strcmp(name, "min"))
+                {
+                    sMin.parse(value);
                     nFlags     |= FF_MIN;
-                if (set_value(&fMax, "max", name, value))
+                }
+                if (!strcmp(name, "max"))
+                {
+                    sMax.parse(value);
                     nFlags     |= FF_MAX;
+                }
                 if (set_value(&fStep, "step", name, value))
                     nFlags     |= FF_STEP;
 
@@ -192,125 +199,26 @@ namespace lsp
         {
             Widget::notify(port, flags);
 
-            if ((port == pPort) && (pPort != NULL))
-                commit_value(pPort->value());
+            size_t k_flags = 0;
+            if (sMin.depends(port))
+                k_flags    |= FF_MIN | FF_VALUE;
+            if (sMax.depends(port))
+                k_flags    |= FF_MAX | FF_VALUE;
+            if ((pPort != NULL) && (port == pPort))
+                k_flags    |= FF_VALUE;
+
+            if (k_flags)
+                commit_value(k_flags);
         }
 
         void Fader::end(ui::UIContext *ctx)
         {
             Widget::end(ctx);
-
-            // Ensure that widget is set
-            tk::Fader *fdr = tk::widget_cast<tk::Fader>(wWidget);
-            if (fdr == NULL)
-                return;
-
-            // Ensure that port is set
-            meta::port_t xp;
-
-            xp.id           = NULL;
-            xp.name         = NULL;
-            xp.unit         = meta::U_NONE;
-            xp.role         = meta::R_CONTROL;
-            xp.flags        = meta::F_LOWER | meta::F_UPPER | meta::F_STEP;
-            xp.min          = 0.0f;
-            xp.max          = 1.0f;
-            xp.start        = 0.0f;
-            xp.step         = 0.01f;
-            xp.items        = NULL;
-            xp.members      = NULL;
-
-            // Ensure that port is set
-            const meta::port_t *p = (pPort != NULL) ? pPort->metadata() : NULL;
-            if (p != NULL)
-                xp          = *p;
-            p           = &xp;
-
-            // Override default values
-            if (nFlags & FF_MIN)
-                xp.min          = fMin;
-            if (nFlags & FF_MAX)
-                xp.max          = fMax;
-            if (nFlags & FF_STEP)
-                xp.step         = fStep;
-            if (nFlags & FF_DFL)
-                xp.start        = fDefault;
-            if (nFlags & FF_LOG_SET)
-                xp.flags        = lsp_setflag(xp.flags, meta::F_LOG, nFlags & FF_LOG);
-            else
-                nFlags          = lsp_setflag(nFlags, FF_LOG, xp.flags & meta::F_LOG);
-
-            float min = 0.0f, max = 1.0f, step = 0.01f, balance = 0.0f;
-
-            if (meta::is_gain_unit(p->unit)) // Decibels
-            {
-                double base     = (p->unit == meta::U_GAIN_AMP) ? 20.0 / M_LN10 : 10.0 / M_LN10;
-
-                min             = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
-                max             = (p->flags & meta::F_UPPER) ? p->max : GAIN_AMP_P_12_DB;
-                float dfl       = (nFlags & FF_BAL_SET) ? fBalance : min;
-
-                step            = base * log((p->flags & meta::F_STEP) ? p->step + 1.0f : 1.01f) * 0.1f;
-                double thresh   = ((p->flags & meta::F_EXT) ? GAIN_AMP_M_140_DB : GAIN_AMP_M_80_DB);
-
-                min             = (fabs(min) < thresh) ? (base * log(thresh) - step) : (base * log(min));
-                max             = (fabs(max) < thresh) ? (base * log(thresh) - step) : (base * log(max));
-                double db_dfl   = (fabs(max) < thresh) ? (base * log(thresh) - step) : (base * log(dfl));
-                balance         = lsp_xlimit(db_dfl, min, max);
-
-                step           *= 10.0f;
-                fDefaultValue   = base * log(p->start);
-            }
-            else if (meta::is_discrete_unit(p->unit)) // Integer type
-            {
-                min             = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
-                max             = (p->unit == meta::U_ENUM) ? min + meta::list_size(p->items) - 1.0f :
-                                  (p->flags & meta::F_UPPER) ? p->max : 1.0f;
-                float dfl       = (nFlags & FF_BAL_SET) ? fBalance : p->min;
-                balance         = lsp_xlimit(dfl, min, max);
-                ssize_t istep   = (p->flags & meta::F_STEP) ? p->step : 1;
-
-                step            = (istep == 0) ? 1.0f : istep;
-                fDefaultValue   = p->start;
-            }
-            else if (meta::is_log_rule(p))  // Float and other values, logarithmic
-            {
-                float xmin      = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
-                float xmax      = (p->flags & meta::F_UPPER) ? p->max : GAIN_AMP_P_12_DB;
-                float xdfl      = (nFlags & FF_BAL_SET) ? fBalance : min;
-                float thresh    = ((p->flags & meta::F_EXT) ? GAIN_AMP_M_140_DB : GAIN_AMP_M_80_DB);
-
-                step            = log((p->flags & meta::F_STEP) ? p->step + 1.0f : 1.01f);
-                min             = (fabs(xmin) < thresh) ? log(thresh) - step : log(xmin);
-                max             = (fabs(xmax) < thresh) ? log(thresh) - step : log(xmax);
-                float dfl       = (fabs(xdfl) < thresh) ? log(thresh) - step : log(xdfl);
-                balance         = lsp_xlimit(dfl, min, max);
-
-                step           *= 10.0f;
-                fDefaultValue = log(p->start);
-            }
-            else // Float and other values, non-logarithmic
-            {
-                min             = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
-                max             = (p->flags & meta::F_UPPER) ? p->max : 1.0f;
-                float dfl       = (nFlags & FF_BAL_SET) ? fBalance : min;
-                balance         = lsp_xlimit(dfl, min, max);
-
-                step            = (p->flags & meta::F_STEP) ? p->step * 10.0f : (max - min) * 0.1f;
-                fDefaultValue   = p->start;
-            }
-
-            // Initialize fader
-            fdr->value()->set_all(fDefaultValue, min, max);
-            fdr->step()->set(step);
-            fdr->balance()->set(balance);
+            commit_value(FF_MIN | FF_MAX | FF_DFL | FF_VALUE);
         }
 
         void Fader::submit_value()
         {
-            if (pPort == NULL)
-                return;
-
             tk::Fader *fdr = tk::widget_cast<tk::Fader>(wWidget);
             if (fdr == NULL)
                 return;
@@ -319,17 +227,20 @@ namespace lsp
             const meta::port_t *p = (pPort != NULL) ? pPort->metadata() : NULL;
             if (p == NULL)
             {
-                pPort->set_value(value);
-                pPort->notify_all(ui::PORT_USER_EDIT);
+                if (pPort != NULL)
+                {
+                    pPort->set_value(value);
+                    pPort->notify_all(ui::PORT_USER_EDIT);
+                }
                 return;
             }
 
             if (is_gain_unit(p->unit)) // Gain
             {
-                double base     = (p->unit == meta::U_GAIN_AMP) ? M_LN10 * 0.05 : M_LN10 * 0.1;
-                value           = exp(value * base);
-                float min       = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
-                if ((min <= 0.0f) && (value < GAIN_AMP_M_80_DB))
+                float base      = (p->unit == meta::U_GAIN_AMP) ? M_LN10 * 0.05 : M_LN10 * 0.1;
+                float thresh    = (p->flags & meta::F_EXT) ? GAIN_AMP_M_140_DB : GAIN_AMP_M_80_DB;
+                value           = expf(value * base);
+                if (value < thresh)
                     value           = 0.0f;
             }
             else if (is_discrete_unit(p->unit)) // Integer type
@@ -338,14 +249,18 @@ namespace lsp
             }
             else if (nFlags & FF_LOG)  // Float and other values, logarithmic
             {
+                double thresh   = (p->flags & meta::F_EXT) ? GAIN_AMP_M_140_DB : GAIN_AMP_M_80_DB;
                 value           = exp(value);
                 float min       = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
-                if ((min <= 0.0f) && (value < log(GAIN_AMP_M_80_DB)))
+                if ((min <= 0.0f) && (value < thresh))
                     value           = 0.0f;
             }
 
-            pPort->set_value(value);
-            pPort->notify_all(ui::PORT_USER_EDIT);
+            if (pPort != NULL)
+            {
+                pPort->set_value(value);
+                pPort->notify_all(ui::PORT_USER_EDIT);
+            }
         }
 
         void Fader::set_default_value()
@@ -385,40 +300,128 @@ namespace lsp
             }
         }
 
-        void Fader::commit_value(float value)
+        void Fader::commit_value(size_t flags)
         {
+            // Ensure that widget is set
             tk::Fader *fdr = tk::widget_cast<tk::Fader>(wWidget);
             if (fdr == NULL)
                 return;
 
+            // Ensure that port is set
+            meta::port_t xp;
+
+            xp.id           = NULL;
+            xp.name         = NULL;
+            xp.unit         = meta::U_NONE;
+            xp.role         = meta::R_CONTROL;
+            xp.flags        = meta::F_LOWER | meta::F_UPPER | meta::F_STEP;
+            xp.min          = 0.0f;
+            xp.max          = 1.0f;
+            xp.start        = 0.0f;
+            xp.step         = 0.01f;
+            xp.items        = NULL;
+            xp.members      = NULL;
+
+            // Ensure that port is set
             const meta::port_t *p = (pPort != NULL) ? pPort->metadata() : NULL;
-            if (p == NULL)
-                return;
+            if (p != NULL)
+                xp          = *p;
+            p           = &xp;
 
-            if (is_gain_unit(p->unit)) // Decibels
+            // Override default values
+            if (nFlags & FF_MIN)
             {
-                double base = (p->unit == meta::U_GAIN_AMP) ? 20.0 / M_LN10 : 10.0 / M_LN10;
-
-                if (value < GAIN_AMP_M_120_DB)
-                    value           = GAIN_AMP_M_120_DB;
-
-                fdr->value()->set(base * log(value));
+                xp.min          = sMin.evaluate_float();
+                xp.flags       |= meta::F_LOWER;
             }
-            else if (is_discrete_unit(p->unit)) // Integer type
+            if (nFlags & FF_MAX)
             {
-                float ov    = truncf(fdr->value()->get());
-                float nv    = truncf(value);
-                if (ov != nv)
-                    fdr->value()->set(nv);
-            }
-            else if (nFlags & FF_LOG)
-            {
-                if (value < GAIN_AMP_M_120_DB)
-                    value           = GAIN_AMP_M_120_DB;
-                fdr->value()->set(log(value));
+                xp.max          = sMax.evaluate_float();
+                xp.flags       |= meta::F_UPPER;
             }
+            if (nFlags & FF_STEP)
+                xp.step         = fStep;
+            if (nFlags & FF_DFL)
+                xp.start        = fDefault;
+            if (nFlags & FF_LOG_SET)
+                xp.flags        = lsp_setflag(xp.flags, meta::F_LOG, nFlags & FF_LOG);
             else
-                fdr->value()->set(value);
+                nFlags          = lsp_setflag(nFlags, FF_LOG, xp.flags & meta::F_LOG);
+
+            float min = 0.0f, max = 1.0f, step = 0.01f, balance = 0.0f;
+            float value     = (pPort != NULL) ? pPort->value() : xp.start;
+
+            if (meta::is_gain_unit(p->unit)) // Decibels
+            {
+                float base      = (p->unit == meta::U_GAIN_AMP) ? 20.0f / M_LN10 : 10.0f / M_LN10;
+
+                min             = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
+                max             = (p->flags & meta::F_UPPER) ? p->max : GAIN_AMP_P_12_DB;
+                float dfl       = (nFlags & FF_BAL_SET) ? fBalance : min;
+
+                step            = base * logf((p->flags & meta::F_STEP) ? p->step + 1.0f : 1.01f) * 0.1f;
+                float thresh    = ((p->flags & meta::F_EXT) ? GAIN_AMP_M_140_DB : GAIN_AMP_M_80_DB);
+
+                min             = (fabsf(min) < thresh)     ? (base * logf(thresh) - step) : (base * logf(min));
+                max             = (fabsf(max) < thresh)     ? (base * logf(thresh) - step) : (base * logf(max));
+                float db_dfl    = (fabsf(max) < thresh)     ? (base * logf(thresh) - step) : (base * logf(dfl));
+                value           = (fabsf(value) < thresh)   ? (base * logf(thresh) - step) : (base * logf(value));
+                balance         = lsp_xlimit(db_dfl, min, max);
+
+                step           *= 10.0f;
+                fDefaultValue   = base * log(p->start);
+            }
+            else if (meta::is_discrete_unit(p->unit)) // Integer type
+            {
+                min             = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
+                max             = (p->unit == meta::U_ENUM) ? min + meta::list_size(p->items) - 1.0f :
+                                  (p->flags & meta::F_UPPER) ? p->max : 1.0f;
+                float dfl       = (nFlags & FF_BAL_SET) ? fBalance : p->min;
+                balance         = lsp_xlimit(dfl, min, max);
+                value           = lsp_xlimit(value, min, max);
+                ssize_t istep   = (p->flags & meta::F_STEP) ? p->step : 1;
+
+                step            = (istep == 0) ? 1.0f : istep;
+                fDefaultValue   = p->start;
+            }
+            else if (meta::is_log_rule(p))  // Float and other values, logarithmic
+            {
+                float xmin      = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
+                float xmax      = (p->flags & meta::F_UPPER) ? p->max : GAIN_AMP_P_12_DB;
+                float xdfl      = (nFlags & FF_BAL_SET) ? fBalance : min;
+                float thresh    = ((p->flags & meta::F_EXT) ? GAIN_AMP_M_140_DB : GAIN_AMP_M_80_DB);
+
+                step            = logf((p->flags & meta::F_STEP) ? p->step + 1.0f : 1.01f);
+                min             = (fabsf(xmin) < thresh)    ? logf(thresh) - step : logf(xmin);
+                max             = (fabsf(xmax) < thresh)    ? logf(thresh) - step : logf(xmax);
+                float dfl       = (fabsf(xdfl) < thresh)    ? logf(thresh) - step : logf(xdfl);
+                value           = (fabsf(value) < thresh)   ? logf(thresh) - step : logf(value);
+                balance         = lsp_xlimit(dfl, min, max);
+
+                step           *= 10.0f;
+                fDefaultValue   = logf(p->start);
+            }
+            else // Float and other values, non-logarithmic
+            {
+                min             = (p->flags & meta::F_LOWER) ? p->min : 0.0f;
+                max             = (p->flags & meta::F_UPPER) ? p->max : 1.0f;
+                float dfl       = (nFlags & FF_BAL_SET) ? fBalance : min;
+                balance         = lsp_xlimit(dfl, min, max);
+                value           = lsp_xlimit(value, min, max);
+
+                step            = (p->flags & meta::F_STEP) ? p->step * 10.0f : (max - min) * 0.1f;
+                fDefaultValue   = p->start;
+            }
+
+            // Initialize fader
+            if (flags & FF_MIN)
+                fdr->value()->set_min(min);
+            if (flags & FF_MAX)
+                fdr->value()->set_max(max);
+            if (flags & FF_VALUE)
+                fdr->value()->set((flags & FF_DFL) ? fDefaultValue : value);
+            fdr->step()->set(step);
+            fdr->balance()->set(balance);
         }
 
         status_t Fader::slot_change(tk::Widget *sender, void *ptr, void *data)
