@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugin-fw
  * Created on: 30 июл. 2021 г.
@@ -61,6 +61,8 @@ namespace lsp
         CTL_FACTORY_IMPL_END(MidiNote);
 
         //-----------------------------------------------------------------
+        const tk::w_class_t MidiNote::PopupWindow::metadata     = { "MidiNote::PopupWindow", &PopupWindow::metadata };
+
         MidiNote::PopupWindow::PopupWindow(MidiNote *label, tk::Display *dpy):
             tk::PopupWindow(dpy),
             sBox(dpy),
@@ -188,6 +190,12 @@ namespace lsp
             return STATUS_OK;
         }
 
+        void MidiNote::destroy()
+        {
+            do_destroy();
+            Widget::destroy();
+        }
+
         void MidiNote::set(ui::UIContext *ctx, const char *name, const char *value)
         {
             tk::Indicator *ind = tk::widget_cast<tk::Indicator>(wWidget);
