@@ -56,7 +56,6 @@ namespace lsp
 
         static const meta::port_t config_metadata[] =
         {
-            SWITCH(UI_MOUNT_STUD_PORT_ID, "Visibility of mount studs in the UI", 1.0f),
             PATH(UI_LAST_VERSION_PORT_ID, "Last version of the product installed"),
             PATH(UI_DLG_SAMPLE_PATH_ID, "Dialog path for selecting sample files"),
             INT_CONTROL_RANGE(UI_DLG_SAMPLE_FTYPE_ID, "Dialog file type for selecting sample files", U_NONE, 0, 100, 0, 1),
@@ -92,6 +91,8 @@ namespace lsp
             SWITCH(UI_GRAPH_DOT_INVERT_VSCROLL_ID, "Invert mouse vertical scroll behaviour for graph dot widget", 0.0f),
             SWITCH(UI_ZOOMABLE_SPECTRUM_GRAPH_ID, "Enables the automatic scaling mode of the frequency graph", 1.0f),
             COMBO(UI_FILTER_POINT_THICK_ID, "Thickness of the filter point", 1.0f, filter_point_thickness_modes),
+            PATH(UI_DOCUMENTATION_PATH_ID, "Path to the local documentation installation"),
+            SWITCH(UI_FILELIST_NAVIGAION_AUTOLOAD_ID, "Automatically load files when navigating over file list", 0.0f),
             PORTS_END
         };
 
@@ -882,26 +883,37 @@ namespace lsp
             c->append_ascii     (config_separator);
             c->append           ('\n');
             c->append_utf8      ("This file contains configuration of the audio plugin.\n");
-            c->fmt_append_utf8  ("  Package:             %s (%s)\n", pkg->artifact, pkg->artifact_name);
-            c->fmt_append_utf8  ("  Package version:     %s\n", pkv.get_utf8());
-            c->fmt_append_utf8  ("  Plugin name:         %s (%s)\n", meta->name, meta->description);
-            c->fmt_append_utf8  ("  Plugin version:      %d.%d.%d\n",
+            c->fmt_append_utf8  ("  Package:                 %s (%s)\n", pkg->artifact, pkg->artifact_name);
+            c->fmt_append_utf8  ("  Package version:         %s\n", pkv.get_utf8());
+            c->fmt_append_utf8  ("  Plugin name:             %s (%s)\n", meta->name, meta->description);
+            c->fmt_append_utf8  ("  Plugin version:          %d.%d.%d\n",
                     int(LSP_MODULE_VERSION_MAJOR(meta->version)),
                     int(LSP_MODULE_VERSION_MINOR(meta->version)),
                     int(LSP_MODULE_VERSION_MICRO(meta->version))
                 );
+
+            char *gst_uid = meta::make_gst_canonical_name(meta->uids.gst);
+            lsp_finally {
+                if (gst_uid != NULL)
+                    free(gst_uid);
+            };
+
             if (meta->uid != NULL)
-                c->fmt_append_utf8   ("  UID:                 %s\n", meta->uid);
-            if (meta->lv2_uri != NULL)
-                c->fmt_append_utf8   ("  LV2 URI:             %s\n", meta->lv2_uri);
-            if (meta->vst2_uid != NULL)
-                c->fmt_append_utf8   ("  VST 2.x identifier:  %s\n", meta->vst2_uid);
-            if (meta->vst3_uid != NULL)
-                c->fmt_append_utf8   ("  VST 3.x identifier:  %s\n", meta::uid_meta_to_vst3(vst3_uid, meta->vst3_uid));
-            if (meta->ladspa_id > 0)
-                c->fmt_append_utf8   ("  LADSPA identifier:   %d\n", meta->ladspa_id);
-            if (meta->ladspa_lbl != NULL)
-                c->fmt_append_utf8   ("  LADSPA label:        %s\n", meta->ladspa_lbl);
+                c->fmt_append_utf8   ("  UID:                     %s\n", meta->uid);
+            if (meta->uids.clap != NULL)
+                c->fmt_append_utf8   ("  CLAP URI:                %s\n", meta->uids.clap);
+            if (gst_uid != NULL)
+                c->fmt_append_utf8   ("  GStreamer identifier:    %s\n", gst_uid);
+            if (meta->uids.ladspa_id > 0)
+                c->fmt_append_utf8   ("  LADSPA identifier:       %d\n", meta->uids.ladspa_id);
+            if (meta->uids.ladspa_lbl != NULL)
+                c->fmt_append_utf8   ("  LADSPA label:            %s\n", meta->uids.ladspa_lbl);
+            if (meta->uids.lv2 != NULL)
+                c->fmt_append_utf8   ("  LV2 URI:                 %s\n", meta->uids.lv2);
+            if (meta->uids.vst2 != NULL)
+                c->fmt_append_utf8   ("  VST 2.x identifier:      %s\n", meta->uids.vst2);
+            if (meta->uids.vst3 != NULL)
+                c->fmt_append_utf8   ("  VST 3.x identifier:      %s\n", meta::uid_meta_to_vst3(vst3_uid, meta->uids.vst3));
             c->append           ('\n');
             c->fmt_append_utf8  ("(C) %s\n", pkg->full_name);
             c->fmt_append_utf8  ("  %s\n", pkg->site);
@@ -941,7 +953,7 @@ namespace lsp
                 const meta::port_t *meta = p->metadata();
                 if (meta == NULL)
                     continue;
-                if (meta::is_out_port(meta))
+                if (!meta::is_in_port(meta))
                     continue;
                 if (!strcmp(meta->id, UI_LAST_VERSION_PORT_ID))
                     continue;
@@ -1620,6 +1632,10 @@ namespace lsp
                 pUI->position_updated(pos);
         }
 
+        void IWrapper::visual_schema_reloaded(const tk::StyleSheet *sheet)
+        {
+        }
+
         bool IWrapper::set_port_value(ui::IPort *port, const config::param_t *param, size_t flags, const io::Path *base)
         {
             // Get metadata
@@ -1677,8 +1693,8 @@ namespace lsp
 
                     lsp_trace("  param = %s, value = %s", param->name.get_utf8(), param->v.str);
 
-                    const char *value = param->v.str;
-                    size_t len      = ::strlen(value);
+                    const char *value   = param->v.str;
+                    size_t len          = ::strlen(value);
                     io::Path path;
 
                     if (core::parse_relative_path(&path, base, value, len))
@@ -1691,6 +1707,22 @@ namespace lsp
                     port->write(value, len, flags);
                     break;
                 }
+                case meta::R_SEND_NAME:
+                case meta::R_RETURN_NAME:
+                case meta::R_STRING:
+                {
+                    // Check type of argument
+                    if (!param->is_string())
+                        return false;
+
+                    lsp_trace("  param = %s, value = %s", param->name.get_utf8(), param->v.str);
+
+                    // Submit string to the port
+                    const char *value   = param->v.str;
+                    const size_t len    = ::strlen(value);
+                    port->write(value, len, flags);
+                    break;
+                }
                 default:
                     return false;
             }
@@ -1797,6 +1829,7 @@ namespace lsp
                         listener->reloaded(sheet);
                 }
             }
+            visual_schema_reloaded(sheet);
 
             return res;
         }
@@ -2008,11 +2041,21 @@ namespace lsp
             return true;
         }
 
+        bool IWrapper::window_resized(tk::Window *wnd, size_t width, size_t height)
+        {
+            return true;
+        }
+
         meta::plugin_format_t IWrapper::plugin_format() const
         {
             return meta::PLUGIN_UNKNOWN;
         }
 
+        const core::ShmState *IWrapper::shm_state()
+        {
+            return NULL;
+        }
+
     } /* namespace ui */
 } /* namespace lsp */
 
