@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_AB_TESTER_VERSION_MAJOR       1
 #define LSP_PLUGINS_AB_TESTER_VERSION_MINOR       0
-#define LSP_PLUGINS_AB_TESTER_VERSION_MICRO       11
+#define LSP_PLUGINS_AB_TESTER_VERSION_MICRO       15
 
 #define LSP_PLUGINS_AB_TESTER_VERSION  \
     LSP_MODULE_VERSION( \
@@ -48,6 +48,7 @@ namespace lsp
 
         #define ABTEST_MONO_CHANNEL(id, label, blind_switch, bte) \
             AUDIO_INPUT("in" id, "Audio input " label), \
+            OPT_RETURN_MONO("ret" id, "rin" id, "Audio return " label), \
             AMP_GAIN100("g" id, "Input gain " label, 1.0), \
             METER_GAIN("ism" id, "Input signal meter " label, GAIN_AMP_P_48_DB), \
             blind_switch(id, label, bte) \
@@ -56,6 +57,7 @@ namespace lsp
         #define ABTEST_STEREO_CHANNEL(id, label, blind_switch, bte) \
             AUDIO_INPUT("in" id "l", "Audio input " label " Left"), \
             AUDIO_INPUT("in" id "r", "Audio input " label " Right"), \
+            OPT_RETURN_STEREO("ret" id, "rin" id, "Audio return " label), \
             AMP_GAIN100("g" id, "Input gain " label, 1.0), \
             METER_GAIN("ism" id "l", "Input signal meter " label " Left", GAIN_AMP_P_48_DB), \
             METER_GAIN("ism" id "r", "Input signal meter " label " Right", GAIN_AMP_P_48_DB), \
@@ -248,14 +250,17 @@ namespace lsp
             "ABP2M",
             &developers::v_sadovnikov,
             "ab_tester_x2_mono",
-            LSP_LV2_URI("ab_tester_x2_mono"),
-            LSP_LV2UI_URI("ab_tester_x2_mono"),
-            "ab2m",
-            LSP_VST3_UID("abp2m   ab2m"),
-            LSP_VST3UI_UID("abp2m   ab2m"),
-            LSP_LADSPA_AB_TESTER_BASE + 0,
-            LSP_LADSPA_URI("ab_tester_x2_mono"),
-            LSP_CLAP_URI("ab_tester_x2_mono"),
+            {
+                LSP_LV2_URI("ab_tester_x2_mono"),
+                LSP_LV2UI_URI("ab_tester_x2_mono"),
+                "ab2m",
+                LSP_VST3_UID("abp2m   ab2m"),
+                LSP_VST3UI_UID("abp2m   ab2m"),
+                LSP_LADSPA_AB_TESTER_BASE + 0,
+                LSP_LADSPA_URI("ab_tester_x2_mono"),
+                LSP_CLAP_URI("ab_tester_x2_mono"),
+                LSP_GST_UID("ab_tester_x2_mono"),
+            },
             LSP_PLUGINS_AB_TESTER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -275,14 +280,17 @@ namespace lsp
             "ABP4M",
             &developers::v_sadovnikov,
             "ab_tester_x4_mono",
-            LSP_LV2_URI("ab_tester_x4_mono"),
-            LSP_LV2UI_URI("ab_tester_x4_mono"),
-            "ab4m",
-            LSP_VST3_UID("abp4m   ab4m"),
-            LSP_VST3UI_UID("abp4m   ab4m"),
-            LSP_LADSPA_AB_TESTER_BASE + 1,
-            LSP_LADSPA_URI("ab_tester_x4_mono"),
-            LSP_CLAP_URI("ab_tester_x4_mono"),
+            {
+                LSP_LV2_URI("ab_tester_x4_mono"),
+                LSP_LV2UI_URI("ab_tester_x4_mono"),
+                "ab4m",
+                LSP_VST3_UID("abp4m   ab4m"),
+                LSP_VST3UI_UID("abp4m   ab4m"),
+                LSP_LADSPA_AB_TESTER_BASE + 1,
+                LSP_LADSPA_URI("ab_tester_x4_mono"),
+                LSP_CLAP_URI("ab_tester_x4_mono"),
+                LSP_GST_UID("ab_tester_x4_mono"),
+            },
             LSP_PLUGINS_AB_TESTER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -302,14 +310,17 @@ namespace lsp
             "ABP8M",
             &developers::v_sadovnikov,
             "ab_tester_x8_mono",
-            LSP_LV2_URI("ab_tester_x8_mono"),
-            LSP_LV2UI_URI("ab_tester_x8_mono"),
-            "ab8m",
-            LSP_VST3_UID("abp8m   ab8m"),
-            LSP_VST3UI_UID("abp8m   ab8m"),
-            LSP_LADSPA_AB_TESTER_BASE + 2,
-            LSP_LADSPA_URI("ab_tester_x8_mono"),
-            LSP_CLAP_URI("ab_tester_x8_mono"),
+            {
+                LSP_LV2_URI("ab_tester_x8_mono"),
+                LSP_LV2UI_URI("ab_tester_x8_mono"),
+                "ab8m",
+                LSP_VST3_UID("abp8m   ab8m"),
+                LSP_VST3UI_UID("abp8m   ab8m"),
+                LSP_LADSPA_AB_TESTER_BASE + 2,
+                LSP_LADSPA_URI("ab_tester_x8_mono"),
+                LSP_CLAP_URI("ab_tester_x8_mono"),
+                LSP_GST_UID("ab_tester_x8_mono"),
+            },
             LSP_PLUGINS_AB_TESTER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -329,14 +340,17 @@ namespace lsp
             "ABP2S",
             &developers::v_sadovnikov,
             "ab_tester_x2_stereo",
-            LSP_LV2_URI("ab_tester_x2_stereo"),
-            LSP_LV2UI_URI("ab_tester_x2_stereo"),
-            "ab2s",
-            LSP_VST3_UID("abp2s   ab2s"),
-            LSP_VST3UI_UID("abp2s   ab2s"),
-            LSP_LADSPA_AB_TESTER_BASE + 3,
-            LSP_LADSPA_URI("ab_tester_x2_stereo"),
-            LSP_CLAP_URI("ab_tester_x2_stereo"),
+            {
+                LSP_LV2_URI("ab_tester_x2_stereo"),
+                LSP_LV2UI_URI("ab_tester_x2_stereo"),
+                "ab2s",
+                LSP_VST3_UID("abp2s   ab2s"),
+                LSP_VST3UI_UID("abp2s   ab2s"),
+                LSP_LADSPA_AB_TESTER_BASE + 3,
+                LSP_LADSPA_URI("ab_tester_x2_stereo"),
+                LSP_CLAP_URI("ab_tester_x2_stereo"),
+                LSP_GST_UID("ab_tester_x2_stereo"),
+            },
             LSP_PLUGINS_AB_TESTER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -356,14 +370,17 @@ namespace lsp
             "ABP4S",
             &developers::v_sadovnikov,
             "ab_tester_x4_stereo",
-            LSP_LV2_URI("ab_tester_x4_stereo"),
-            LSP_LV2UI_URI("ab_tester_x4_stereo"),
-            "ab4s",
-            LSP_VST3_UID("abp4s   ab4s"),
-            LSP_VST3UI_UID("abp4s   ab4s"),
-            LSP_LADSPA_AB_TESTER_BASE + 4,
-            LSP_LADSPA_URI("ab_tester_x4_stereo"),
-            LSP_CLAP_URI("ab_tester_x4_stereo"),
+            {
+                LSP_LV2_URI("ab_tester_x4_stereo"),
+                LSP_LV2UI_URI("ab_tester_x4_stereo"),
+                "ab4s",
+                LSP_VST3_UID("abp4s   ab4s"),
+                LSP_VST3UI_UID("abp4s   ab4s"),
+                LSP_LADSPA_AB_TESTER_BASE + 4,
+                LSP_LADSPA_URI("ab_tester_x4_stereo"),
+                LSP_CLAP_URI("ab_tester_x4_stereo"),
+                LSP_GST_UID("ab_tester_x4_stereo"),
+            },
             LSP_PLUGINS_AB_TESTER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -383,14 +400,17 @@ namespace lsp
             "ABP8S",
             &developers::v_sadovnikov,
             "ab_tester_x8_stereo",
-            LSP_LV2_URI("ab_tester_x8_stereo"),
-            LSP_LV2UI_URI("ab_tester_x8_stereo"),
-            "ab8s",
-            LSP_VST3_UID("abp8s   ab8s"),
-            LSP_VST3UI_UID("abp8s   ab8s"),
-            LSP_LADSPA_AB_TESTER_BASE + 5,
-            LSP_LADSPA_URI("ab_tester_x8_stereo"),
-            LSP_CLAP_URI("ab_tester_x8_stereo"),
+            {
+                LSP_LV2_URI("ab_tester_x8_stereo"),
+                LSP_LV2UI_URI("ab_tester_x8_stereo"),
+                "ab8s",
+                LSP_VST3_UID("abp8s   ab8s"),
+                LSP_VST3UI_UID("abp8s   ab8s"),
+                LSP_LADSPA_AB_TESTER_BASE + 5,
+                LSP_LADSPA_URI("ab_tester_x8_stereo"),
+                LSP_CLAP_URI("ab_tester_x8_stereo"),
+                LSP_GST_UID("ab_tester_x8_stereo"),
+            },
             LSP_PLUGINS_AB_TESTER_VERSION,
             plugin_classes,
             clap_features_stereo,
