@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_DYNA_PROCESSOR_VERSION_MAJOR       1
 #define LSP_PLUGINS_DYNA_PROCESSOR_VERSION_MINOR       0
-#define LSP_PLUGINS_DYNA_PROCESSOR_VERSION_MICRO       23
+#define LSP_PLUGINS_DYNA_PROCESSOR_VERSION_MICRO       27
 
 #define LSP_PLUGINS_DYNA_PROCESSOR_VERSION  \
     LSP_MODULE_VERSION( \
@@ -83,6 +83,7 @@ namespace lsp
         {
             { "Feed-forward",   "sidechain.feed_forward"    },
             { "Feed-back",      "sidechain.feed_back"       },
+            { "Link",           "sidechain.link" },
             { NULL, NULL }
         };
 
@@ -91,6 +92,7 @@ namespace lsp
             { "Feed-forward",   "sidechain.feed_forward"    },
             { "Feed-back",      "sidechain.feed_back"       },
             { "External",       "sidechain.external"        },
+            { "Link",           "sidechain.link" },
             { NULL, NULL }
         };
 
@@ -137,6 +139,12 @@ namespace lsp
             SWITCH("ssplit", "Stereo split", 0.0f), \
             COMBO("sscs", "Split sidechain source", dyna_processor_metadata::SC_SPLIT_SOURCE_DFL, dyna_proc_sc_split_sources)
 
+        #define DYNA_PROC_SHM_LINK_MONO \
+            OPT_RETURN_MONO("link", "shml", "Side-chain shared memory link")
+
+        #define DYNA_PROC_SHM_LINK_STEREO \
+            OPT_RETURN_STEREO("link", "shml_", "Side-chain shared memory link")
+
         #define DYNA_PROC_SC_MONO_CHANNEL(sct) \
             COMBO("sct", "Sidechain type", dyna_processor_metadata::SC_TYPE_DFL, sct), \
             COMBO("scm", "Sidechain mode", dyna_processor_metadata::SC_MODE_DFL, dyna_proc_sc_modes), \
@@ -213,6 +221,7 @@ namespace lsp
         static const port_t dyna_processor_mono_ports[] =
         {
             PORTS_MONO_PLUGIN,
+            DYNA_PROC_SHM_LINK_MONO,
             DYNA_PROC_COMMON,
             DYNA_PROC_SC_MONO_CHANNEL(dyna_proc_sc_type),
             DYNA_PROC_CHANNEL("", ""),
@@ -224,6 +233,7 @@ namespace lsp
         static const port_t dyna_processor_stereo_ports[] =
         {
             PORTS_STEREO_PLUGIN,
+            DYNA_PROC_SHM_LINK_STEREO,
             DYNA_PROC_COMMON,
             DYNA_PROC_SPLIT_COMMON,
             DYNA_PROC_SC_STEREO_CHANNEL("", "", dyna_proc_sc_type),
@@ -237,6 +247,7 @@ namespace lsp
         static const port_t dyna_processor_lr_ports[] =
         {
             PORTS_STEREO_PLUGIN,
+            DYNA_PROC_SHM_LINK_STEREO,
             DYNA_PROC_LR_COMMON,
             DYNA_PROC_SC_STEREO_CHANNEL("_l", " Left", dyna_proc_sc_type),
             DYNA_PROC_SC_STEREO_CHANNEL("_r", " Right", dyna_proc_sc_type),
@@ -251,6 +262,7 @@ namespace lsp
         static const port_t dyna_processor_ms_ports[] =
         {
             PORTS_STEREO_PLUGIN,
+            DYNA_PROC_SHM_LINK_STEREO,
             DYNA_PROC_MS_COMMON,
             DYNA_PROC_SC_STEREO_CHANNEL("_m", " Mid", dyna_proc_sc_type),
             DYNA_PROC_SC_STEREO_CHANNEL("_s", " Side", dyna_proc_sc_type),
@@ -266,6 +278,7 @@ namespace lsp
         {
             PORTS_MONO_PLUGIN,
             PORTS_MONO_SIDECHAIN,
+            DYNA_PROC_SHM_LINK_MONO,
             DYNA_PROC_COMMON,
             DYNA_PROC_SC_MONO_CHANNEL(dyna_proc_extsc_type),
             DYNA_PROC_CHANNEL("", ""),
@@ -278,6 +291,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             PORTS_STEREO_SIDECHAIN,
+            DYNA_PROC_SHM_LINK_STEREO,
             DYNA_PROC_COMMON,
             DYNA_PROC_SPLIT_COMMON,
             DYNA_PROC_SC_STEREO_CHANNEL("", "", dyna_proc_extsc_type),
@@ -292,6 +306,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             PORTS_STEREO_SIDECHAIN,
+            DYNA_PROC_SHM_LINK_STEREO,
             DYNA_PROC_LR_COMMON,
             DYNA_PROC_SC_STEREO_CHANNEL("_l", " Left", dyna_proc_extsc_type),
             DYNA_PROC_SC_STEREO_CHANNEL("_r", " Right", dyna_proc_extsc_type),
@@ -307,6 +322,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             PORTS_STEREO_SIDECHAIN,
+            DYNA_PROC_SHM_LINK_STEREO,
             DYNA_PROC_MS_COMMON,
             DYNA_PROC_SC_STEREO_CHANNEL("_m", " Mid", dyna_proc_extsc_type),
             DYNA_PROC_SC_STEREO_CHANNEL("_s", " Side", dyna_proc_extsc_type),
@@ -336,14 +352,17 @@ namespace lsp
             "DP1M",
             &developers::v_sadovnikov,
             "dyna_processor_mono",
-            LSP_LV2_URI("dyna_processor_mono"),
-            LSP_LV2UI_URI("dyna_processor_mono"),
-            "lqpm",
-            LSP_VST3_UID("dp1m    lqpm"),
-            LSP_VST3UI_UID("dp1m    lqpm"),
-            LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 0,
-            LSP_LADSPA_URI("dyna_processor_mono"),
-            LSP_CLAP_URI("dyna_processor_mono"),
+            {
+                LSP_LV2_URI("dyna_processor_mono"),
+                LSP_LV2UI_URI("dyna_processor_mono"),
+                "lqpm",
+                LSP_VST3_UID("dp1m    lqpm"),
+                LSP_VST3UI_UID("dp1m    lqpm"),
+                LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 0,
+                LSP_LADSPA_URI("dyna_processor_mono"),
+                LSP_CLAP_URI("dyna_processor_mono"),
+                LSP_GST_UID("dyna_processor_mono"),
+            },
             LSP_PLUGINS_DYNA_PROCESSOR_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -363,14 +382,17 @@ namespace lsp
             "DP1S",
             &developers::v_sadovnikov,
             "dyna_processor_stereo",
-            LSP_LV2_URI("dyna_processor_stereo"),
-            LSP_LV2UI_URI("dyna_processor_stereo"),
-            "aat9",
-            LSP_VST3_UID("dp1s    aat9"),
-            LSP_VST3UI_UID("dp1s    aat9"),
-            LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 1,
-            LSP_LADSPA_URI("dyna_processor_stereo"),
-            LSP_CLAP_URI("dyna_processor_stereo"),
+            {
+                LSP_LV2_URI("dyna_processor_stereo"),
+                LSP_LV2UI_URI("dyna_processor_stereo"),
+                "aat9",
+                LSP_VST3_UID("dp1s    aat9"),
+                LSP_VST3UI_UID("dp1s    aat9"),
+                LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 1,
+                LSP_LADSPA_URI("dyna_processor_stereo"),
+                LSP_CLAP_URI("dyna_processor_stereo"),
+                LSP_GST_UID("dyna_processor_stereo"),
+            },
             LSP_PLUGINS_DYNA_PROCESSOR_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -390,14 +412,17 @@ namespace lsp
             "DP1LR",
             &developers::v_sadovnikov,
             "dyna_processor_lr",
-            LSP_LV2_URI("dyna_processor_lr"),
-            LSP_LV2UI_URI("dyna_processor_lr"),
-            "hl9g",
-            LSP_VST3_UID("dp1lr   hl9g"),
-            LSP_VST3UI_UID("dp1lr   hl9g"),
-            LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 2,
-            LSP_LADSPA_URI("dyna_processor_lr"),
-            LSP_CLAP_URI("dyna_processor_lr"),
+            {
+                LSP_LV2_URI("dyna_processor_lr"),
+                LSP_LV2UI_URI("dyna_processor_lr"),
+                "hl9g",
+                LSP_VST3_UID("dp1lr   hl9g"),
+                LSP_VST3UI_UID("dp1lr   hl9g"),
+                LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 2,
+                LSP_LADSPA_URI("dyna_processor_lr"),
+                LSP_CLAP_URI("dyna_processor_lr"),
+                LSP_GST_UID("dyna_processor_lr"),
+            },
             LSP_PLUGINS_DYNA_PROCESSOR_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -417,14 +442,17 @@ namespace lsp
             "DP1MS",
             &developers::v_sadovnikov,
             "dyna_processor_ms",
-            LSP_LV2_URI("dyna_processor_ms"),
-            LSP_LV2UI_URI("dyna_processor_ms"),
-            "uvrg",
-            LSP_VST3_UID("dp1ms   uvrg"),
-            LSP_VST3UI_UID("dp1ms   uvrg"),
-            LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 3,
-            LSP_LADSPA_URI("dyna_processor_ms"),
-            LSP_CLAP_URI("dyna_processor_ms"),
+            {
+                LSP_LV2_URI("dyna_processor_ms"),
+                LSP_LV2UI_URI("dyna_processor_ms"),
+                "uvrg",
+                LSP_VST3_UID("dp1ms   uvrg"),
+                LSP_VST3UI_UID("dp1ms   uvrg"),
+                LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 3,
+                LSP_LADSPA_URI("dyna_processor_ms"),
+                LSP_CLAP_URI("dyna_processor_ms"),
+                LSP_GST_UID("dyna_processor_ms"),
+            },
             LSP_PLUGINS_DYNA_PROCESSOR_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -445,14 +473,17 @@ namespace lsp
             "SCDP1M",
             &developers::v_sadovnikov,
             "sc_dyna_processor_mono",
-            LSP_LV2_URI("sc_dyna_processor_mono"),
-            LSP_LV2UI_URI("sc_dyna_processor_mono"),
-            "apkx",
-            LSP_VST3_UID("scdp1m  apkx"),
-            LSP_VST3UI_UID("scdp1m  apkx"),
-            LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 4,
-            LSP_LADSPA_URI("sc_dyna_processor_mono"),
-            LSP_CLAP_URI("sc_dyna_processor_mono"),
+            {
+                LSP_LV2_URI("sc_dyna_processor_mono"),
+                LSP_LV2UI_URI("sc_dyna_processor_mono"),
+                "apkx",
+                LSP_VST3_UID("scdp1m  apkx"),
+                LSP_VST3UI_UID("scdp1m  apkx"),
+                LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 4,
+                LSP_LADSPA_URI("sc_dyna_processor_mono"),
+                LSP_CLAP_URI("sc_dyna_processor_mono"),
+                LSP_GST_UID("sc_dyna_processor_mono"),
+            },
             LSP_PLUGINS_DYNA_PROCESSOR_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -472,14 +503,17 @@ namespace lsp
             "SCDP1S",
             &developers::v_sadovnikov,
             "sc_dyna_processor_stereo",
-            LSP_LV2_URI("sc_dyna_processor_stereo"),
-            LSP_LV2UI_URI("sc_dyna_processor_stereo"),
-            "fqne",
-            LSP_VST3_UID("scdp1s  fqne"),
-            LSP_VST3UI_UID("scdp1s  fqne"),
-            LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 5,
-            LSP_LADSPA_URI("sc_dyna_processor_stereo"),
-            LSP_CLAP_URI("sc_dyna_processor_stereo"),
+            {
+                LSP_LV2_URI("sc_dyna_processor_stereo"),
+                LSP_LV2UI_URI("sc_dyna_processor_stereo"),
+                "fqne",
+                LSP_VST3_UID("scdp1s  fqne"),
+                LSP_VST3UI_UID("scdp1s  fqne"),
+                LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 5,
+                LSP_LADSPA_URI("sc_dyna_processor_stereo"),
+                LSP_CLAP_URI("sc_dyna_processor_stereo"),
+                LSP_GST_UID("sc_dyna_processor_stereo"),
+            },
             LSP_PLUGINS_DYNA_PROCESSOR_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -499,14 +533,17 @@ namespace lsp
             "SCDP1LR",
             &developers::v_sadovnikov,
             "sc_dyna_processor_lr",
-            LSP_LV2_URI("sc_dyna_processor_lr"),
-            LSP_LV2UI_URI("sc_dyna_processor_lr"),
-            "sxmi",
-            LSP_VST3_UID("scdp1lr sxmi"),
-            LSP_VST3UI_UID("scdp1lr sxmi"),
-            LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 6,
-            LSP_LADSPA_URI("sc_dyna_processor_lr"),
-            LSP_CLAP_URI("sc_dyna_processor_lr"),
+            {
+                LSP_LV2_URI("sc_dyna_processor_lr"),
+                LSP_LV2UI_URI("sc_dyna_processor_lr"),
+                "sxmi",
+                LSP_VST3_UID("scdp1lr sxmi"),
+                LSP_VST3UI_UID("scdp1lr sxmi"),
+                LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 6,
+                LSP_LADSPA_URI("sc_dyna_processor_lr"),
+                LSP_CLAP_URI("sc_dyna_processor_lr"),
+                LSP_GST_UID("sc_dyna_processor_lr"),
+            },
             LSP_PLUGINS_DYNA_PROCESSOR_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -526,14 +563,17 @@ namespace lsp
             "SCDP1MS",
             &developers::v_sadovnikov,
             "sc_dyna_processor_ms",
-            LSP_LV2_URI("sc_dyna_processor_ms"),
-            LSP_LV2UI_URI("sc_dyna_processor_ms"),
-            "fcj9",
-            LSP_VST3_UID("scdp1ms fcj9"),
-            LSP_VST3UI_UID("scdp1ms fcj9"),
-            LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 7,
-            LSP_LADSPA_URI("sc_dyna_processor_ms"),
-            LSP_CLAP_URI("sc_dyna_processor_ms"),
+            {
+                LSP_LV2_URI("sc_dyna_processor_ms"),
+                LSP_LV2UI_URI("sc_dyna_processor_ms"),
+                "fcj9",
+                LSP_VST3_UID("scdp1ms fcj9"),
+                LSP_VST3UI_UID("scdp1ms fcj9"),
+                LSP_LADSPA_DYNAMIC_PROCESSOR_BASE + 7,
+                LSP_LADSPA_URI("sc_dyna_processor_ms"),
+                LSP_CLAP_URI("sc_dyna_processor_ms"),
+                LSP_GST_UID("sc_dyna_processor_ms"),
+            },
             LSP_PLUGINS_DYNA_PROCESSOR_VERSION,
             plugin_classes,
             clap_features_stereo,
