@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_FLANGER_VERSION_MAJOR       1
 #define LSP_PLUGINS_FLANGER_VERSION_MINOR       0
-#define LSP_PLUGINS_FLANGER_VERSION_MICRO       8
+#define LSP_PLUGINS_FLANGER_VERSION_MICRO       12
 
 #define LSP_PLUGINS_FLANGER_VERSION  \
     LSP_MODULE_VERSION( \
@@ -226,14 +226,17 @@ namespace lsp
             "F1M",
             &developers::v_sadovnikov,
             "flanger_mono",
-            LSP_LV2_URI("flanger_mono"),
-            LSP_LV2UI_URI("flanger_mono"),
-            "lf1m",
-            LSP_VST3_UID("f1m     lf1m"),
-            LSP_VST3UI_UID("f1m     lf1m"),
-            LSP_LADSPA_FLANGER_BASE + 0,
-            LSP_LADSPA_URI("flanger_mono"),
-            LSP_CLAP_URI("flanger_mono"),
+            {
+                LSP_LV2_URI("flanger_mono"),
+                LSP_LV2UI_URI("flanger_mono"),
+                "lf1m",
+                LSP_VST3_UID("f1m     lf1m"),
+                LSP_VST3UI_UID("f1m     lf1m"),
+                LSP_LADSPA_FLANGER_BASE + 0,
+                LSP_LADSPA_URI("flanger_mono"),
+                LSP_CLAP_URI("flanger_mono"),
+                LSP_GST_UID("flanger_mono"),
+            },
             LSP_PLUGINS_FLANGER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -253,14 +256,17 @@ namespace lsp
             "F1S",
             &developers::v_sadovnikov,
             "flanger_stereo",
-            LSP_LV2_URI("flanger_stereo"),
-            LSP_LV2UI_URI("flanger_stereo"),
-            "lf1s",
-            LSP_VST3_UID("f1s     lf1s"),
-            LSP_VST3UI_UID("f1s     lf1s"),
-            LSP_LADSPA_FLANGER_BASE + 1,
-            LSP_LADSPA_URI("flanger_stereo"),
-            LSP_CLAP_URI("flanger_stereo"),
+            {
+                LSP_LV2_URI("flanger_stereo"),
+                LSP_LV2UI_URI("flanger_stereo"),
+                "lf1s",
+                LSP_VST3_UID("f1s     lf1s"),
+                LSP_VST3UI_UID("f1s     lf1s"),
+                LSP_LADSPA_FLANGER_BASE + 1,
+                LSP_LADSPA_URI("flanger_stereo"),
+                LSP_CLAP_URI("flanger_stereo"),
+                LSP_GST_UID("flanger_stereo"),
+            },
             LSP_PLUGINS_FLANGER_VERSION,
             plugin_classes,
             clap_features_stereo,
