@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION_MAJOR       1
 #define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION_MINOR       0
-#define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION_MICRO       23
+#define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION_MICRO       27
 
 #define LSP_PLUGINS_GRAPH_EQUALIZER_VERSION  \
     LSP_MODULE_VERSION( \
@@ -175,11 +175,27 @@ namespace lsp
         #define BAND_SELECT(fselect) \
             COMBO("fsel", "Band select", 0, fselect)
 
+        #define EQ_COMMUNICATION_MONO \
+            OPT_SEND_NAME("send", "Audio send"), \
+            OPT_AUDIO_SEND("snd", "Audio send output", 0, "send"), \
+            OPT_RETURN_NAME("return", "Audio return"), \
+            OPT_AUDIO_RETURN("rtn", "Audio return input", 0, "return")
+
+        #define EQ_COMMUNICATION_STEREO \
+            OPT_SEND_NAME("send", "Audio send"), \
+            OPT_AUDIO_SEND("snd_l", "Audio send output left", 0, "send"), \
+            OPT_AUDIO_SEND("snd_r", "Audio send output right", 1, "send"), \
+            OPT_RETURN_NAME("return", "Audio return"), \
+            OPT_AUDIO_RETURN("rtn_l", "Audio return input left", 0, "return"), \
+            OPT_AUDIO_RETURN("rtn_r", "Audio return input right", 1, "return")
+
         #define CHANNEL_ANALYSIS(id, label) \
             SWITCH("ife" id, "Input FFT graph enable" label, 1.0f), \
             SWITCH("ofe" id, "Output FFT graph enable" label, 1.0f), \
+            SWITCH("rfe" id, "Return FFT graph enable" label, 1.0f), \
             MESH("ifg" id, "Input FFT graph" label, 2, graph_equalizer_metadata::MESH_POINTS + 2), \
-            MESH("ofg" id, "Output FFT graph" label, 2, graph_equalizer_metadata::MESH_POINTS)
+            MESH("ofg" id, "Output FFT graph" label, 2, graph_equalizer_metadata::MESH_POINTS), \
+            MESH("rfg" id, "Return FFT graph" label, 2, graph_equalizer_metadata::MESH_POINTS)
 
         #define EQ_BANDS_32X(band) \
             band(0, "16"), \
@@ -237,6 +253,7 @@ namespace lsp
         {
             PORTS_MONO_PLUGIN,
             EQ_COMMON,
+            EQ_COMMUNICATION_MONO,
             CHANNEL_ANALYSIS("", ""),
             EQ_MONO_PORTS,
             EQ_BANDS_16X(EQ_BAND_MONO),
@@ -248,6 +265,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON,
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             EQ_STEREO_PORTS,
@@ -260,6 +278,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON,
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             BAND_SELECT(band_select_16lr),
@@ -273,6 +292,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON,
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_m", " Mid"),
             CHANNEL_ANALYSIS("_s", " Side"),
             BAND_SELECT(band_select_16ms),
@@ -286,6 +306,7 @@ namespace lsp
         {
             PORTS_MONO_PLUGIN,
             EQ_COMMON,
+            EQ_COMMUNICATION_MONO,
             CHANNEL_ANALYSIS("", ""),
             BAND_SELECT(band_select_32),
             EQ_MONO_PORTS,
@@ -298,6 +319,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON,
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             BAND_SELECT(band_select_32),
@@ -311,6 +333,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON,
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             BAND_SELECT(band_select_32lr),
@@ -324,6 +347,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON,
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_m", " Mid"),
             CHANNEL_ANALYSIS("_s", " Side"),
             BAND_SELECT(band_select_32ms),
@@ -350,14 +374,17 @@ namespace lsp
             "GE16M",
             &developers::v_sadovnikov,
             "graph_equalizer_x16_mono",
-            LSP_LV2_URI("graph_equalizer_x16_mono"),
-            LSP_LV2UI_URI("graph_equalizer_x16_mono"),
-            "rvwk",
-            LSP_VST3_UID("ge16m   rvwk"),
-            LSP_VST3UI_UID("ge16m   rvwk"),
-            LSP_LADSPA_GRAPH_EQUALIZER_BASE + 0,
-            LSP_LADSPA_URI("graph_equalizer_x16_mono"),
-            LSP_CLAP_URI("graph_equalizer_x16_mono"),
+            {
+                LSP_LV2_URI("graph_equalizer_x16_mono"),
+                LSP_LV2UI_URI("graph_equalizer_x16_mono"),
+                "rvwk",
+                LSP_VST3_UID("ge16m   rvwk"),
+                LSP_VST3UI_UID("ge16m   rvwk"),
+                LSP_LADSPA_GRAPH_EQUALIZER_BASE + 0,
+                LSP_LADSPA_URI("graph_equalizer_x16_mono"),
+                LSP_CLAP_URI("graph_equalizer_x16_mono"),
+                LSP_GST_UID("graph_equalizer_x16_mono"),
+            },
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -377,14 +404,17 @@ namespace lsp
             "GE32M",
             &developers::v_sadovnikov,
             "graph_equalizer_x32_mono",
-            LSP_LV2_URI("graph_equalizer_x32_mono"),
-            LSP_LV2UI_URI("graph_equalizer_x32_mono"),
-            "vnca",
-            LSP_VST3_UID("ge32m   vnca"),
-            LSP_VST3UI_UID("ge32m   vnca"),
-            LSP_LADSPA_GRAPH_EQUALIZER_BASE + 1,
-            LSP_LADSPA_URI("graph_equalizer_x32_mono"),
-            LSP_CLAP_URI("graph_equalizer_x32_mono"),
+            {
+                LSP_LV2_URI("graph_equalizer_x32_mono"),
+                LSP_LV2UI_URI("graph_equalizer_x32_mono"),
+                "vnca",
+                LSP_VST3_UID("ge32m   vnca"),
+                LSP_VST3UI_UID("ge32m   vnca"),
+                LSP_LADSPA_GRAPH_EQUALIZER_BASE + 1,
+                LSP_LADSPA_URI("graph_equalizer_x32_mono"),
+                LSP_CLAP_URI("graph_equalizer_x32_mono"),
+                LSP_GST_UID("graph_equalizer_x32_mono"),
+            },
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -404,14 +434,17 @@ namespace lsp
             "GE16S",
             &developers::v_sadovnikov,
             "graph_equalizer_x16_stereo",
-            LSP_LV2_URI("graph_equalizer_x16_stereo"),
-            LSP_LV2UI_URI("graph_equalizer_x16_stereo"),
-            "argl",
-            LSP_VST3_UID("ge16s   argl"),
-            LSP_VST3UI_UID("ge16s   argl"),
-            LSP_LADSPA_GRAPH_EQUALIZER_BASE + 2,
-            LSP_LADSPA_URI("graph_equalizer_x16_stereo"),
-            LSP_CLAP_URI("graph_equalizer_x16_stereo"),
+            {
+                LSP_LV2_URI("graph_equalizer_x16_stereo"),
+                LSP_LV2UI_URI("graph_equalizer_x16_stereo"),
+                "argl",
+                LSP_VST3_UID("ge16s   argl"),
+                LSP_VST3UI_UID("ge16s   argl"),
+                LSP_LADSPA_GRAPH_EQUALIZER_BASE + 2,
+                LSP_LADSPA_URI("graph_equalizer_x16_stereo"),
+                LSP_CLAP_URI("graph_equalizer_x16_stereo"),
+                LSP_GST_UID("graph_equalizer_x16_stereo"),
+            },
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -431,14 +464,17 @@ namespace lsp
             "GE32S",
             &developers::v_sadovnikov,
             "graph_equalizer_x32_stereo",
-            LSP_LV2_URI("graph_equalizer_x32_stereo"),
-            LSP_LV2UI_URI("graph_equalizer_x32_stereo"),
-            "nvsd",
-            LSP_VST3_UID("ge32s   nvsd"),
-            LSP_VST3UI_UID("ge32s   nvsd"),
-            LSP_LADSPA_GRAPH_EQUALIZER_BASE + 3,
-            LSP_LADSPA_URI("graph_equalizer_x32_stereo"),
-            LSP_CLAP_URI("graph_equalizer_x32_stereo"),
+            {
+                LSP_LV2_URI("graph_equalizer_x32_stereo"),
+                LSP_LV2UI_URI("graph_equalizer_x32_stereo"),
+                "nvsd",
+                LSP_VST3_UID("ge32s   nvsd"),
+                LSP_VST3UI_UID("ge32s   nvsd"),
+                LSP_LADSPA_GRAPH_EQUALIZER_BASE + 3,
+                LSP_LADSPA_URI("graph_equalizer_x32_stereo"),
+                LSP_CLAP_URI("graph_equalizer_x32_stereo"),
+                LSP_GST_UID("graph_equalizer_x32_stereo"),
+            },
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -458,14 +494,17 @@ namespace lsp
             "GE16LR",
             &developers::v_sadovnikov,
             "graph_equalizer_x16_lr",
-            LSP_LV2_URI("graph_equalizer_x16_lr"),
-            LSP_LV2UI_URI("graph_equalizer_x16_lr"),
-            "zefi",
-            LSP_VST3_UID("ge16lr  zefi"),
-            LSP_VST3UI_UID("ge16lr  zefi"),
-            LSP_LADSPA_GRAPH_EQUALIZER_BASE + 4,
-            LSP_LADSPA_URI("graph_equalizer_x16_lr"),
-            LSP_CLAP_URI("graph_equalizer_x16_lr"),
+            {
+                LSP_LV2_URI("graph_equalizer_x16_lr"),
+                LSP_LV2UI_URI("graph_equalizer_x16_lr"),
+                "zefi",
+                LSP_VST3_UID("ge16lr  zefi"),
+                LSP_VST3UI_UID("ge16lr  zefi"),
+                LSP_LADSPA_GRAPH_EQUALIZER_BASE + 4,
+                LSP_LADSPA_URI("graph_equalizer_x16_lr"),
+                LSP_CLAP_URI("graph_equalizer_x16_lr"),
+                LSP_GST_UID("graph_equalizer_x16_lr"),
+            },
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -485,14 +524,17 @@ namespace lsp
             "GE32LR",
             &developers::v_sadovnikov,
             "graph_equalizer_x32_lr",
-            LSP_LV2_URI("graph_equalizer_x32_lr"),
-            LSP_LV2UI_URI("graph_equalizer_x32_lr"),
-            "0heu",
-            LSP_VST3_UID("ge32lr  0heu"),
-            LSP_VST3UI_UID("ge32lr  0heu"),
-            LSP_LADSPA_GRAPH_EQUALIZER_BASE + 5,
-            LSP_LADSPA_URI("graph_equalizer_x32_lr"),
-            LSP_CLAP_URI("graph_equalizer_x32_lr"),
+            {
+                LSP_LV2_URI("graph_equalizer_x32_lr"),
+                LSP_LV2UI_URI("graph_equalizer_x32_lr"),
+                "0heu",
+                LSP_VST3_UID("ge32lr  0heu"),
+                LSP_VST3UI_UID("ge32lr  0heu"),
+                LSP_LADSPA_GRAPH_EQUALIZER_BASE + 5,
+                LSP_LADSPA_URI("graph_equalizer_x32_lr"),
+                LSP_CLAP_URI("graph_equalizer_x32_lr"),
+                LSP_GST_UID("graph_equalizer_x32_lr"),
+            },
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -512,14 +554,17 @@ namespace lsp
             "GE16MS",
             &developers::v_sadovnikov,
             "graph_equalizer_x16_ms",
-            LSP_LV2_URI("graph_equalizer_x16_ms"),
-            LSP_LV2UI_URI("graph_equalizer_x16_ms"),
-            "woys",
-            LSP_VST3_UID("ge16ms  woys"),
-            LSP_VST3UI_UID("ge16ms  woys"),
-            LSP_LADSPA_GRAPH_EQUALIZER_BASE + 6,
-            LSP_LADSPA_URI("graph_equalizer_x16_ms"),
-            LSP_CLAP_URI("graph_equalizer_x16_ms"),
+            {
+                LSP_LV2_URI("graph_equalizer_x16_ms"),
+                LSP_LV2UI_URI("graph_equalizer_x16_ms"),
+                "woys",
+                LSP_VST3_UID("ge16ms  woys"),
+                LSP_VST3UI_UID("ge16ms  woys"),
+                LSP_LADSPA_GRAPH_EQUALIZER_BASE + 6,
+                LSP_LADSPA_URI("graph_equalizer_x16_ms"),
+                LSP_CLAP_URI("graph_equalizer_x16_ms"),
+                LSP_GST_UID("graph_equalizer_x16_ms"),
+            },
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -539,14 +584,17 @@ namespace lsp
             "GE32MS",
             &developers::v_sadovnikov,
             "graph_equalizer_x32_ms",
-            LSP_LV2_URI("graph_equalizer_x32_ms"),
-            LSP_LV2UI_URI("graph_equalizer_x32_ms"),
-            "ku8j",
-            LSP_VST3_UID("ge32ms  ku8j"),
-            LSP_VST3UI_UID("ge32ms  ku8j"),
-            LSP_LADSPA_GRAPH_EQUALIZER_BASE + 7,
-            LSP_LADSPA_URI("graph_equalizer_x32_ms"),
-            LSP_CLAP_URI("graph_equalizer_x32_ms"),
+            {
+                LSP_LV2_URI("graph_equalizer_x32_ms"),
+                LSP_LV2UI_URI("graph_equalizer_x32_ms"),
+                "ku8j",
+                LSP_VST3_UID("ge32ms  ku8j"),
+                LSP_VST3UI_UID("ge32ms  ku8j"),
+                LSP_LADSPA_GRAPH_EQUALIZER_BASE + 7,
+                LSP_LADSPA_URI("graph_equalizer_x32_ms"),
+                LSP_CLAP_URI("graph_equalizer_x32_ms"),
+                LSP_GST_UID("graph_equalizer_x32_ms"),
+            },
             LSP_PLUGINS_GRAPH_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
