@@ -27,7 +27,7 @@
 
 #define LSP_PLUGINS_IMPULSE_RESPONSES_VERSION_MAJOR       1
 #define LSP_PLUGINS_IMPULSE_RESPONSES_VERSION_MINOR       0
-#define LSP_PLUGINS_IMPULSE_RESPONSES_VERSION_MICRO       23
+#define LSP_PLUGINS_IMPULSE_RESPONSES_VERSION_MICRO       27
 
 #define LSP_PLUGINS_IMPULSE_RESPONSES_VERSION  \
     LSP_MODULE_VERSION( \
@@ -103,7 +103,9 @@ namespace lsp
             CONTROL("itc" id, "Tail cut" label, U_MSEC, impulse_responses_metadata::CONV_LENGTH), \
             CONTROL("ifi" id, "Fade in" label, U_MSEC, impulse_responses_metadata::CONV_LENGTH), \
             CONTROL("ifo" id, "Fade out" label, U_MSEC, impulse_responses_metadata::CONV_LENGTH), \
-            TRIGGER("ils" id, "Impulse listen" label), \
+            TRIGGER("ils" id, "Impulse preview listen" label), \
+            TRIGGER("ilc" id, "Impulse preview stop" label), \
+            SWITCH("irv" id, "Impulse reverse" label, 0.0f), \
             STATUS("ifs" id, "Load status" label), \
             METER("ifl" id, "Impulse length" label, U_MSEC, impulse_responses_metadata::CONV_LENGTH), \
             MESH("ifd" id, "Impulse file contents" label, impulse_responses_metadata::TRACKS_MAX, impulse_responses_metadata::MESH_SIZE)
@@ -185,14 +187,17 @@ namespace lsp
             "IA1M",
             &developers::v_sadovnikov,
             "impulse_responses_mono",
-            LSP_LV2_URI("impulse_responses_mono"),
-            LSP_LV2UI_URI("impulse_responses_mono"),
-            "wvwt",
-            LSP_VST3_UID("ia1m    wvwt"),
-            LSP_VST3UI_UID("ia1m    wvwt"),
-            0,
-            NULL,
-            LSP_CLAP_URI("impulse_responses_mono"),
+            {
+                LSP_LV2_URI("impulse_responses_mono"),
+                LSP_LV2UI_URI("impulse_responses_mono"),
+                "wvwt",
+                LSP_VST3_UID("ia1m    wvwt"),
+                LSP_VST3UI_UID("ia1m    wvwt"),
+                0,
+                NULL,
+                LSP_CLAP_URI("impulse_responses_mono"),
+                LSP_GST_UID("impulse_responses_mono"),
+            },
             LSP_PLUGINS_IMPULSE_RESPONSES_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -212,14 +217,17 @@ namespace lsp
             "IA1S",
             &developers::v_sadovnikov,
             "impulse_responses_stereo",
-            LSP_LV2_URI("impulse_responses_stereo"),
-            LSP_LV2UI_URI("impulse_responses_stereo"),
-            "1khz",
-            LSP_VST3_UID("ia1s    1khz"),
-            LSP_VST3UI_UID("ia1s    1khz"),
-            0,
-            NULL,
-            LSP_CLAP_URI("impulse_responses_stereo"),
+            {
+                LSP_LV2_URI("impulse_responses_stereo"),
+                LSP_LV2UI_URI("impulse_responses_stereo"),
+                "1khz",
+                LSP_VST3_UID("ia1s    1khz"),
+                LSP_VST3UI_UID("ia1s    1khz"),
+                0,
+                NULL,
+                LSP_CLAP_URI("impulse_responses_stereo"),
+                LSP_GST_UID("impulse_responses_stereo"),
+            },
             LSP_PLUGINS_IMPULSE_RESPONSES_VERSION,
             plugin_classes,
             clap_features_stereo,
