@@ -27,7 +27,7 @@
 
 #define LSP_PLUGINS_IMPULSE_REVERB_VERSION_MAJOR       1
 #define LSP_PLUGINS_IMPULSE_REVERB_VERSION_MINOR       0
-#define LSP_PLUGINS_IMPULSE_REVERB_VERSION_MICRO       20
+#define LSP_PLUGINS_IMPULSE_REVERB_VERSION_MICRO       24
 
 #define LSP_PLUGINS_IMPULSE_REVERB_VERSION  \
     LSP_MODULE_VERSION( \
@@ -121,7 +121,8 @@ namespace lsp
             CONTROL("itc" id, "Tail cut" label, U_MSEC, impulse_reverb_metadata::CONV_LENGTH), \
             CONTROL("ifi" id, "Fade in" label, U_MSEC, impulse_reverb_metadata::CONV_LENGTH), \
             CONTROL("ifo" id, "Fade out" label, U_MSEC, impulse_reverb_metadata::CONV_LENGTH), \
-            TRIGGER("ils" id, "Impulse listen" label), \
+            TRIGGER("ils" id, "Impulse listen preview" label), \
+            TRIGGER("ilc" id, "Impulse stop preview" label), \
             SWITCH("irv" id, "Impulse reverse" label, 0.0f), \
             STATUS("ifs" id, "Load status" label), \
             METER("ifl" id, "Impulse length" label, U_MSEC, impulse_reverb_metadata::CONV_LENGTH), \
@@ -226,14 +227,17 @@ namespace lsp
             "INH1M",
             &developers::v_sadovnikov,
             "impulse_reverb_mono",
-            LSP_LV2_URI("impulse_reverb_mono"),
-            LSP_LV2UI_URI("impulse_reverb_mono"),
-            "fggq",
-            LSP_VST3_UID("inh1m   fggq"),
-            LSP_VST3UI_UID("inh1m   fggq"),
-            0,
-            NULL,
-            LSP_CLAP_URI("impulse_reverb_mono"),
+            {
+                LSP_LV2_URI("impulse_reverb_mono"),
+                LSP_LV2UI_URI("impulse_reverb_mono"),
+                "fggq",
+                LSP_VST3_UID("inh1m   fggq"),
+                LSP_VST3UI_UID("inh1m   fggq"),
+                0,
+                NULL,
+                LSP_CLAP_URI("impulse_reverb_mono"),
+                LSP_GST_UID("impulse_reverb_mono"),
+            },
             LSP_PLUGINS_IMPULSE_REVERB_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -253,14 +257,17 @@ namespace lsp
             "INH1S",
             &developers::v_sadovnikov,
             "impulse_reverb_stereo",
-            LSP_LV2_URI("impulse_reverb_stereo"),
-            LSP_LV2UI_URI("impulse_reverb_stereo"),
-            "o9zj",
-            LSP_VST3_UID("inh1s   o9zj"),
-            LSP_VST3UI_UID("inh1s   o9zj"),
-            0,
-            NULL,
-            LSP_CLAP_URI("impulse_reverb_stereo"),
+            {
+                LSP_LV2_URI("impulse_reverb_stereo"),
+                LSP_LV2UI_URI("impulse_reverb_stereo"),
+                "o9zj",
+                LSP_VST3_UID("inh1s   o9zj"),
+                LSP_VST3UI_UID("inh1s   o9zj"),
+                0,
+                NULL,
+                LSP_CLAP_URI("impulse_reverb_stereo"),
+                LSP_GST_UID("impulse_reverb_stereo"),
+            },
             LSP_PLUGINS_IMPULSE_REVERB_VERSION,
             plugin_classes,
             clap_features_stereo,
