@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_LOUD_COMP_VERSION_MAJOR       1
 #define LSP_PLUGINS_LOUD_COMP_VERSION_MINOR       0
-#define LSP_PLUGINS_LOUD_COMP_VERSION_MICRO       19
+#define LSP_PLUGINS_LOUD_COMP_VERSION_MICRO       23
 
 #define LSP_PLUGINS_LOUD_COMP_VERSION  \
     LSP_MODULE_VERSION( \
@@ -60,6 +60,19 @@ namespace lsp
             { "ISO226-2003",        "lcomp.curve.iso226" },
             { "Fletcher-Munson",    "lcomp.curve.fm" },
             { "Robinson-Dadson",    "lcomp.curve.rd" },
+            { "ISO226-2023",        "lcomp.curve.iso226_2023" },
+            { NULL, NULL }
+        };
+
+        static const port_item_t loud_comp_generator[] =
+        {
+            { "Sine @ 1kHz 0 dBFS",     "lcomp.gen.sine_1khz" },
+            { "Pink Noise @ -23 LUFS",  "lcomp.gen.pink_23" },
+            { "Pink Noise @ -20 LUFS",  "lcomp.gen.pink_20" },
+            { "Pink Noise @ -18 LUFS",  "lcomp.gen.pink_18" },
+            { "Pink Noise @ -16 LUFS",  "lcomp.gen.pink_16" },
+            { "Pink Noise @ -14 LUFS",  "lcomp.gen.pink_14" },
+            { "Pink Noise @ -12 LUFS",  "lcomp.gen.pink_12" },
             { NULL, NULL }
         };
 
@@ -68,12 +81,15 @@ namespace lsp
             COMBO("std", "Loudness contour standard", loud_comp_metadata::STD_DFL, loud_comp_std), \
             COMBO("fft", "FFT size", loud_comp_metadata::FFT_RANK_IDX_DFL, loud_comp_fft_rank), \
             CONTROL("volume", "Output volume", U_DB, loud_comp_metadata::PHONS), \
-            SWITCH("refer", "Enable reference sine generator", 0.0f), \
+            SWITCH("refer", "Enable reference generator", 0.0f), \
+            COMBO("reftype", "Type of reference generator", 2.0f, loud_comp_generator), \
             SWITCH("hclip", "Hard-clipping enable", 0.0f), \
             CONTROL("hcrange", "Hard-clipping range", U_DB, loud_comp_metadata::HCRANGE), \
             TRIGGER("hcclean", "Clean hard-clipping indicators"), \
             MESH("spec", "Level compensation frequency graph", 2, loud_comp_metadata::CURVE_MESH_SIZE), \
-            SWITCH("relspec", "Equalization curve is shown relative to the volume", 0.0f)
+            SWITCH("relspec", "Equalization curve is shown relative to the volume", 0.0f), \
+            LUFS_METER("lufs_il", "Input signal LUFS", 24.0f), \
+            LUFS_METER("lufs_ol", "Input signal LUFS", 24.0f)
 
         static const port_t loud_comp_mono_ports[] =
         {
@@ -118,14 +134,17 @@ namespace lsp
             "LK1M",
             &developers::v_sadovnikov,
             "loud_comp_mono",
-            LSP_LV2_URI("loud_comp_mono"),
-            LSP_LV2UI_URI("loud_comp_mono"),
-            "eno9",
-            LSP_VST3_UID("lk1m    eno9"),
-            LSP_VST3UI_UID("lk1m    eno9"),
-            LSP_LADSPA_LOUD_COMP_BASE + 0,
-            LSP_LADSPA_URI("loud_comp_mono"),
-            LSP_CLAP_URI("loud_comp_mono"),
+            {
+                LSP_LV2_URI("loud_comp_mono"),
+                LSP_LV2UI_URI("loud_comp_mono"),
+                "eno9",
+                LSP_VST3_UID("lk1m    eno9"),
+                LSP_VST3UI_UID("lk1m    eno9"),
+                LSP_LADSPA_LOUD_COMP_BASE + 0,
+                LSP_LADSPA_URI("loud_comp_mono"),
+                LSP_CLAP_URI("loud_comp_mono"),
+                LSP_GST_UID("loud_comp_mono"),
+            },
             LSP_PLUGINS_LOUD_COMP_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -145,14 +164,17 @@ namespace lsp
             "LK1S",
             &developers::v_sadovnikov,
             "loud_comp_stereo",
-            LSP_LV2_URI("loud_comp_stereo"),
-            LSP_LV2UI_URI("loud_comp_stereo"),
-            "wva0",
-            LSP_VST3_UID("lk1s    wva0"),
-            LSP_VST3UI_UID("lk1s    wva0"),
-            LSP_LADSPA_LOUD_COMP_BASE + 1,
-            LSP_LADSPA_URI("loud_comp_stereo"),
-            LSP_CLAP_URI("loud_comp_stereo"),
+            {
+                LSP_LV2_URI("loud_comp_stereo"),
+                LSP_LV2UI_URI("loud_comp_stereo"),
+                "wva0",
+                LSP_VST3_UID("lk1s    wva0"),
+                LSP_VST3UI_UID("lk1s    wva0"),
+                LSP_LADSPA_LOUD_COMP_BASE + 1,
+                LSP_LADSPA_URI("loud_comp_stereo"),
+                LSP_CLAP_URI("loud_comp_stereo"),
+                LSP_GST_UID("loud_comp_stereo"),
+            },
             LSP_PLUGINS_LOUD_COMP_VERSION,
             plugin_classes,
             clap_features_stereo,
