@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_MB_LIMITER_VERSION_MAJOR       1
 #define LSP_PLUGINS_MB_LIMITER_VERSION_MINOR       0
-#define LSP_PLUGINS_MB_LIMITER_VERSION_MICRO       8
+#define LSP_PLUGINS_MB_LIMITER_VERSION_MICRO       12
 
 #define LSP_PLUGINS_MB_LIMITER_VERSION  \
     LSP_MODULE_VERSION( \
@@ -120,7 +120,22 @@ namespace lsp
             { NULL, NULL }
         };
 
-        #define MBL_COMMON \
+        static const port_item_t limiter_sc_types[] =
+        {
+            { "Internal",       "sidechain.internal"        },
+            { "Link",           "sidechain.link"            },
+            { NULL, NULL }
+        };
+
+        static const port_item_t limiter_sc_types_for_sc[] =
+        {
+            { "Internal",       "sidechain.internal"        },
+            { "External",       "sidechain.external"        },
+            { "Link",           "sidechain.link"            },
+            { NULL, NULL }
+        };
+
+        #define MBL_BASE \
             BYPASS, \
             IN_GAIN, \
             OUT_GAIN, \
@@ -134,9 +149,19 @@ namespace lsp
             LOG_CONTROL("react", "FFT reactivity", U_MSEC, mb_limiter::REACT_TIME), \
             AMP_GAIN100("shift", "Shift gain", 1.0f)
 
+        #define MBL_COMMON \
+            MBL_BASE, \
+            COMBO("extsc", "Sidechain source", 0.0f, limiter_sc_types)
+
         #define MBL_SC_COMMON \
-            MBL_COMMON, \
-            SWITCH("extsc", "External sidechain", 0.0f)
+            MBL_BASE, \
+            COMBO("extsc", "Sidechain source", 0.0f, limiter_sc_types_for_sc)
+
+        #define MBL_SHM_LINK_MONO \
+            OPT_RETURN_MONO("link", "shml", "Side-chain shared memory link")
+
+        #define MBL_SHM_LINK_STEREO \
+            OPT_RETURN_STEREO("link", "shml_", "Side-chain shared memory link")
 
         #define MBL_SPLIT(id, label, enable, freq) \
             SWITCH("se" id, "Limiter band enable" label, enable), \
@@ -207,6 +232,7 @@ namespace lsp
         {
             // Input and output audio ports
             PORTS_MONO_PLUGIN,
+            MBL_SHM_LINK_MONO,
             MBL_COMMON,
             MBL_METERS_MONO,
             MBL_MAIN_LIMITER_MONO,
@@ -235,6 +261,7 @@ namespace lsp
         {
             // Input and output audio ports
             PORTS_STEREO_PLUGIN,
+            MBL_SHM_LINK_STEREO,
             MBL_COMMON,
             MBL_METERS_STEREO,
             MBL_MAIN_LIMITER_STEREO,
@@ -264,6 +291,7 @@ namespace lsp
             // Input and output audio ports
             PORTS_MONO_PLUGIN,
             PORTS_MONO_SIDECHAIN,
+            MBL_SHM_LINK_MONO,
             MBL_SC_COMMON,
             MBL_METERS_MONO,
             MBL_MAIN_LIMITER_MONO,
@@ -293,6 +321,7 @@ namespace lsp
             // Input and output audio ports
             PORTS_STEREO_PLUGIN,
             PORTS_STEREO_SIDECHAIN,
+            MBL_SHM_LINK_STEREO,
             MBL_SC_COMMON,
             MBL_METERS_STEREO,
             MBL_MAIN_LIMITER_STEREO,
@@ -338,14 +367,17 @@ namespace lsp
             "MBB1M",
             &developers::v_sadovnikov,
             "mb_limiter_mono",
-            LSP_LV2_URI("mb_limiter_mono"),
-            LSP_LV2UI_URI("mb_limiter_mono"),
-            "mblm",
-            LSP_VST3_UID("mbb1m   mblm"),
-            LSP_VST3UI_UID("mbb1m   mblm"),
-            LSP_LADSPA_MB_LIMITER_BASE + 0,
-            LSP_LADSPA_URI("mb_limiter_mono"),
-            LSP_CLAP_URI("mb_limiter_mono"),
+            {
+                LSP_LV2_URI("mb_limiter_mono"),
+                LSP_LV2UI_URI("mb_limiter_mono"),
+                "mblm",
+                LSP_VST3_UID("mbb1m   mblm"),
+                LSP_VST3UI_UID("mbb1m   mblm"),
+                LSP_LADSPA_MB_LIMITER_BASE + 0,
+                LSP_LADSPA_URI("mb_limiter_mono"),
+                LSP_CLAP_URI("mb_limiter_mono"),
+                LSP_GST_UID("mb_limiter_mono"),
+            },
             LSP_PLUGINS_MB_LIMITER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -365,14 +397,17 @@ namespace lsp
             "MBB1S",
             &developers::v_sadovnikov,
             "mb_limiter_stereo",
-            LSP_LV2_URI("mb_limiter_stereo"),
-            LSP_LV2UI_URI("mb_limiter_stereo"),
-            "mbls",
-            LSP_VST3_UID("mbb1s   mbls"),
-            LSP_VST3UI_UID("mbb1s   mbls"),
-            LSP_LADSPA_MB_LIMITER_BASE + 1,
-            LSP_LADSPA_URI("mb_limiter_stereo"),
-            LSP_CLAP_URI("mb_limiter_stereo"),
+            {
+                LSP_LV2_URI("mb_limiter_stereo"),
+                LSP_LV2UI_URI("mb_limiter_stereo"),
+                "mbls",
+                LSP_VST3_UID("mbb1s   mbls"),
+                LSP_VST3UI_UID("mbb1s   mbls"),
+                LSP_LADSPA_MB_LIMITER_BASE + 1,
+                LSP_LADSPA_URI("mb_limiter_stereo"),
+                LSP_CLAP_URI("mb_limiter_stereo"),
+                LSP_GST_UID("mb_limiter_stereo"),
+            },
             LSP_PLUGINS_MB_LIMITER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -392,14 +427,17 @@ namespace lsp
             "SCMBB1M",
             &developers::v_sadovnikov,
             "sc_mb_limiter_mono",
-            LSP_LV2_URI("sc_mb_limiter_mono"),
-            LSP_LV2UI_URI("sc_mb_limiter_mono"),
-            "mblM",
-            LSP_VST3_UID("scmbb1m mblM"),
-            LSP_VST3UI_UID("scmbb1m mblM"),
-            LSP_LADSPA_MB_LIMITER_BASE + 2,
-            LSP_LADSPA_URI("sc_mb_limiter_mono"),
-            LSP_CLAP_URI("sc_mb_limiter_mono"),
+            {
+                LSP_LV2_URI("sc_mb_limiter_mono"),
+                LSP_LV2UI_URI("sc_mb_limiter_mono"),
+                "mblM",
+                LSP_VST3_UID("scmbb1m mblM"),
+                LSP_VST3UI_UID("scmbb1m mblM"),
+                LSP_LADSPA_MB_LIMITER_BASE + 2,
+                LSP_LADSPA_URI("sc_mb_limiter_mono"),
+                LSP_CLAP_URI("sc_mb_limiter_mono"),
+                LSP_GST_UID("sc_mb_limiter_mono"),
+            },
             LSP_PLUGINS_MB_LIMITER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -419,14 +457,17 @@ namespace lsp
             "SCMBB1S",
             &developers::v_sadovnikov,
             "sc_mb_limiter_stereo",
-            LSP_LV2_URI("sc_mb_limiter_stereo"),
-            LSP_LV2UI_URI("sc_mb_limiter_stereo"),
-            "mblS",
-            LSP_VST3_UID("scmbb1s mblS"),
-            LSP_VST3UI_UID("scmbb1s mblS"),
-            LSP_LADSPA_MB_LIMITER_BASE + 3,
-            LSP_LADSPA_URI("sc_mb_limiter_stereo"),
-            LSP_CLAP_URI("sc_mb_limiter_stereo"),
+            {
+                LSP_LV2_URI("sc_mb_limiter_stereo"),
+                LSP_LV2UI_URI("sc_mb_limiter_stereo"),
+                "mblS",
+                LSP_VST3_UID("scmbb1s mblS"),
+                LSP_VST3UI_UID("scmbb1s mblS"),
+                LSP_LADSPA_MB_LIMITER_BASE + 3,
+                LSP_LADSPA_URI("sc_mb_limiter_stereo"),
+                LSP_CLAP_URI("sc_mb_limiter_stereo"),
+                LSP_GST_UID("sc_mb_limiter_stereo"),
+            },
             LSP_PLUGINS_MB_LIMITER_VERSION,
             plugin_classes,
             clap_features_stereo,
