@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_MIXER_VERSION_MAJOR       1
 #define LSP_PLUGINS_MIXER_VERSION_MINOR       0
-#define LSP_PLUGINS_MIXER_VERSION_MICRO       11
+#define LSP_PLUGINS_MIXER_VERSION_MICRO       15
 
 #define LSP_PLUGINS_MIXER_VERSION  \
     LSP_MODULE_VERSION( \
@@ -40,8 +40,19 @@ namespace lsp
     {
         //-------------------------------------------------------------------------
         // Plugin metadata
+        #define MIX_MONO_PORTS \
+            PORTS_MONO_PLUGIN, \
+            OPT_SEND_MONO("send", "sout", "Mix send"), \
+            OPT_RETURN_MONO("return", "rin", "Mix return")
+
+        #define MIX_STEREO_PORTS \
+            PORTS_STEREO_PLUGIN, \
+            OPT_SEND_STEREO("send", "sout", "Mix send"), \
+            OPT_RETURN_STEREO("return", "rin", "Mix return")
+
         #define MIX_MONO_CHANNEL(id, label) \
             AUDIO_INPUT("in" id, "Audio input " label), \
+            OPT_RETURN_MONO("ret" id, "rin" id, "Audio channel " label " return"), \
             SWITCH("cs" id, "Channel solo " label, 0.0f), \
             SWITCH("cm" id, "Channel mute " label, 0.0f), \
             SWITCH("ci" id, "Channel phase invert " label, 0.0f), \
@@ -51,6 +62,7 @@ namespace lsp
         #define MIX_STEREO_CHANNEL(id, label) \
             AUDIO_INPUT("in" id "l", "Audio input left " label), \
             AUDIO_INPUT("in" id "r", "Audio input right " label), \
+            OPT_RETURN_STEREO("ret" id, "rin" id, "Audio channel " label " return"), \
             SWITCH("cs" id, "Channel solo " label, 0.0f), \
             SWITCH("cm" id, "Channel mute " label, 0.0f), \
             SWITCH("ci" id, "Channel phase invert " label, 0.0f), \
@@ -81,7 +93,7 @@ namespace lsp
 
         static const port_t mixer_x4_mono_ports[] =
         {
-            PORTS_MONO_PLUGIN,
+            MIX_MONO_PORTS,
             BYPASS,
             MIX_MONO_GLOBAL,
 
@@ -95,7 +107,7 @@ namespace lsp
 
         static const port_t mixer_x8_mono_ports[] =
         {
-            PORTS_MONO_PLUGIN,
+            MIX_MONO_PORTS,
             BYPASS,
             MIX_MONO_GLOBAL,
 
@@ -113,7 +125,7 @@ namespace lsp
 
         static const port_t mixer_x16_mono_ports[] =
         {
-            PORTS_MONO_PLUGIN,
+            MIX_MONO_PORTS,
             BYPASS,
             MIX_MONO_GLOBAL,
 
@@ -139,7 +151,7 @@ namespace lsp
 
         static const port_t mixer_x4_stereo_ports[] =
         {
-            PORTS_STEREO_PLUGIN,
+            MIX_STEREO_PORTS,
             BYPASS,
             MIX_STEREO_GLOBAL,
 
@@ -153,7 +165,7 @@ namespace lsp
 
         static const port_t mixer_x8_stereo_ports[] =
         {
-            PORTS_STEREO_PLUGIN,
+            MIX_STEREO_PORTS,
             BYPASS,
             MIX_STEREO_GLOBAL,
 
@@ -171,7 +183,7 @@ namespace lsp
 
         static const port_t mixer_x16_stereo_ports[] =
         {
-            PORTS_STEREO_PLUGIN,
+            MIX_STEREO_PORTS,
             BYPASS,
             MIX_STEREO_GLOBAL,
 
@@ -335,14 +347,17 @@ namespace lsp
             "M4M",
             &developers::v_sadovnikov,
             "mixer_x4_mono",
-            LSP_LV2_URI("mixer_x4_mono"),
-            LSP_LV2UI_URI("mixer_x4_mono"),
-            "m04m",
-            LSP_VST3_UID("m4m     m04m"),
-            LSP_VST3UI_UID("m4m     m04m"),
-            LSP_LADSPA_MIXER_BASE + 0,
-            LSP_LADSPA_URI("mixer_x4_mono"),
-            LSP_CLAP_URI("mixer_x4_mono"),
+            {
+                LSP_LV2_URI("mixer_x4_mono"),
+                LSP_LV2UI_URI("mixer_x4_mono"),
+                "m04m",
+                LSP_VST3_UID("m4m     m04m"),
+                LSP_VST3UI_UID("m4m     m04m"),
+                LSP_LADSPA_MIXER_BASE + 0,
+                LSP_LADSPA_URI("mixer_x4_mono"),
+                LSP_CLAP_URI("mixer_x4_mono"),
+                LSP_GST_UID("mixer_x4_mono"),
+            },
             LSP_PLUGINS_MIXER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -362,14 +377,17 @@ namespace lsp
             "M8M",
             &developers::v_sadovnikov,
             "mixer_x8_mono",
-            LSP_LV2_URI("mixer_x8_mono"),
-            LSP_LV2UI_URI("mixer_x8_mono"),
-            "m08m",
-            LSP_VST3_UID("m8m     m08m"),
-            LSP_VST3UI_UID("m8m     m08m"),
-            LSP_LADSPA_MIXER_BASE + 1,
-            LSP_LADSPA_URI("mixer_x8_mono"),
-            LSP_CLAP_URI("mixer_x8_mono"),
+            {
+                LSP_LV2_URI("mixer_x8_mono"),
+                LSP_LV2UI_URI("mixer_x8_mono"),
+                "m08m",
+                LSP_VST3_UID("m8m     m08m"),
+                LSP_VST3UI_UID("m8m     m08m"),
+                LSP_LADSPA_MIXER_BASE + 1,
+                LSP_LADSPA_URI("mixer_x8_mono"),
+                LSP_CLAP_URI("mixer_x8_mono"),
+                LSP_GST_UID("mixer_x8_mono"),
+            },
             LSP_PLUGINS_MIXER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -389,14 +407,17 @@ namespace lsp
             "M16M",
             &developers::v_sadovnikov,
             "mixer_x16_mono",
-            LSP_LV2_URI("mixer_x16_mono"),
-            LSP_LV2UI_URI("mixer_x16_mono"),
-            "m16m",
-            LSP_VST3_UID("m16m    m16m"),
-            LSP_VST3UI_UID("m16m    m16m"),
-            LSP_LADSPA_MIXER_BASE + 2,
-            LSP_LADSPA_URI("mixer_x16_mono"),
-            LSP_CLAP_URI("mixer_x16_mono"),
+            {
+                LSP_LV2_URI("mixer_x16_mono"),
+                LSP_LV2UI_URI("mixer_x16_mono"),
+                "m16m",
+                LSP_VST3_UID("m16m    m16m"),
+                LSP_VST3UI_UID("m16m    m16m"),
+                LSP_LADSPA_MIXER_BASE + 2,
+                LSP_LADSPA_URI("mixer_x16_mono"),
+                LSP_CLAP_URI("mixer_x16_mono"),
+                LSP_GST_UID("mixer_x16_mono"),
+            },
             LSP_PLUGINS_MIXER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -416,14 +437,17 @@ namespace lsp
             "M4S",
             &developers::v_sadovnikov,
             "mixer_x4_stereo",
-            LSP_LV2_URI("mixer_x4_stereo"),
-            LSP_LV2UI_URI("mixer_x4_stereo"),
-            "m04s",
-            LSP_VST3_UID("m4s     m04s"),
-            LSP_VST3UI_UID("m4s     m04s"),
-            LSP_LADSPA_MIXER_BASE + 3,
-            LSP_LADSPA_URI("mixer_x4_stereo"),
-            LSP_CLAP_URI("mixer_x4_stereo"),
+            {
+                LSP_LV2_URI("mixer_x4_stereo"),
+                LSP_LV2UI_URI("mixer_x4_stereo"),
+                "m04s",
+                LSP_VST3_UID("m4s     m04s"),
+                LSP_VST3UI_UID("m4s     m04s"),
+                LSP_LADSPA_MIXER_BASE + 3,
+                LSP_LADSPA_URI("mixer_x4_stereo"),
+                LSP_CLAP_URI("mixer_x4_stereo"),
+                LSP_GST_UID("mixer_x4_stereo"),
+            },
             LSP_PLUGINS_MIXER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -443,14 +467,17 @@ namespace lsp
             "M8S",
             &developers::v_sadovnikov,
             "mixer_x8_stereo",
-            LSP_LV2_URI("mixer_x8_stereo"),
-            LSP_LV2UI_URI("mixer_x8_stereo"),
-            "m08s",
-            LSP_VST3_UID("m8s     m08s"),
-            LSP_VST3UI_UID("m8s     m08s"),
-            LSP_LADSPA_MIXER_BASE + 4,
-            LSP_LADSPA_URI("mixer_x8_stereo"),
-            LSP_CLAP_URI("mixer_x8_stereo"),
+            {
+                LSP_LV2_URI("mixer_x8_stereo"),
+                LSP_LV2UI_URI("mixer_x8_stereo"),
+                "m08s",
+                LSP_VST3_UID("m8s     m08s"),
+                LSP_VST3UI_UID("m8s     m08s"),
+                LSP_LADSPA_MIXER_BASE + 4,
+                LSP_LADSPA_URI("mixer_x8_stereo"),
+                LSP_CLAP_URI("mixer_x8_stereo"),
+                LSP_GST_UID("mixer_x8_stereo"),
+            },
             LSP_PLUGINS_MIXER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -470,14 +497,17 @@ namespace lsp
             "M16s",
             &developers::v_sadovnikov,
             "mixer_x16_stereo",
-            LSP_LV2_URI("mixer_x16_stereo"),
-            LSP_LV2UI_URI("mixer_x16_stereo"),
-            "m16s",
-            LSP_VST3_UID("m16s    m16s"),
-            LSP_VST3UI_UID("m16s    m16s"),
-            LSP_LADSPA_MIXER_BASE + 5,
-            LSP_LADSPA_URI("mixer_x16_stereo"),
-            LSP_CLAP_URI("mixer_x16_stereo"),
+            {
+                LSP_LV2_URI("mixer_x16_stereo"),
+                LSP_LV2UI_URI("mixer_x16_stereo"),
+                "m16s",
+                LSP_VST3_UID("m16s    m16s"),
+                LSP_VST3UI_UID("m16s    m16s"),
+                LSP_LADSPA_MIXER_BASE + 5,
+                LSP_LADSPA_URI("mixer_x16_stereo"),
+                LSP_CLAP_URI("mixer_x16_stereo"),
+                LSP_GST_UID("mixer_x16_stereo"),
+            },
             LSP_PLUGINS_MIXER_VERSION,
             plugin_classes,
             clap_features_stereo,
