@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2022 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2022 Stefano Tronci <stefano.tronci@protonmail.com>
+ * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2024 Stefano Tronci <stefano.tronci@protonmail.com>
  *
  * This file is part of lsp-plugins
  * Created on: 27 Feb 2022
@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_NOISE_GENERATOR_VERSION_MAJOR       1
 #define LSP_PLUGINS_NOISE_GENERATOR_VERSION_MINOR       0
-#define LSP_PLUGINS_NOISE_GENERATOR_VERSION_MICRO       14
+#define LSP_PLUGINS_NOISE_GENERATOR_VERSION_MICRO       18
 
 #define LSP_PLUGINS_NOISE_GENERATOR_VERSION  \
     LSP_MODULE_VERSION( \
@@ -271,14 +271,17 @@ namespace lsp
             "NG1",
             &developers::s_tronci,
             "noise_generator_x1",
-            LSP_LV2_URI("noise_generator_x1"),
-            LSP_LV2UI_URI("noise_generator_x1"),
-            "lng0",
-            LSP_VST3_UID("ng1     lng0"),
-            LSP_VST3UI_UID("ng1     lng0"),
-            LSP_LADSPA_NOISE_GENERATOR_BASE + 0,
-            LSP_LADSPA_URI("noise_generator_x1"),
-            LSP_CLAP_URI("noise_generator_x1"),
+            {
+                LSP_LV2_URI("noise_generator_x1"),
+                LSP_LV2UI_URI("noise_generator_x1"),
+                "lng0",
+                LSP_VST3_UID("ng1     lng0"),
+                LSP_VST3UI_UID("ng1     lng0"),
+                LSP_LADSPA_NOISE_GENERATOR_BASE + 0,
+                LSP_LADSPA_URI("noise_generator_x1"),
+                LSP_CLAP_URI("noise_generator_x1"),
+                LSP_GST_UID("noise_generator_x1"),
+            },
             LSP_PLUGINS_NOISE_GENERATOR_VERSION,
             plugin_classes,
             clap_features,
@@ -298,14 +301,17 @@ namespace lsp
             "NG2",
             &developers::s_tronci,
             "noise_generator_x2",
-            LSP_LV2_URI("noise_generator_x2"),
-            LSP_LV2UI_URI("noise_generator_x2"),
-            "lng1",
-            LSP_VST3_UID("ng2     lng1"),
-            LSP_VST3UI_UID("ng2     lng1"),
-            LSP_LADSPA_NOISE_GENERATOR_BASE + 1,
-            LSP_LADSPA_URI("noise_generator_x2"),
-            LSP_CLAP_URI("noise_generator_x2"),
+            {
+                LSP_LV2_URI("noise_generator_x2"),
+                LSP_LV2UI_URI("noise_generator_x2"),
+                "lng1",
+                LSP_VST3_UID("ng2     lng1"),
+                LSP_VST3UI_UID("ng2     lng1"),
+                LSP_LADSPA_NOISE_GENERATOR_BASE + 1,
+                LSP_LADSPA_URI("noise_generator_x2"),
+                LSP_CLAP_URI("noise_generator_x2"),
+                LSP_GST_UID("noise_generator_x2"),
+            },
             LSP_PLUGINS_NOISE_GENERATOR_VERSION,
             plugin_classes,
             clap_features,
@@ -325,14 +331,17 @@ namespace lsp
             "NG4",
             &developers::s_tronci,
             "noise_generator_x4",
-            LSP_LV2_URI("noise_generator_x4"),
-            LSP_LV2UI_URI("noise_generator_x4"),
-            "lng2",
-            LSP_VST3_UID("ng4     lng2"),
-            LSP_VST3UI_UID("ng4     lng2"),
-            LSP_LADSPA_NOISE_GENERATOR_BASE + 2,
-            LSP_LADSPA_URI("noise_generator_x4"),
-            LSP_CLAP_URI("noise_generator_x4"),
+            {
+                LSP_LV2_URI("noise_generator_x4"),
+                LSP_LV2UI_URI("noise_generator_x4"),
+                "lng2",
+                LSP_VST3_UID("ng4     lng2"),
+                LSP_VST3UI_UID("ng4     lng2"),
+                LSP_LADSPA_NOISE_GENERATOR_BASE + 2,
+                LSP_LADSPA_URI("noise_generator_x4"),
+                LSP_CLAP_URI("noise_generator_x4"),
+                LSP_GST_UID("noise_generator_x4"),
+            },
             LSP_PLUGINS_NOISE_GENERATOR_VERSION,
             plugin_classes,
             clap_features,
