@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_PARA_EQUALIZER_VERSION_MAJOR         1
 #define LSP_PLUGINS_PARA_EQUALIZER_VERSION_MINOR         0
-#define LSP_PLUGINS_PARA_EQUALIZER_VERSION_MICRO         24
+#define LSP_PLUGINS_PARA_EQUALIZER_VERSION_MICRO         28
 
 #define LSP_PLUGINS_PARA_EQUALIZER_VERSION  \
     LSP_MODULE_VERSION( \
@@ -179,18 +179,18 @@ namespace lsp
         };
 
         #define EQ_FILTER(id, label, x, total, f) \
-                COMBO("ft" id "_" #x, "Filter type " label #x, 0, filter_types), \
-                COMBO("fm" id "_" #x, "Filter mode " label #x, 0, filter_modes), \
-                COMBO("s" id "_" #x, "Filter slope " label #x, 0, filter_slopes), \
-                SWITCH("xs" id "_" #x, "Filter solo " label #x, 0.0f), \
-                SWITCH("xm" id "_" #x, "Filter mute " label #x, 0.0f), \
-                LOG_CONTROL_DFL("f" id "_" #x, "Frequency " label #x, U_HZ, para_equalizer_metadata::FREQ, f), \
-                CONTROL("w" id "_" #x, "Filter Width " label #x, U_OCTAVES, para_equalizer_metadata::WIDTH), \
-                { "g" id "_" #x, "Gain " label # x, U_GAIN_AMP, R_CONTROL, F_LOG | F_UPPER | F_LOWER | F_STEP, GAIN_AMP_M_36_DB, GAIN_AMP_P_36_DB, GAIN_AMP_0_DB, 0.01, NULL, NULL }, \
-                { "q" id "_" #x, "Quality factor " label #x, U_NONE, R_CONTROL, F_UPPER | F_LOWER | F_STEP, 0.0f, 100.0f, 0.0f, 0.025f, NULL        }, \
-                { "hue" id "_" #x, "Hue " label #x, U_NONE, R_CONTROL, F_UPPER | F_LOWER | F_STEP | F_CYCLIC, 0.0f, 1.0f, (float(x) / float(total)), 0.25f/360.0f, NULL     }, \
-                BLINK("fv" id "_" #x, "Filter visibility " label #x), \
-                MESH("agf" id "_" #x, "Amplitude graph " label #x, 2, para_equalizer_metadata::FILTER_MESH_POINTS)
+            COMBO("ft" id "_" #x, "Filter type " label #x, 0, filter_types), \
+            COMBO("fm" id "_" #x, "Filter mode " label #x, 0, filter_modes), \
+            COMBO("s" id "_" #x, "Filter slope " label #x, 0, filter_slopes), \
+            SWITCH("xs" id "_" #x, "Filter solo " label #x, 0.0f), \
+            SWITCH("xm" id "_" #x, "Filter mute " label #x, 0.0f), \
+            LOG_CONTROL_DFL("f" id "_" #x, "Frequency " label #x, U_HZ, para_equalizer_metadata::FREQ, f), \
+            CONTROL("w" id "_" #x, "Filter Width " label #x, U_OCTAVES, para_equalizer_metadata::WIDTH), \
+            { "g" id "_" #x, "Gain " label # x, U_GAIN_AMP, R_CONTROL, F_LOG | F_UPPER | F_LOWER | F_STEP, GAIN_AMP_M_36_DB, GAIN_AMP_P_36_DB, GAIN_AMP_0_DB, 0.01, NULL, NULL }, \
+            { "q" id "_" #x, "Quality factor " label #x, U_NONE, R_CONTROL, F_UPPER | F_LOWER | F_STEP, 0.0f, 100.0f, 0.0f, 0.025f, NULL        }, \
+            { "hue" id "_" #x, "Hue " label #x, U_NONE, R_CONTROL, F_UPPER | F_LOWER | F_STEP | F_CYCLIC, 0.0f, 1.0f, (float(x) / float(total)), 0.25f/360.0f, NULL     }, \
+            BLINK("fv" id "_" #x, "Filter visibility " label #x), \
+            MESH("agf" id "_" #x, "Amplitude graph " label #x, 2, para_equalizer_metadata::FILTER_MESH_POINTS)
 
         #define EQ_FILTER_MONO(x, total, f)     EQ_FILTER("", "", x, total, f)
         #define EQ_FILTER_STEREO(x, total, f)   EQ_FILTER("", "", x, total, f)
@@ -198,72 +198,89 @@ namespace lsp
         #define EQ_FILTER_MS(x, total, f)       EQ_FILTER("m", "Mid ", x, total, f), EQ_FILTER("s", "Side ", x, total, f)
 
         #define EQ_COMMON(fselect, filters) \
-                BYPASS, \
-                AMP_GAIN("g_in", "Input gain", para_equalizer_metadata::IN_GAIN_DFL, 10.0f), \
-                AMP_GAIN("g_out", "Output gain", para_equalizer_metadata::OUT_GAIN_DFL, 10.0f), \
-                COMBO("mode", "Equalizer mode", 0, equalizer_eq_modes), \
-                LOG_CONTROL("react", "FFT reactivity", U_MSEC, para_equalizer_metadata::REACT_TIME), \
-                AMP_GAIN("shift", "Shift gain", 1.0f, 100.0f), \
-                LOG_CONTROL("zoom", "Graph zoom", U_GAIN_AMP, para_equalizer_metadata::ZOOM), \
-                COMBO("fsel", "Filter select", 0, fselect), \
-                INT_CONTROL_RANGE("insp_id", "Inspected filter identifier", U_NONE, -1, (filters-1), -1, 1), \
-                CONTROL("insp_r", "Inspect frequency range", U_OCTAVES, para_equalizer_metadata::INSPECT), \
-                SWITCH("insp_on", "Automatically inspect filter when editing", 0)
+            BYPASS, \
+            AMP_GAIN("g_in", "Input gain", para_equalizer_metadata::IN_GAIN_DFL, 10.0f), \
+            AMP_GAIN("g_out", "Output gain", para_equalizer_metadata::OUT_GAIN_DFL, 10.0f), \
+            COMBO("mode", "Equalizer mode", 0, equalizer_eq_modes), \
+            LOG_CONTROL("react", "FFT reactivity", U_MSEC, para_equalizer_metadata::REACT_TIME), \
+            AMP_GAIN("shift", "Shift gain", 1.0f, 100.0f), \
+            LOG_CONTROL("zoom", "Graph zoom", U_GAIN_AMP, para_equalizer_metadata::ZOOM), \
+            COMBO("fsel", "Filter select", 0, fselect), \
+            INT_CONTROL_RANGE("insp_id", "Inspected filter identifier", U_NONE, -1, (filters-1), -1, 1), \
+            CONTROL("insp_r", "Inspect frequency range", U_OCTAVES, para_equalizer_metadata::INSPECT), \
+            SWITCH("insp_on", "Automatically inspect filter when editing", 0)
 
         #define EQ_MONO_PORTS \
-                MESH("ag", "Amplitude graph", 2, para_equalizer_metadata::MESH_POINTS), \
-                CONTROL("frqs", "Frequency shift", U_SEMITONES, para_equalizer_metadata::PITCH), \
-                METER_GAIN("im", "Input signal meter", GAIN_AMP_P_12_DB), \
-                METER_GAIN("sm", "Output signal meter", GAIN_AMP_P_12_DB)
+            MESH("ag", "Amplitude graph", 2, para_equalizer_metadata::MESH_POINTS), \
+            CONTROL("frqs", "Frequency shift", U_SEMITONES, para_equalizer_metadata::PITCH), \
+            METER_GAIN("im", "Input signal meter", GAIN_AMP_P_12_DB), \
+            METER_GAIN("sm", "Output signal meter", GAIN_AMP_P_12_DB)
 
         #define EQ_STEREO_PORTS \
-                PAN_CTL("bal", "Output balance", 0.0f), \
-                MESH("ag", "Amplitude graph", 2, para_equalizer_metadata::MESH_POINTS), \
-                CONTROL("frqs", "Frequency shift", U_SEMITONES, para_equalizer_metadata::PITCH), \
-                METER_GAIN("iml", "Input signal meter Left", GAIN_AMP_P_12_DB), \
-                METER_GAIN("sml", "Output signal meter Left", GAIN_AMP_P_12_DB), \
-                METER_GAIN("imr", "Input signal meter Right", GAIN_AMP_P_12_DB), \
-                METER_GAIN("smr", "Output signal meter Right", GAIN_AMP_P_12_DB)
+            PAN_CTL("bal", "Output balance", 0.0f), \
+            MESH("ag", "Amplitude graph", 2, para_equalizer_metadata::MESH_POINTS), \
+            CONTROL("frqs", "Frequency shift", U_SEMITONES, para_equalizer_metadata::PITCH), \
+            METER_GAIN("iml", "Input signal meter Left", GAIN_AMP_P_12_DB), \
+            METER_GAIN("sml", "Output signal meter Left", GAIN_AMP_P_12_DB), \
+            METER_GAIN("imr", "Input signal meter Right", GAIN_AMP_P_12_DB), \
+            METER_GAIN("smr", "Output signal meter Right", GAIN_AMP_P_12_DB)
 
         #define EQ_LR_PORTS \
-                PAN_CTL("bal", "Output balance", 0.0f), \
-                MESH("ag_l", "Amplitude graph Left", 2, para_equalizer_metadata::MESH_POINTS), \
-                CONTROL("frqs_l", "Frequency shift Left", U_SEMITONES, para_equalizer_metadata::PITCH), \
-                METER_GAIN("iml", "Input signal meter Left", GAIN_AMP_P_12_DB), \
-                METER_GAIN("sml", "Output signal meter Left", GAIN_AMP_P_12_DB), \
-                SWITCH("fltv_l", "Filter visibility Left", 1.0f), \
-                MESH("ag_r", "Amplitude graph Right", 2, para_equalizer_metadata::MESH_POINTS), \
-                CONTROL("frqs_r", "Frequency shift Right", U_SEMITONES, para_equalizer_metadata::PITCH), \
-                METER_GAIN("imr", "Input signal meter Right", GAIN_AMP_P_12_DB), \
-                METER_GAIN("smr", "Output signal meter Right", GAIN_AMP_P_12_DB), \
-                SWITCH("fltv_r", "Filter visibility Right", 1.0f)
+            PAN_CTL("bal", "Output balance", 0.0f), \
+            MESH("ag_l", "Amplitude graph Left", 2, para_equalizer_metadata::MESH_POINTS), \
+            CONTROL("frqs_l", "Frequency shift Left", U_SEMITONES, para_equalizer_metadata::PITCH), \
+            METER_GAIN("iml", "Input signal meter Left", GAIN_AMP_P_12_DB), \
+            METER_GAIN("sml", "Output signal meter Left", GAIN_AMP_P_12_DB), \
+            SWITCH("fltv_l", "Filter visibility Left", 1.0f), \
+            MESH("ag_r", "Amplitude graph Right", 2, para_equalizer_metadata::MESH_POINTS), \
+            CONTROL("frqs_r", "Frequency shift Right", U_SEMITONES, para_equalizer_metadata::PITCH), \
+            METER_GAIN("imr", "Input signal meter Right", GAIN_AMP_P_12_DB), \
+            METER_GAIN("smr", "Output signal meter Right", GAIN_AMP_P_12_DB), \
+            SWITCH("fltv_r", "Filter visibility Right", 1.0f)
 
         #define EQ_MS_PORTS \
-                PAN_CTL("bal", "Output balance", 0.0f), \
-                SWITCH("lstn", "Mid/Side listen", 0.0f), \
-                AMP_GAIN100("gain_m", "Mid gain", GAIN_AMP_0_DB), \
-                AMP_GAIN100("gain_s", "Side gain", GAIN_AMP_0_DB), \
-                MESH("ag_m", "Amplitude graph Mid", 2, para_equalizer_metadata::MESH_POINTS), \
-                CONTROL("frqs_m", "Frequency shift Mid", U_SEMITONES, para_equalizer_metadata::PITCH), \
-                METER_GAIN("iml", "Input signal meter Left", GAIN_AMP_P_12_DB), \
-                METER_GAIN("sml", "Output signal meter Left", GAIN_AMP_P_12_DB), \
-                SWITCH("fltv_m", "Filter visibility Mid", 1.0f), \
-                MESH("ag_s", "Amplitude graph Side", 2, para_equalizer_metadata::MESH_POINTS), \
-                CONTROL("frqs_s", "Frequency shift Side", U_SEMITONES, para_equalizer_metadata::PITCH), \
-                METER_GAIN("imr", "Input signal meter Right", GAIN_AMP_P_12_DB), \
-                METER_GAIN("smr", "Output signal meter Right", GAIN_AMP_P_12_DB), \
-                SWITCH("fltv_s", "Filter visibility Side", 1.0f)
+            PAN_CTL("bal", "Output balance", 0.0f), \
+            SWITCH("lstn", "Mid/Side listen", 0.0f), \
+            AMP_GAIN100("gain_m", "Mid gain", GAIN_AMP_0_DB), \
+            AMP_GAIN100("gain_s", "Side gain", GAIN_AMP_0_DB), \
+            MESH("ag_m", "Amplitude graph Mid", 2, para_equalizer_metadata::MESH_POINTS), \
+            CONTROL("frqs_m", "Frequency shift Mid", U_SEMITONES, para_equalizer_metadata::PITCH), \
+            METER_GAIN("iml", "Input signal meter Left", GAIN_AMP_P_12_DB), \
+            METER_GAIN("sml", "Output signal meter Left", GAIN_AMP_P_12_DB), \
+            SWITCH("fltv_m", "Filter visibility Mid", 1.0f), \
+            MESH("ag_s", "Amplitude graph Side", 2, para_equalizer_metadata::MESH_POINTS), \
+            CONTROL("frqs_s", "Frequency shift Side", U_SEMITONES, para_equalizer_metadata::PITCH), \
+            METER_GAIN("imr", "Input signal meter Right", GAIN_AMP_P_12_DB), \
+            METER_GAIN("smr", "Output signal meter Right", GAIN_AMP_P_12_DB), \
+            SWITCH("fltv_s", "Filter visibility Side", 1.0f)
+
+        #define EQ_COMMUNICATION_MONO \
+            OPT_SEND_NAME("send", "Audio send"), \
+            OPT_AUDIO_SEND("snd", "Audio send output", 0, "send"), \
+            OPT_RETURN_NAME("return", "Audio return"), \
+            OPT_AUDIO_RETURN("rtn", "Audio return input", 0, "return")
+
+        #define EQ_COMMUNICATION_STEREO \
+            OPT_SEND_NAME("send", "Audio send"), \
+            OPT_AUDIO_SEND("snd_l", "Audio send output left", 0, "send"), \
+            OPT_AUDIO_SEND("snd_r", "Audio send output right", 1, "send"), \
+            OPT_RETURN_NAME("return", "Audio return"), \
+            OPT_AUDIO_RETURN("rtn_l", "Audio return input left", 0, "return"), \
+            OPT_AUDIO_RETURN("rtn_r", "Audio return input right", 1, "return")
 
         #define CHANNEL_ANALYSIS(id, label) \
             SWITCH("ife" id, "Input FFT graph enable" label, 1.0f), \
             SWITCH("ofe" id, "Output FFT graph enable" label, 1.0f), \
+            SWITCH("rfe" id, "Return FFT graph enable" label, 1.0f), \
             MESH("ifg" id, "Input FFT graph" label, 2, para_equalizer_metadata::MESH_POINTS + 2), \
-            MESH("ofg" id, "Output FFT graph" label, 2, para_equalizer_metadata::MESH_POINTS)
+            MESH("ofg" id, "Output FFT graph" label, 2, para_equalizer_metadata::MESH_POINTS), \
+            MESH("rfg" id, "Return FFT graph" label, 2, para_equalizer_metadata::MESH_POINTS)
 
         static const port_t para_equalizer_x8_mono_ports[] =
         {
             PORTS_MONO_PLUGIN,
             EQ_COMMON(filter_select_8, 8),
+            EQ_COMMUNICATION_MONO,
             CHANNEL_ANALYSIS("", ""),
             EQ_MONO_PORTS,
             EQ_FILTER_MONO(0, 8, 16.0f),
@@ -282,6 +299,7 @@ namespace lsp
         {
             PORTS_MONO_PLUGIN,
             EQ_COMMON(filter_select_16, 16),
+            EQ_COMMUNICATION_MONO,
             CHANNEL_ANALYSIS("", ""),
             EQ_MONO_PORTS,
             EQ_FILTER_MONO(0, 16, 16.0f),
@@ -308,6 +326,7 @@ namespace lsp
         {
             PORTS_MONO_PLUGIN,
             EQ_COMMON(filter_select_32, 32),
+            EQ_COMMUNICATION_MONO,
             CHANNEL_ANALYSIS("", ""),
             EQ_MONO_PORTS,
             EQ_FILTER_MONO(0, 32, 16.0f),
@@ -350,6 +369,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON(filter_select_8, 8),
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             EQ_STEREO_PORTS,
@@ -369,6 +389,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON(filter_select_16, 16),
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             EQ_STEREO_PORTS,
@@ -396,6 +417,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON(filter_select_32, 32),
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             EQ_STEREO_PORTS,
@@ -439,6 +461,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON(filter_select_8lr, 16),
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             EQ_LR_PORTS,
@@ -458,6 +481,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON(filter_select_16lr, 32),
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             EQ_LR_PORTS,
@@ -485,6 +509,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON(filter_select_32lr, 64),
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_l", " Left"),
             CHANNEL_ANALYSIS("_r", " Right"),
             EQ_LR_PORTS,
@@ -528,6 +553,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON(filter_select_8ms, 16),
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_m", " Mid"),
             CHANNEL_ANALYSIS("_s", " Side"),
             EQ_MS_PORTS,
@@ -547,6 +573,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON(filter_select_16ms, 32),
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_m", " Mid"),
             CHANNEL_ANALYSIS("_s", " Side"),
             EQ_MS_PORTS,
@@ -574,6 +601,7 @@ namespace lsp
         {
             PORTS_STEREO_PLUGIN,
             EQ_COMMON(filter_select_32ms, 64),
+            EQ_COMMUNICATION_STEREO,
             CHANNEL_ANALYSIS("_m", " Mid"),
             CHANNEL_ANALYSIS("_s", " Side"),
             EQ_MS_PORTS,
@@ -630,14 +658,17 @@ namespace lsp
             "PE8M",
             &developers::v_sadovnikov,
             "para_equalizer_x8_mono",
-            LSP_LV2_URI("para_equalizer_x8_mono"),
-            LSP_LV2UI_URI("para_equalizer_x8_mono"),
-            "dh38",
-            LSP_VST3_UID("pe8m    dh38"),
-            LSP_VST3UI_UID("pe8m    dh38"),
-            LSP_LADSPA_PARA_EQUALIZER_X8 + 0,
-            LSP_LADSPA_URI("para_equalizer_x8_mono"),
-            LSP_CLAP_URI("para_equalizer_x8_mono"),
+            {
+                LSP_LV2_URI("para_equalizer_x8_mono"),
+                LSP_LV2UI_URI("para_equalizer_x8_mono"),
+                "dh38",
+                LSP_VST3_UID("pe8m    dh38"),
+                LSP_VST3UI_UID("pe8m    dh38"),
+                LSP_LADSPA_PARA_EQUALIZER_X8 + 0,
+                LSP_LADSPA_URI("para_equalizer_x8_mono"),
+                LSP_CLAP_URI("para_equalizer_x8_mono"),
+                LSP_GST_UID("para_equalizer_x8_mono"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -657,14 +688,17 @@ namespace lsp
             "PE16M",
             &developers::v_sadovnikov,
             "para_equalizer_x16_mono",
-            LSP_LV2_URI("para_equalizer_x16_mono"),
-            LSP_LV2UI_URI("para_equalizer_x16_mono"),
-            "dh3y",
-            LSP_VST3_UID("pe16m   dh3y"),
-            LSP_VST3UI_UID("pe16m   dh3y"),
-            LSP_LADSPA_PARA_EQUALIZER_BASE + 0,
-            LSP_LADSPA_URI("para_equalizer_x16_mono"),
-            LSP_CLAP_URI("para_equalizer_x16_mono"),
+            {
+                LSP_LV2_URI("para_equalizer_x16_mono"),
+                LSP_LV2UI_URI("para_equalizer_x16_mono"),
+                "dh3y",
+                LSP_VST3_UID("pe16m   dh3y"),
+                LSP_VST3UI_UID("pe16m   dh3y"),
+                LSP_LADSPA_PARA_EQUALIZER_BASE + 0,
+                LSP_LADSPA_URI("para_equalizer_x16_mono"),
+                LSP_CLAP_URI("para_equalizer_x16_mono"),
+                LSP_GST_UID("para_equalizer_x16_mono"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -684,14 +718,17 @@ namespace lsp
             "PE32M",
             &developers::v_sadovnikov,
             "para_equalizer_x32_mono",
-            LSP_LV2_URI("para_equalizer_x32_mono"),
-            LSP_LV2UI_URI("para_equalizer_x32_mono"),
-            "i0px",
-            LSP_VST3_UID("pe32m   i0px"),
-            LSP_VST3UI_UID("pe32m   i0px"),
-            LSP_LADSPA_PARA_EQUALIZER_BASE + 1,
-            LSP_LADSPA_URI("para_equalizer_x32_mono"),
-            LSP_CLAP_URI("para_equalizer_x32_mono"),
+            {
+                LSP_LV2_URI("para_equalizer_x32_mono"),
+                LSP_LV2UI_URI("para_equalizer_x32_mono"),
+                "i0px",
+                LSP_VST3_UID("pe32m   i0px"),
+                LSP_VST3UI_UID("pe32m   i0px"),
+                LSP_LADSPA_PARA_EQUALIZER_BASE + 1,
+                LSP_LADSPA_URI("para_equalizer_x32_mono"),
+                LSP_CLAP_URI("para_equalizer_x32_mono"),
+                LSP_GST_UID("para_equalizer_x32_mono"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_mono,
@@ -711,14 +748,17 @@ namespace lsp
             "PE8S",
             &developers::v_sadovnikov,
             "para_equalizer_x8_stereo",
-            LSP_LV2_URI("para_equalizer_x8_stereo"),
-            LSP_LV2UI_URI("para_equalizer_x8_stereo"),
-            "a5e8",
-            LSP_VST3_UID("pe8s    a5e8"),
-            LSP_VST3UI_UID("pe8s    a5e8"),
-            LSP_LADSPA_PARA_EQUALIZER_X8 + 1,
-            LSP_LADSPA_URI("para_equalizer_x8_stereo"),
-            LSP_CLAP_URI("para_equalizer_x8_stereo"),
+            {
+                LSP_LV2_URI("para_equalizer_x8_stereo"),
+                LSP_LV2UI_URI("para_equalizer_x8_stereo"),
+                "a5e8",
+                LSP_VST3_UID("pe8s    a5e8"),
+                LSP_VST3UI_UID("pe8s    a5e8"),
+                LSP_LADSPA_PARA_EQUALIZER_X8 + 1,
+                LSP_LADSPA_URI("para_equalizer_x8_stereo"),
+                LSP_CLAP_URI("para_equalizer_x8_stereo"),
+                LSP_GST_UID("para_equalizer_x8_stereo"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -738,14 +778,17 @@ namespace lsp
             "PE16S",
             &developers::v_sadovnikov,
             "para_equalizer_x16_stereo",
-            LSP_LV2_URI("para_equalizer_x16_stereo"),
-            LSP_LV2UI_URI("para_equalizer_x16_stereo"),
-            "a5er",
-            LSP_VST3_UID("pe16s   a5er"),
-            LSP_VST3UI_UID("pe16s   a5er"),
-            LSP_LADSPA_PARA_EQUALIZER_BASE + 2,
-            LSP_LADSPA_URI("para_equalizer_x16_stereo"),
-            LSP_CLAP_URI("para_equalizer_x16_stereo"),
+            {
+                LSP_LV2_URI("para_equalizer_x16_stereo"),
+                LSP_LV2UI_URI("para_equalizer_x16_stereo"),
+                "a5er",
+                LSP_VST3_UID("pe16s   a5er"),
+                LSP_VST3UI_UID("pe16s   a5er"),
+                LSP_LADSPA_PARA_EQUALIZER_BASE + 2,
+                LSP_LADSPA_URI("para_equalizer_x16_stereo"),
+                LSP_CLAP_URI("para_equalizer_x16_stereo"),
+                LSP_GST_UID("para_equalizer_x16_stereo"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -765,14 +808,17 @@ namespace lsp
             "PE32S",
             &developers::v_sadovnikov,
             "para_equalizer_x32_stereo",
-            LSP_LV2_URI("para_equalizer_x32_stereo"),
-            LSP_LV2UI_URI("para_equalizer_x32_stereo"),
-            "s2nz",
-            LSP_VST3_UID("pe32s   s2nz"),
-            LSP_VST3UI_UID("pe32s   s2nz"),
-            LSP_LADSPA_PARA_EQUALIZER_BASE + 3,
-            LSP_LADSPA_URI("para_equalizer_x32_stereo"),
-            LSP_CLAP_URI("para_equalizer_x32_stereo"),
+            {
+                LSP_LV2_URI("para_equalizer_x32_stereo"),
+                LSP_LV2UI_URI("para_equalizer_x32_stereo"),
+                "s2nz",
+                LSP_VST3_UID("pe32s   s2nz"),
+                LSP_VST3UI_UID("pe32s   s2nz"),
+                LSP_LADSPA_PARA_EQUALIZER_BASE + 3,
+                LSP_LADSPA_URI("para_equalizer_x32_stereo"),
+                LSP_CLAP_URI("para_equalizer_x32_stereo"),
+                LSP_GST_UID("para_equalizer_x32_stereo"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -792,14 +838,17 @@ namespace lsp
             "PE8LR",
             &developers::v_sadovnikov,
             "para_equalizer_x8_lr",
-            LSP_LV2_URI("para_equalizer_x8_lr"),
-            LSP_LV2UI_URI("para_equalizer_x8_lr"),
-            "4ke8",
-            LSP_VST3_UID("pe8lr   4ke8"),
-            LSP_VST3UI_UID("pe8lr   4ke8"),
-            LSP_LADSPA_PARA_EQUALIZER_X8 + 2,
-            LSP_LADSPA_URI("para_equalizer_x8_lr"),
-            LSP_CLAP_URI("para_equalizer_x8_lr"),
+            {
+                LSP_LV2_URI("para_equalizer_x8_lr"),
+                LSP_LV2UI_URI("para_equalizer_x8_lr"),
+                "4ke8",
+                LSP_VST3_UID("pe8lr   4ke8"),
+                LSP_VST3UI_UID("pe8lr   4ke8"),
+                LSP_LADSPA_PARA_EQUALIZER_X8 + 2,
+                LSP_LADSPA_URI("para_equalizer_x8_lr"),
+                LSP_CLAP_URI("para_equalizer_x8_lr"),
+                LSP_GST_UID("para_equalizer_x8_lr"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -819,14 +868,17 @@ namespace lsp
             "PE16LR",
             &developers::v_sadovnikov,
             "para_equalizer_x16_lr",
-            LSP_LV2_URI("para_equalizer_x16_lr"),
-            LSP_LV2UI_URI("para_equalizer_x16_lr"),
-            "4kef",
-            LSP_VST3_UID("pe16lr  4kef"),
-            LSP_VST3UI_UID("pe16lr  4kef"),
-            LSP_LADSPA_PARA_EQUALIZER_BASE + 4,
-            LSP_LADSPA_URI("para_equalizer_x16_lr"),
-            LSP_CLAP_URI("para_equalizer_x16_lr"),
+            {
+                LSP_LV2_URI("para_equalizer_x16_lr"),
+                LSP_LV2UI_URI("para_equalizer_x16_lr"),
+                "4kef",
+                LSP_VST3_UID("pe16lr  4kef"),
+                LSP_VST3UI_UID("pe16lr  4kef"),
+                LSP_LADSPA_PARA_EQUALIZER_BASE + 4,
+                LSP_LADSPA_URI("para_equalizer_x16_lr"),
+                LSP_CLAP_URI("para_equalizer_x16_lr"),
+                LSP_GST_UID("para_equalizer_x16_lr"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -846,14 +898,17 @@ namespace lsp
             "PE32LR",
             &developers::v_sadovnikov,
             "para_equalizer_x32_lr",
-            LSP_LV2_URI("para_equalizer_x32_lr"),
-            LSP_LV2UI_URI("para_equalizer_x32_lr"),
-            "ilqj",
-            LSP_VST3_UID("pe32lr  ilqj"),
-            LSP_VST3UI_UID("pe32lr  ilqj"),
-            LSP_LADSPA_PARA_EQUALIZER_BASE + 5,
-            LSP_LADSPA_URI("para_equalizer_x32_lr"),
-            LSP_CLAP_URI("para_equalizer_x32_lr"),
+            {
+                LSP_LV2_URI("para_equalizer_x32_lr"),
+                LSP_LV2UI_URI("para_equalizer_x32_lr"),
+                "ilqj",
+                LSP_VST3_UID("pe32lr  ilqj"),
+                LSP_VST3UI_UID("pe32lr  ilqj"),
+                LSP_LADSPA_PARA_EQUALIZER_BASE + 5,
+                LSP_LADSPA_URI("para_equalizer_x32_lr"),
+                LSP_CLAP_URI("para_equalizer_x32_lr"),
+                LSP_GST_UID("para_equalizer_x32_lr"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -873,14 +928,17 @@ namespace lsp
             "PE8MS",
             &developers::v_sadovnikov,
             "para_equalizer_x8_ms",
-            LSP_LV2_URI("para_equalizer_x8_ms"),
-            LSP_LV2UI_URI("para_equalizer_x8_ms"),
-            "opj8",
-            LSP_VST3_UID("pe8ms   opj8"),
-            LSP_VST3UI_UID("pe8ms   opj8"),
-            LSP_LADSPA_PARA_EQUALIZER_X8 + 3,
-            LSP_LADSPA_URI("para_equalizer_x8_ms"),
-            LSP_CLAP_URI("para_equalizer_x8_ms"),
+            {
+                LSP_LV2_URI("para_equalizer_x8_ms"),
+                LSP_LV2UI_URI("para_equalizer_x8_ms"),
+                "opj8",
+                LSP_VST3_UID("pe8ms   opj8"),
+                LSP_VST3UI_UID("pe8ms   opj8"),
+                LSP_LADSPA_PARA_EQUALIZER_X8 + 3,
+                LSP_LADSPA_URI("para_equalizer_x8_ms"),
+                LSP_CLAP_URI("para_equalizer_x8_ms"),
+                LSP_GST_UID("para_equalizer_x8_ms"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -900,14 +958,17 @@ namespace lsp
             "PE16MS",
             &developers::v_sadovnikov,
             "para_equalizer_x16_ms",
-            LSP_LV2_URI("para_equalizer_x16_ms"),
-            LSP_LV2UI_URI("para_equalizer_x16_ms"),
-            "opjs",
-            LSP_VST3_UID("pe16ms  opjs"),
-            LSP_VST3UI_UID("pe16ms  opjs"),
-            LSP_LADSPA_PARA_EQUALIZER_BASE + 6,
-            LSP_LADSPA_URI("para_equalizer_x16_ms"),
-            LSP_CLAP_URI("para_equalizer_x16_ms"),
+            {
+                LSP_LV2_URI("para_equalizer_x16_ms"),
+                LSP_LV2UI_URI("para_equalizer_x16_ms"),
+                "opjs",
+                LSP_VST3_UID("pe16ms  opjs"),
+                LSP_VST3UI_UID("pe16ms  opjs"),
+                LSP_LADSPA_PARA_EQUALIZER_BASE + 6,
+                LSP_LADSPA_URI("para_equalizer_x16_ms"),
+                LSP_CLAP_URI("para_equalizer_x16_ms"),
+                LSP_GST_UID("para_equalizer_x16_ms"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
@@ -927,14 +988,17 @@ namespace lsp
             "PE32MS",
             &developers::v_sadovnikov,
             "para_equalizer_x32_ms",
-            LSP_LV2_URI("para_equalizer_x32_ms"),
-            LSP_LV2UI_URI("para_equalizer_x32_ms"),
-            "lgz9",
-            LSP_VST3_UID("pe32ms  lgz9"),
-            LSP_VST3UI_UID("pe32ms  lgz9"),
-            LSP_LADSPA_PARA_EQUALIZER_BASE + 7,
-            LSP_LADSPA_URI("para_equalizer_x32_ms"),
-            LSP_CLAP_URI("para_equalizer_x32_ms"),
+            {
+                LSP_LV2_URI("para_equalizer_x32_ms"),
+                LSP_LV2UI_URI("para_equalizer_x32_ms"),
+                "lgz9",
+                LSP_VST3_UID("pe32ms  lgz9"),
+                LSP_VST3UI_UID("pe32ms  lgz9"),
+                LSP_LADSPA_PARA_EQUALIZER_BASE + 7,
+                LSP_LADSPA_URI("para_equalizer_x32_ms"),
+                LSP_CLAP_URI("para_equalizer_x32_ms"),
+                LSP_GST_UID("para_equalizer_x32_ms"),
+            },
             LSP_PLUGINS_PARA_EQUALIZER_VERSION,
             plugin_classes,
             clap_features_stereo,
