@@ -128,6 +128,7 @@ namespace lsp
             pDrift          = NULL;
             pActivity       = NULL;
             pListen         = NULL;
+            pStop           = NULL;
             pData           = NULL;
         }
 
@@ -182,6 +183,7 @@ namespace lsp
                 af->pRenderer               = NULL;
 
                 af->sListen.construct();
+                af->sStop.construct();
                 af->sNoteOn.construct();
                 for (size_t i=0; i<4; ++i)
                 {
@@ -193,6 +195,9 @@ namespace lsp
                 for (size_t j=0; j<meta::sampler_metadata::TRACKS_MAX; ++j)
                     af->vThumbs[j]              = NULL;
 
+                af->sListen.init();
+                af->sStop.init();
+
                 af->nUpdateReq              = 0;
                 af->nUpdateResp             = 0;
                 af->bSync                   = false;
@@ -214,7 +219,8 @@ namespace lsp
                 af->fTailCut                = 0.0f;
                 af->fFadeIn                 = 0.0f;
                 af->fFadeOut                = 0.0f;
-                af->bReverse                = false;
+                af->bPreReverse             = false;
+                af->bPostReverse            = false;
                 af->bCompensate             = false;
                 af->fCompensateFade         = 0.0f;
                 af->fCompensateChunk        = 0.0f;
@@ -252,7 +258,9 @@ namespace lsp
                 af->pPreDelay               = NULL;
                 af->pOn                     = NULL;
                 af->pListen                 = NULL;
-                af->pReverse                = NULL;
+                af->pStop                   = NULL;
+                af->pPreReverse             = NULL;
+                af->pPostReverse            = NULL;
                 af->pCompensate             = NULL;
                 af->pCompensateFade         = NULL;
                 af->pCompensateChunk        = NULL;
@@ -313,6 +321,7 @@ namespace lsp
 
             // Initialize toggle
             sListen.init();
+            sStop.init();
 
             return true;
         }
@@ -321,6 +330,7 @@ namespace lsp
         {
             lsp_trace("Binding listen toggle...");
             BIND_PORT(pListen);
+            BIND_PORT(pStop);
 
             if (dynamics)
             {
@@ -363,7 +373,9 @@ namespace lsp
                 BIND_PORT(af->pPreDelay);
                 BIND_PORT(af->pOn);
                 BIND_PORT(af->pListen);
-                BIND_PORT(af->pReverse);
+                BIND_PORT(af->pStop);
+                BIND_PORT(af->pPreReverse);
+                BIND_PORT(af->pPostReverse);
                 BIND_PORT(af->pCompensate);
                 BIND_PORT(af->pCompensateFade);
                 BIND_PORT(af->pCompensateChunk);
@@ -416,6 +428,7 @@ namespace lsp
         void sampler_kernel::destroy_afile(afile_t *af)
         {
             af->sListen.destroy();
+            af->sStop.destroy();
             af->sNoteOn.destroy();
             for (size_t i=0; i<4; ++i)
             {
@@ -505,7 +518,7 @@ namespace lsp
         }
 
         template <class T>
-        void sampler_kernel::commit_value(size_t & counter, T & field, plug::IPort *port)
+        void sampler_kernel::commit_value(uint32_t & counter, T & field, plug::IPort *port)
         {
             const T temp = port->value();
             if (temp != field)
@@ -515,7 +528,7 @@ namespace lsp
             }
         }
 
-        void sampler_kernel::commit_value(size_t & counter, bool & field, plug::IPort *port)
+        void sampler_kernel::commit_value(uint32_t & counter, bool & field, plug::IPort *port)
         {
             const bool temp = port->value() >= 0.5f;
             if (temp != field)
@@ -553,9 +566,11 @@ namespace lsp
             // Process listen toggle
             if (pListen != NULL)
                 sListen.submit(pListen->value());
+            if (pStop != NULL)
+                sStop.submit(pStop->value());
 
             // Update note and octave
-            lsp_trace("Initializing samples...");
+//            lsp_trace("Initializing samples...");
 
             // Iterate all samples
             for (size_t i=0; i<nFiles; ++i)
@@ -576,6 +591,7 @@ namespace lsp
                 // Listen trigger
     //            lsp_trace("submit listen%d = %f", int(i), af->pListen->getValue());
                 af->sListen.submit(af->pListen->value());
+                af->sStop.submit(af->pStop->value());
     //            lsp_trace("listen[%d].pending = %s", int(i), (af->sListen.pending()) ? "true" : "false");
 
                 // Makeup gain + mix gain
@@ -619,14 +635,15 @@ namespace lsp
                 commit_value(af->nUpdateReq, af->fTailCut, af->pTailCut);
                 commit_value(af->nUpdateReq, af->fFadeIn, af->pFadeIn);
                 commit_value(af->nUpdateReq, af->fFadeOut, af->pFadeOut);
-                commit_value(af->nUpdateReq, af->bReverse, af->pReverse);
+                commit_value(af->nUpdateReq, af->bPreReverse, af->pPreReverse);
+                commit_value(af->nUpdateReq, af->bPostReverse, af->pPostReverse);
                 commit_value(af->nUpdateReq, af->bCompensate, af->pCompensate);
                 commit_value(af->nUpdateReq, af->fCompensateFade, af->pCompensateFade);
                 commit_value(af->nUpdateReq, af->fCompensateChunk, af->pCompensateChunk);
                 commit_value(af->nUpdateReq, af->nCompensateFadeType, af->pCompensateFadeType);
 
                 // Update loop parameters
-                size_t loop_update = 0;
+                uint32_t loop_update = 0;
                 dspu::sample_loop_t loop_mode = decode_loop_mode(af->pLoopOn, af->pLoopMode);
                 if (af->enLoopMode != loop_mode)
                 {
@@ -719,7 +736,7 @@ namespace lsp
                 lsp_trace("load failed: status=%d (%s)", status, get_status(status));
                 return status;
             }
-            size_t channels         = lsp_min(nChannels, source->channels());
+            const size_t channels   = lsp_min(nChannels, source->channels());
             if (!source->set_channels(channels))
             {
                 lsp_trace("failed to resize source sample to %d channels", int(channels));
@@ -771,6 +788,9 @@ namespace lsp
                 lsp_warn("Error resampling source sample");
                 return STATUS_NO_MEM;
             }
+            if (af->bPreReverse)
+                temp.reverse();
+
             if (af->bCompensate)
             {
                 size_t chunk_size       = dspu::millis_to_samples(nSampleRate, af->fCompensateChunk);
@@ -966,7 +986,7 @@ namespace lsp
                 (af->nLoopFadeType == XFADE_LINEAR) ? dspu::SAMPLE_CROSSFADE_LINEAR : dspu::SAMPLE_CROSSFADE_CONST_POWER,
                 dspu::millis_to_samples(nSampleRate, af->fLoopFade));
             ps.set_delay(delay);
-            ps.set_start((af->bReverse) ? s->length() : 0, af->bReverse);
+            ps.set_start((af->bPostReverse) ? s->length() : 0, af->bPostReverse);
 
             dspu::Playback *vpb = (mode == PLAY_FILE) ? af->vListen :
                                   (mode == PLAY_INSTRUMENT) ? vListen :
@@ -977,10 +997,7 @@ namespace lsp
                 lsp_trace("channels[%d].play(%d, %d, %f, %d)", int(0), int(af->nID), int(0), gain * af->fGains[0], int(delay));
                 ps.set_sample_channel(0);
                 ps.set_volume(gain * af->fGains[0]);
-                vpb[0].set(vChannels[0].play(&ps));
-                vpb[1].clear();
-                vpb[2].clear();
-                vpb[3].clear();
+                vpb[0] = vChannels[0].play(&ps);
             }
             else // if (nChannels == 2)
             {
@@ -988,14 +1005,14 @@ namespace lsp
                 for (size_t i=0; i<2; ++i)
                 {
                     size_t j=i^1; // j = (i + 1) % 2
-                    ps.set_sample_channel(i);
+                    ps.set_sample_channel(i % s->channels());
 
                     lsp_trace("channels[%d].play(%d, %d, %f, %d)", int(i), int(af->nID), int(i), gain * af->fGains[i], int(delay));
                     ps.set_volume(gain * af->fGains[i]);
-                    vpb[pb_id++].set(vChannels[i].play(&ps));
+                    vpb[pb_id++] = vChannels[i].play(&ps);
                     lsp_trace("channels[%d].play(%d, %d, %f, %d)", int(j), int(i), int(af->nID), gain * (1.0f - af->fGains[i]), int(delay));
                     ps.set_volume(gain * (1.0f - af->fGains[i]));
-                    vpb[pb_id++].set(vChannels[j].play(&ps));
+                    vpb[pb_id++] = vChannels[j].play(&ps);
                 }
             }
         }
@@ -1040,9 +1057,9 @@ namespace lsp
                     vListen[i].cancel(fadeout, 0);
             }
             else
+            {
                 for (size_t i=0; i<4; ++i)
                     vListen[i].stop(0);
-            {
             }
         }
 
@@ -1253,8 +1270,14 @@ namespace lsp
                 start_listen_instrument(0.5f, 1.0f);
                 sListen.commit();
             }
-            else if (sListen.off())
+			else if (sListen.off())
                 stop_listen_instrument(false);
+   
+            if (sStop.pending())
+            {
+                stop_listen_instrument(true);
+                sStop.commit();
+            }
 
             for (size_t i=0; i<nFiles; ++i)
             {
@@ -1273,6 +1296,12 @@ namespace lsp
                 }
                 else if (af->sListen.off())
                     stop_listen_file(af, false);
+
+                if (af->sStop.pending())
+                {
+                    stop_listen_file(af, true);
+                    af->sStop.commit();
+                }
             }
         }
 
@@ -1355,7 +1384,7 @@ namespace lsp
 
                 // Store file thumbnails to mesh
                 plug::mesh_t *mesh  = reinterpret_cast<plug::mesh_t *>(af->pMesh->buffer());
-                if ((mesh == NULL) || (!mesh->isEmpty()) || (!af->bSync) || (!af->pLoader->idle()))
+                if ((mesh == NULL) || (!mesh->isEmpty()) || (!af->bSync) || (!af->pLoader->idle()) || (!af->pRenderer->idle()))
                     continue;
 
                 if ((channels > 0) && (af->vThumbs[0] != NULL))
@@ -1417,6 +1446,7 @@ namespace lsp
             v->write_object("pLoader", f->pLoader);
             v->write_object("pRenderer", f->pRenderer);
             v->write_object("sListen", &f->sListen);
+            v->write_object("sStop", &f->sStop);
             v->write_object("sNoteOn", &f->sNoteOn);
             v->write_object_array("vPlayback", f->vPlayback, 4);
             v->write_object_array("vListen", f->vListen, 4);
@@ -1445,7 +1475,8 @@ namespace lsp
             v->write("fTailCut", f->fTailCut);
             v->write("fFadeIn", f->fFadeIn);
             v->write("fFadeOut", f->fFadeOut);
-            v->write("bReverse", f->bReverse);
+            v->write("bPreReverse", f->bPreReverse);
+            v->write("bPostReverse", f->bPostReverse);
             v->write("bCompensate", f->bCompensate);
             v->write("fCompensateFade", f->fCompensateFade);
             v->write("fCompensateChunk", f->fCompensateChunk);
@@ -1482,7 +1513,9 @@ namespace lsp
             v->write("pPreDelay", f->pPreDelay);
             v->write("pOn", f->pOn);
             v->write("pListen", f->pListen);
-            v->write("pReverse", f->pReverse);
+            v->write("pStop", f->pStop);
+            v->write("pPreReverse", f->pPreReverse);
+            v->write("pPostReverse", f->pPostReverse);
             v->write("pCompensate", f->pCompensate);
             v->write("pCompensateFade", f->pCompensateFade);
             v->write("pCompensateChunk", f->pCompensateChunk);
@@ -1519,6 +1552,7 @@ namespace lsp
             v->write_object_array("vListen", vListen, 4);
             v->write_object("sActivity", &sActivity);
             v->write_object("sListen", &sListen);
+            v->write_object("sStop", &sStop);
             v->write_object("sRandom", &sRandom);
             v->write_object("sGCTask", &sGCTask);
 
@@ -1537,6 +1571,7 @@ namespace lsp
             v->write("pDrift", pDrift);
             v->write("pActivity", pActivity);
             v->write("pListen", pListen);
+            v->write("pStop", pStop);
             v->write("pData", pData);
         }
     } /* namespace plugins */
