@@ -75,7 +75,7 @@ namespace lsp
             sHBar(dpy),
             sVBar(dpy),
             vItems(&sProperties, &sIListener),
-            vSelected(&sProperties, &sIListener),
+            vSelected(&sProperties, &sSListener),
             sSizeConstraints(&sProperties),
             sHScrollMode(&sProperties),
             sVScrollMode(&sProperties),
@@ -94,6 +94,7 @@ namespace lsp
         {
             nBMask          = 0;
             nXFlags         = 0;
+            nPendingIndex   = -1;
             nCurrIndex      = -1;
             nLastIndex      = -1;
             nKeyScroll      = SCR_NONE;
@@ -164,8 +165,7 @@ namespace lsp
                 return result;
 
             sIListener.bind_all(this, on_add_item, on_remove_item);
-            sKeyTimer.bind(pDisplay);
-            sKeyTimer.set_handler(key_scroll_handler, self());
+            sSListener.bind_all(this, on_select_item, on_deselect_item);
 
             // Configure scroll bars
             sHBar.orientation()->set(O_HORIZONTAL);
@@ -258,6 +258,7 @@ namespace lsp
 
             alloc->wMinW        = 0;
             alloc->wMinH        = 0;
+            alloc->wItemH       = 0;
 
             LSPString s;
             ws::font_parameters_t fp;
@@ -299,8 +300,10 @@ namespace lsp
                 li->padding()->add(&ai->a, scaling);
 
                 // Update overall width and height
+                const ssize_t item_h = ai->a.nHeight + spacing;
                 alloc->wMinW    = lsp_max(alloc->wMinW, ai->a.nWidth);
-                alloc->wMinH   += ai->a.nHeight + spacing;
+                alloc->wMinH   += item_h;
+                alloc->wItemH   = lsp_max(alloc->wItemH, item_h);
             }
         }
 
@@ -438,36 +441,61 @@ namespace lsp
 
             if (a.bHBar)
             {
+                const ssize_t range = lsp_max(0, a.wMinW - a.sList.nWidth);
                 sHBar.realize_widget(&a.sHBar);
-                sHScroll.set_range(0, lsp_max(0, a.wMinW - a.sList.nWidth));
+                sHScroll.set_range(0, range);
                 sHBar.value()->set_range(sHScroll.min(), sHScroll.max());
+
+                const ssize_t step = lsp_max(range / 100, 2);
+                sHBar.step()->set_step(step);
+                sHBar.accel_step()->set_step(step * 5);
             }
             if (a.bVBar)
             {
+                const ssize_t range = lsp_max(0, a.wMinH - a.sList.nHeight);
                 sVBar.realize_widget(&a.sVBar);
-                sVScroll.set_range(0, lsp_max(0, a.wMinH - a.sList.nHeight));
+                sVScroll.set_range(0, range);
                 sVBar.value()->set_range(sVScroll.min(), sVScroll.max());
+
+                const ssize_t step = lsp_limit(range / 100, a.wItemH, a.wItemH * 5);
+                sVBar.step()->set_step(step);
+                sVBar.accel_step()->set_step(step * 5);
             }
 
             // Realize children
             realize_children();
 
-            // Update scrolling
-//            item_t *curr    = find_by_index(nCurrIndex);
-//            ssize_t start   = vVisible.index_of(curr);
-//            if (start >= 0)
-//            {
-//                if (scroll_to_item(start))
-//                    realize_children();
-//            }
+            // Check if there is pending scroll_to_item
+            if (nPendingIndex >= 0)
+            {
+                item_t *curr    = find_by_index(nPendingIndex);
+                ssize_t start   = (curr != NULL) ? vVisible.index_of(curr) : -1;
+                if ((start >= 0) && (scroll_to_item(start)))
+                {
+                    realize_children();
+                    nCurrIndex          = nPendingIndex;
+                }
+
+                // Commit new index
+                nPendingIndex       = -1;
+            }
 
             // Call parent for realize
             WidgetContainer::realize(r);
         }
 
-        void ListBox::scroll_to_current()
+        void ListBox::scroll_to(size_t index)
         {
-            item_t *curr    = find_by_index(nCurrIndex);
+            if (nFlags & SIZE_INVALID)
+            {
+                nPendingIndex       = index;
+                return;
+            }
+
+            item_t *curr    = find_by_index(index);
+            if (curr == NULL)
+                return;
+
             ssize_t start   = vVisible.index_of(curr);
             if (start >= 0)
             {
@@ -476,6 +504,11 @@ namespace lsp
             }
         }
 
+        void ListBox::scroll_to_current()
+        {
+            scroll_to(nCurrIndex);
+        }
+
         void ListBox::realize_children()
         {
             float scaling       = lsp_max(0.0f, sScaling.get());
@@ -772,16 +805,18 @@ namespace lsp
             if (item == NULL)
                 return;
 
-            ListBox *_this = widget_ptrcast<ListBox>(obj);
-            if (_this == NULL)
+            ListBox *self = widget_ptrcast<ListBox>(obj);
+            if (self == NULL)
                 return;
 
             // Change parent only if we are working with the main item list.
-            if (_this->vItems.is(prop))
+            if (self->vItems.is(prop))
             {
-                item->set_parent(_this);
+                item->set_parent(self);
             }
-            _this->query_resize();
+
+            self->vVisible.clear();
+            self->query_resize();
         }
 
         void ListBox::on_remove_item(void *obj, Property *prop, void *w)
@@ -803,9 +838,28 @@ namespace lsp
                 self->unlink_widget(item);
             }
 
+            self->vVisible.clear();
             self->query_resize();
         }
 
+        void ListBox::on_select_item(void *obj, Property *prop, void *w)
+        {
+            ListBox *self = widget_ptrcast<ListBox>(obj);
+            if (self == NULL)
+                return;
+
+            self->query_draw();
+        }
+
+        void ListBox::on_deselect_item(void *obj, Property *prop, void *w)
+        {
+            ListBox *self = widget_ptrcast<ListBox>(obj);
+            if (self == NULL)
+                return;
+
+            self->query_draw();
+        }
+
         status_t ListBox::on_mouse_down(const ws::event_t *e)
         {
             if (nBMask == 0)
@@ -945,7 +999,7 @@ namespace lsp
                 }
             }
 
-            lsp_trace("first = %d", int(first));
+//            lsp_trace("first = %d", int(first));
             it  = vVisible.uget(lsp_limit(first, 0, ssize_t(vVisible.size() - 1)));
             return (Position::inside(&it->r, x, y)) ? it : NULL;
         }
@@ -1046,6 +1100,8 @@ namespace lsp
         {
             size_t scroll   = nKeyScroll;
 
+            lsp_trace("keycode = 0x%x", int(e->nCode));
+
             nKeyScroll  = lsp_setflag(nKeyScroll, SCR_SHIFT, e->nState & ws::MCF_SHIFT);
             nKeyScroll  = lsp_setflag(nKeyScroll, SCR_CTRL, e->nState & ws::MCF_CONTROL);
 
@@ -1103,17 +1159,15 @@ namespace lsp
             }
 
             if ((scroll ^ nKeyScroll) & SCR_KEYMASK)
-            {
                 on_key_scroll();
-                if (scroll == 0)
-                    sKeyTimer.launch(-1, 250, 1000);
-            }
 
             return STATUS_OK;
         }
 
         status_t ListBox::on_key_up(const ws::event_t *e)
         {
+            lsp_trace("keycode = 0x%x", int(e->nCode));
+
             nKeyScroll  = lsp_setflag(nKeyScroll, SCR_SHIFT, e->nState & ws::MCF_SHIFT);
             nKeyScroll  = lsp_setflag(nKeyScroll, SCR_CTRL, e->nState & ws::MCF_CONTROL);
 
@@ -1137,18 +1191,9 @@ namespace lsp
                     break;
             }
 
-            if (!(nKeyScroll & SCR_KEYMASK))
-                sKeyTimer.cancel();
-
             return STATUS_OK;
         }
 
-        status_t ListBox::key_scroll_handler(ws::timestamp_t sched, ws::timestamp_t time, void *arg)
-        {
-            ListBox *_this = widget_ptrcast<ListBox>(arg);
-            return (_this != NULL) ? _this->on_key_scroll() : STATUS_OK;
-        }
-
         status_t ListBox::on_key_scroll()
         {
             size_t k1 = nKeyScroll & SCR_KEYMASK1;
@@ -1157,6 +1202,8 @@ namespace lsp
             if (mask == 0)
                 return STATUS_OK;
 
+            lsp_trace("on_key_scroll mask=0x%08x", int(mask));
+
             float scaling   = lsp_max(0.0f, sScaling.get());
             item_t *curr    = find_by_index(nCurrIndex);
             ssize_t start   = lsp_max(-1, vVisible.index_of(curr));
@@ -1190,7 +1237,7 @@ namespace lsp
                     }
                 }
             }
-            else if ((mask & SCR_UP) | (mask & SCR_KP_UP))
+            else if (mask & (SCR_UP | SCR_KP_UP))
             {
                 if (nKeyScroll & (SCR_UP | SCR_KP_UP))
                 {
