@@ -66,6 +66,8 @@ namespace lsp
 
         Window::Window(Display *dpy, void *handle, ssize_t screen):
             WidgetContainer(dpy),
+            sShortcuts(NULL),
+            sShortcutTracker(&sShortcuts),
             sTitle(&sProperties),
             sRole(&sProperties),
             sBorderColor(&sProperties),
@@ -175,17 +177,23 @@ namespace lsp
             return init_internal(true);
         }
 
-        status_t Window::sync_size()
+        status_t Window::sync_size(bool force)
         {
             // Request size limits of the window
             ws::size_limit_t sr;
-            ws::rectangle_t r;
+            ws::rectangle_t r, wsr;
 
             get_padded_size_limits(&sr);
             float scaling       = lsp_max(0.0f, sScaling.get());
             size_t border       = lsp_max(0, sBorderSize.get()) * scaling;
-            sPosition.get(&r);
             sWindowSize.compute(&r, scaling);
+            pWindow->get_geometry(&wsr);
+            sPosition.get(&r);
+
+//            lsp_trace("Current window geometry: x=%d, y=%d, w=%d, h=%d",
+//                int(r.nLeft), int(r.nTop), int(r.nWidth), int(r.nHeight));
+//            lsp_trace("Window subsystem geometry: x=%d, y=%d, w=%d, h=%d",
+//                int(wsr.nLeft), int(wsr.nTop), int(wsr.nWidth), int(wsr.nHeight));
 
             // Set window's size constraints and update geometry
             if (sPolicy.get() == WP_GREEDY)
@@ -216,8 +224,16 @@ namespace lsp
                 xr.nHeight          = lsp_max(0, sr.nMinHeight) + border*2;
 
                 // Maximize the width
-                r.nWidth            = lsp_max(xr.nWidth,  r.nWidth);
-                r.nHeight           = lsp_max(xr.nHeight, r.nHeight);
+                if (force)
+                {
+                    r.nWidth            = lsp_max(xr.nWidth,  r.nWidth);
+                    r.nHeight           = lsp_max(xr.nHeight, r.nHeight);
+                }
+                else
+                {
+                    r.nWidth            = lsp_max(xr.nWidth,  r.nWidth, wsr.nWidth);
+                    r.nHeight           = lsp_max(xr.nHeight, r.nHeight, wsr.nHeight);
+                }
             }
 
             // Window size should be at least 1x1 pixel
@@ -226,7 +242,7 @@ namespace lsp
 
             // Check if we need to resize window
 //            lsp_trace("size constraints: w={%d, %d}, h={%d, %d}",
-//                    int(sr.nMinWidth), int(sr.nMinHeight), int(sr.nMaxWidth), int(sr.nMaxHeight)
+//                int(sr.nMinWidth), int(sr.nMinHeight), int(sr.nMaxWidth), int(sr.nMaxHeight)
 //            );
             pWindow->set_size_constraints(&sr);
             if ((sSize.nWidth != r.nWidth) || (sSize.nHeight != r.nHeight))
@@ -291,7 +307,7 @@ namespace lsp
                 return STATUS_OK;
 
             if (resize_pending())
-                sync_size();
+                sync_size(false);
 
             if (!redraw_pending())
                 return STATUS_OK;
@@ -461,15 +477,20 @@ namespace lsp
             return update_pointer();
         }
 
+        status_t Window::on_mouse_pointer(pointer_event_t *e)
+        {
+            if ((!bOverridePointer) && (hMouse.pWidget != NULL) && (hMouse.pWidget != this))
+                e->enPointer    = hMouse.pWidget->current_pointer(e->nLeft, e->nTop);
+
+            return STATUS_OK;
+        }
+
         status_t Window::update_pointer()
         {
             if (pWindow == NULL)
                 return STATUS_OK;
 
-            ws::mouse_pointer_t mp  = sPointer.get();
-            if ((!bOverridePointer) && (hMouse.pWidget != NULL))
-                mp      = hMouse.pWidget->current_pointer();
-
+            ws::mouse_pointer_t mp  = current_pointer(hMouse.nLeft, hMouse.nTop);
             return (mp == pWindow->get_mouse_pointer()) ? STATUS_OK : pWindow->set_mouse_pointer(mp);
         }
 
@@ -540,8 +561,8 @@ namespace lsp
 ////                            int(l.nMinHeight), int(l.nMaxHeight)
 ////                        );
 //                }
-
                 query_resize();
+                sync_size(true);
             }
             if (sLayout.is(prop))
             {
@@ -579,7 +600,7 @@ namespace lsp
             // Update window parameters
             if (pWindow != NULL)
             {
-                sync_size();
+                sync_size(false);
                 update_pointer();
             }
 
@@ -630,7 +651,7 @@ namespace lsp
 
         void Window::show()
         {
-            pActor      = NULL;
+            pActor              = NULL;
             return WidgetContainer::show();
         }
 
@@ -728,6 +749,7 @@ namespace lsp
                         sRedraw.launch(-1, 40);
                         query_draw(REDRAW_SURFACE);
                     }
+                    sShortcutTracker.reset();
                     sVisibility.commit_value(true);
                     break;
 
@@ -759,33 +781,30 @@ namespace lsp
                     if (!bMapped)
                         break;
 
-                    if (!(nFlags & RESIZE_PENDING))
+                    lsp_trace("resize to: l=%d, t=%d, w=%d, h=%d", int(e->nLeft), int(e->nTop), int(e->nWidth), int(e->nHeight));
+
+                    // Update the position of the window
+                    if ((sSize.nLeft != e->nLeft) || (sSize.nTop != e->nTop))
+                        sPosition.commit_value(e->nLeft, e->nTop);
+
+                    // Update size of the window
+                    if ((sSize.nWidth != e->nWidth) || (sSize.nHeight != e->nHeight))
                     {
-                        lsp_trace("resize to: l=%d, t=%d, w=%d, h=%d", int(e->nLeft), int(e->nTop), int(e->nWidth), int(e->nHeight));
+                        // Realize the widget only if size has changed
+                        sWindowSize.commit_value(e->nWidth, e->nHeight, sScaling.get());
 
-                        // Update the position of the window
-                        if ((sSize.nLeft != e->nLeft) || (sSize.nTop != e->nTop))
-                            sPosition.commit_value(e->nLeft, e->nTop);
-
-                        // Update size of the window
-                        if ((sSize.nWidth != e->nWidth) || (sSize.nHeight != e->nHeight))
-                        {
-                            // Realize the widget only if size has changed
-                            sWindowSize.commit_value(e->nWidth, e->nHeight, sScaling.get());
-
-                            ws::rectangle_t r = {
-                                e->nLeft,
-                                e->nTop,
-                                e->nWidth,
-                                e->nHeight
-                            };
-                            realize_widget(&r);
-                        }
-                        else
-                        {
-                            sSize.nLeft     = e->nLeft;
-                            sSize.nTop      = e->nTop;
-                        }
+                        ws::rectangle_t r = {
+                            e->nLeft,
+                            e->nTop,
+                            e->nWidth,
+                            e->nHeight
+                        };
+                        realize_widget(&r);
+                    }
+                    else
+                    {
+                        sSize.nLeft     = e->nLeft;
+                        sSize.nTop      = e->nTop;
                     }
                     break;
 
@@ -872,22 +891,32 @@ namespace lsp
                     // Find the keyboard event handler
                     lsp_trace("key down: keys.pWidget = %p, pFocused = %p, nkeys=%d",
                         hKeys.pWidget, pFocused, int(hKeys.vKeys.size()));
-                    Widget *h       = pFocused; //(hKeys.pWidget != NULL) ? hKeys.pWidget : pFocused;
-                    if (h == NULL)
-                        h               = find_widget(e->nLeft, e->nTop);
+                    Widget *handler     = (pFocused != NULL) ? pFocused : find_widget(e->nLeft, e->nTop);
 
                     // Take focus first and acquire keyboard lock
                     make_key_pressed(e->nCode);
-                    hKeys.pWidget       = h;
+                    hKeys.pWidget       = handler;
 
                     lsp_trace("update: keys.pWidget = %p, pFocused = %p, nkeys=%d",
                         hKeys.pWidget, pFocused, int(hKeys.vKeys.size()));
 
-                    // Handle key press event
-                    if (h == this)
-                        result          = WidgetContainer::handle_event(e);
-                    else if (h != NULL)
-                        result          = h->handle_event(e);
+                    if (handler == NULL)
+                        break;
+
+                    // Handle key press event by tracker first
+                    result          = sShortcutTracker.handle(handler, e);
+                    if (result == STATUS_OK)
+                    {
+                        // Call handler only if widget has not changed
+                        if (hKeys.pWidget == handler)
+                        {
+                            result = (handler == this) ?
+                                WidgetContainer::handle_event(e) :
+                                handler->handle_event(e);
+                        }
+                    }
+                    else if (result == STATUS_SKIP)
+                        result      = STATUS_OK;
 
                     break;
                 }
@@ -895,20 +924,28 @@ namespace lsp
                 case ws::UIE_KEY_UP:
                 {
                     // Find the keyboard event handler
-                    Widget *h       = hKeys.pWidget;
+                    Widget *handler = hKeys.pWidget;
 
                     // Release key lock state
                     if (make_key_released(e->nCode) <= 0)
                         hKeys.pWidget       = NULL;
 
                     lsp_trace("key up  : keys.pWidget = %p, pFocused = %p, nkeys=%d, handler=%p",
-                        hKeys.pWidget, pFocused, int(hKeys.vKeys.size()), h);
+                        hKeys.pWidget, pFocused, int(hKeys.vKeys.size()), handler);
 
                     // Handle key press event
-                    if (h == this)
-                        result          = WidgetContainer::handle_event(e);
-                    else if (h != NULL)
-                        result          = h->handle_event(e);
+                    if (handler == NULL)
+                        break;
+
+                    result          = sShortcutTracker.handle(handler, e);
+                    if (result == STATUS_OK)
+                    {
+                        result = (handler == this) ?
+                            WidgetContainer::handle_event(e) :
+                            handler->handle_event(e);
+                    }
+                    else if (result == STATUS_SKIP)
+                        result      = STATUS_OK;
 
                     break;
                 }
@@ -949,10 +986,17 @@ namespace lsp
 //                        h->handle_event(&ev);
 //                    }
 
+                    sShortcutTracker.reset();
                     do_kill_focus(pFocused);
                     break;
                 }
 
+                case ws::UIE_FOCUS_IN:
+                {
+                    sShortcutTracker.reset();
+                    break;
+                }
+
                 case ws::UIE_MOUSE_IN:
                 {
                     Widget *w   = hMouse.pWidget;
@@ -997,6 +1041,7 @@ namespace lsp
         {
             sPosition.set(size->nLeft, size->nTop);
             sWindowSize.set(size->nWidth, size->nHeight, sScaling.get());
+            sync_size(true);
 
             return STATUS_OK;
         }
@@ -1004,6 +1049,7 @@ namespace lsp
         status_t Window::resize_window(ssize_t width, ssize_t height)
         {
             sWindowSize.set(width, height, sScaling.get());
+            sync_size(true);
             return STATUS_OK;
         }
 
@@ -1107,6 +1153,10 @@ namespace lsp
 
         bool Window::do_kill_focus(Widget *w)
         {
+            // Ensure that widget is not handling keyboard events
+            if (hKeys.pWidget == w)
+                hKeys.pWidget       = NULL;
+
             // Check that widget owns focus
             if (w != pFocused)
                 return false;
